/****** Cyclical Labor Costs Within Jobs ******

** Authors: Daniel Schaefer & Carl Singleton - University of Edinburgh & University of Reading
** author contact details: c.a.singleton@reading.ac.uk
** date last updated: 13/08/2019
** last updated by: Daniel Schaefer

IMPORTANT NOTE: 
**********************************************************************************************
THE Office for National Statistics (ONS) is the data owner and sometimes RETROSPECTIVELY UPDATES/REVISES datasets. Numerical results obtained when running this replication code can thus differ from the figures presented in the paper. However, these differences should not qualitatively affect the results.
**********************************************************************************************

This work was carried out as part of an approved project by the UK Data Service and the data owners. Any results or views expressed herein are those of the authors only, and not the UK Data Service nor the Office for National Ststistics.

Inputs:

(1) Office for National Statistics 2017. Annual Survey of Hours and Earnings - 1997-2016: Secure Access. 9th Edition. UK Data Service. SN: 6689 - available from UK Data Service - http://dx.doi.org/10.5255/UKDA-SN-6689-8 [Note Change log to datasets]

(2) UK RPI/CPI year on year % inflation change, ONS - time series accessed 24/05/2016

(3) National Minimum Wage Rates

(4) SIC 2003 crosswalk 

(5) ISCO88 crosswalk

Inputs 2-5 must be created by anybody wishing to run this replication file such that they fit the code below. More details on sources listed below.

Outputs: All figures and statistics presented in "Cyclical Labor Costs Within Jobs"

*/

* Set global directories to the following, or as appropriate. 
* DO NOT change the names of the directories, only adjust paths as required.

* Location of ASHE annual datasets
global inputdir ""

* Location of .do-file
global codedir ""

* Location for datasets created by the below code
global created_datadir "" 

* Location for baseline regression results, first stage
global reg_resultsdir_97_16 ""

* Location for baseline regression results, second stage
global reg_results_2nd_stage ""

* Location of figures
global figure_dir ""

* Location of tables
global table_dir ""

* Location for tenure related results in section 5 of the paper
global tenure_dir ""

* Location for National Minimum Wage related results in appendix F of the paper
global nmw ""

* Location of other data, e.g. unemployment rate time series
global other_data ""

* Folders for other regression results
global reg_results_poe_criteria ""
global reg_results_public_dir ""
global reg_results_deflators ""
global reg_results_mean ""
global reg_results_no_controls ""
global reg_results_wls ""
global reg_results_ft ""
global reg_results_overtime ""
global reg_results_3d ""
global reg_results_p25 ""
global reg_results_p75 ""
global reg_first_diff ""

sysdir set PERSONAL $codedir
net set ado PERSONAL
adopath + R:\ADO_Files\

* Change font in graphs to Times New Roman
graph set window fontface "Times New Roman"

* must be entered directly into command window
set more off, perm

capture log close

	global create_datasets		= 1 // Creates all datasets (takes a couple of hours). RUN FIRST
	global regressions			= 1 // Run first- and second-step regressions
	global tables				= 1 // Create figures
	global figures				= 1 // Create figures
	global NMW					= 1 // Create figures related to appendix F
	
*** CREATE THE REQUIRED DATASETS ***	
if $create_datasets==1{
	
	* Define which datasets to create using the follwing global settings
	global create_panel 		= 1 // Create a panel from the indivdual annual ASHE 1997-2016 datasets.
	global creation_variables	= 1 // Add/create additional variables.
	global create_baseline 		= 1 // Create baseline sample of firms.
	global create_row3_data 	= 1 // Create dataset for Table 3, Row 3
	global create_row4_data 	= 1 // Create dataset for Table 3, Row 4
	global create_row7_data 	= 1 // Create dataset for Table 3, Row 7
	global tenure_data 			= 1 // Create dataset for Figure 2&3, Table C6-C9
	global create_B2_data 		= 1 // Create dataset for Table B2
	
*** Create an ASHE panel dataset from annual (2016-1997) datasets
if $create_panel==1{

	/* 
	The following code adjusts the ASHE annual datasets 1997-2016 to be consistent
	across years. This involves a cross-walk for area codes. To match occuaptional codes over 
	time, the dual-coded 2011 ASHE dataset will be used.
	*/
	
	*****************
	*** 2016-2012 ***
	*****************
	{
	/* 
	Note, ASHE 2012-2016 warea coding in ONS 9-digit format, use conversion file to obtain 3 digit standard.
	Also, multiple occurances of piden create problems with the panel structure of the ASHE. Keep only 
	main jobs - necessary to create panel.
	*/

	* Define program "correct_djob" to correct djob and mjob entries. Keep only main jobs.
	program define correct_djob	
		drop if piden==.
		sort piden
		egen tag = tag(piden)
		replace tag=. if tag==1
		by piden: egen marker = count(tag)
		replace djob=1 if marker!=0
		replace djob=0 if marker==0
		replace mjob=0 if djob==0
		drop tag marker
		drop if djob==1 & mjob!=1
		sort piden
		egen tag = tag(piden mjob)
		by piden: egen num = count(tag)
		keep if num==1
		drop num tag
	end	

	forvalues i = 2012/2016{
		cd $inputdir
		use ashe_`i'_restricted.dta, clear
		cd $other_data
		quietly merge m:1 warea using warea_conversion, nogen
		drop warea
		rename ukds warea
		destring piden, replace
		destring luref, replace
		correct_djob
		cd $created_datadir
		save ashe_`i'_numeric, replace
	}
	
	}
	************
	*** 2011 ***
	************
	{
	/*
	ASHE 2011 is available in two versions; SOC00 and SOC10 coding. Merge SOC10 into SOC00 dataset on piden.
	Therefore, piden has to uniquely identify workers in both datasets. Only workers with at most two job holdings
	will be included, because main job and one secondary job can be identified reliably.
	Note that ASHE2011 in SOC00 coding has piden stored as "long" as opposed to "string".
	The following code matches as many occupation classifications in 2011 as possible.
	*/
	{
	cd $inputdir
	use piden occ10 djob mjob entref using ashe_2011prov_soc10_restricted.dta, clear
	
	* piden is string, change to numeric
	drop if piden==""
	g new_piden = real(piden)
	drop piden
	rename new_piden piden
	
	* Impute missing double job marker if multiple piden
	sort piden
	egen tag = tag(piden)
	replace tag=. if tag==1
	by piden: egen marker = count(tag)
	replace djob=1 if marker!=0
	replace djob=0 if marker==0
	replace mjob=0 if djob==0
	drop tag marker

	/* Create three different datasets that contain piden and ---SOC10---: 
	(1) workers with exactly two jobs - main job
	(1) workers with exactly two jobs - secondary job
	(3) workers with exactly one job
	*/
	* Multiple job employees
	preserve
		*Identify main jobs of multiple job holders
		drop if djob==0
		drop if mjob==0
		drop djob mjob entref
		cd $created_datadir
		save temp_djob_inc_main, replace
	restore
	preserve
		*Identify mutliple job holders with exactly two jobs (exclude 3, 4, ...). Keep secondary job
		drop if djob==0
		drop if mjob==1
		sort piden
		egen tag = tag(piden)
		by piden: egen temp = count(tag)
		drop if temp!=1
		drop tag temp djob mjob entref
		cd $created_datadir
		save temp_djob_exc_main, replace
	restore

	* Single job employees
	drop if djob==1
	keep piden occ10
	cd $created_datadir
	save temp_mjob, replace

	cd $inputdir
	use ashe_2011_restricted.dta, clear
	* Impute missing double job marker if multiple piden
	drop if piden==.
	sort piden
	egen tag = tag(piden)
	replace tag=. if tag==1
	by piden: egen marker = count(tag)
	replace djob=1 if marker!=0
	replace djob=0 if marker==0
	replace mjob=0 if djob==0
	drop tag marker

	/* Create three different datasets that contain piden and ---SOC00--- and merge 
	with previously created SOC10: 
	(1) workers with exactly two jobs - main job
	(1) workers with exactly two jobs - secondary job
	(3) workers with exactly one job
	*/
	* multiple job employees
	preserve
		*Identify main jobs of multiple job holders
		drop if djob==0
		drop if mjob==0
		* merge with SCO10
		cd $created_datadir 
		quietly merge 1:1 piden using temp_djob_inc_main.dta, nogen
		save temp_djob3, replace 
	restore
	preserve
		*Identify mutliple job holders with exactly two jobs (exclude 3, 4, ...). Keep secondary job
		drop if djob==0
		drop if mjob==1
		egen tag = tag(piden)
		sort piden
		by piden: egen temp = count(tag)
		drop if temp!=1
		drop tag temp
		* merge with SCO10
		cd $created_datadir 
		quietly merge 1:1 piden using temp_djob_exc_main.dta, nogen
		save temp_djob2, replace 
	restore
	
	* single job employees
	drop if djob==1
	* merge with SCO10
	cd $created_datadir 
	quietly merge m:1 piden using temp_mjob.dta, nogen
	append using temp_djob2
	append using temp_djob3
	save ashe_2011_numeric, replace 

	* Clean up temporary data
	erase temp_djob_exc_main.dta
	erase temp_djob_inc_main.dta
	erase temp_djob2.dta
	erase temp_djob3.dta
	erase temp_mjob.dta
	}
	}
	*****************
	*** 2010-1997 ***
	*****************
	{
	forvalues i = 2004/2010{
		cd $inputdir
		use ashe_`i'_restricted.dta, clear
		destring piden, replace
		* numstrata identifies different versions of the ASHE data
		drop if year==2004 & numstrata==1
		drop if year==2006 & numstrata==3
		correct_djob
		cd $created_datadir
		save ashe_`i'_numeric, replace
	}

	forvalues i = 2001/2003{
		cd $inputdir
		use ashe_`i'_with_piden_restricted.dta, clear
		destring piden, replace
		correct_djob
		cd $created_datadir
		save ashe_`i'_numeric, replace
	}
	
	forvalues i = 1997/2000{
		cd $inputdir
		use ashe_`i'_with_piden_restricted.dta, clear
		drop if piden==""
		*never possible to impute missing pay obs
		drop if bhr==0 | gpox==0 | hexo==0

		*no marker for main job available - select main job based on highest bhr
		sort piden
		by piden: egen ind = max(bhr)
		drop if bhr<ind

		*drop all obs with ambiguous main job
		egen tag = tag(piden)
		by piden: egen marker = count(tag)
		drop if marker!=1
		drop tag marker

		cd $created_datadir
		save ashe_`i'_numeric, replace
	}

	}

	********************************************************************************
	*** Link piden backwards for job stayers to impute missing entref and empsta ***
	********************************************************************************
	
	/*
	Idea:
	A worker who stays in the same job stays necessarily also in the same firm.
	We can impute missing firm identifiers from the next year if a worker has 
	a firm identifier missing in the current year, as long as the worker remained in the same job.
	Additionally, local unit identifiers (plants) can be used WITHIN a year to impute firm idnetifiers
	for other workers. 
	*/
	
	forvalues i = 2016(-1)2009{
		cd $created_datadir
		use piden entref sjd mjob djob using ashe_`i'_numeric.dta, clear
		drop if djob==1 & mjob!=1 // necessary because ashe_2011 not in correct format	
		
		keep if sjd==1 & entref!=. & piden!=.
		keep piden entref
		cd $created_datadir
		save entref_temp.dta, replace

		local k = `i' - 1
		cd $created_datadir
		use ashe_`k'_numeric, clear
		destring piden, replace
		cd $created_datadir
		quietly merge m:1 piden using entref_temp.dta, update nogen keep(1 3 4 5)
		
		* Use luref within cross-section to impute missing entref. Only use "unambiguous" lurefs.
		* Note that miscoding could theoretically cause some lurefs to be attributed to multiple entrefs.
		preserve
			drop if entref==.
			destring luref, replace
			sort luref
			by luref: egen temp = count(luref)
			drop if temp<=1
			sort luref entref
			egen tag = tag(luref entref)
			replace tag=. if tag==0
			sort luref
			by luref: egen marker = count(tag)
			drop if marker!=1
			egen tag2 = tag(luref)
			drop if tag2==0
			keep luref entref
			cd $created_datadir
			save luref_temp.dta, replace
		restore
		
		destring luref, replace
		quietly merge m:1 luref using luref_temp.dta, update nogen keep(1 3 4 5)  
		save ashe_`k'_numeric, replace
	}

	forvalues i = 2008(-1)1998{
		cd $created_datadir
		
		use piden entref sjob using ashe_`i'_numeric.dta, clear
		
		keep if sjob==1 & entref!=. & piden!=.
		cd $created_datadir
		save entref_temp.dta, replace

		local k = `i' - 1
		cd $created_datadir
		use ashe_`k'_numeric, clear
		destring piden, replace
		drop if piden == .
		cd $created_datadir
		quietly merge m:1 piden using entref_temp.dta, update nogen keep(1 3 4 5)
		
		* Use luref within cross-section to impute missing entref. Only use unambiguous lurefs
		preserve
			drop if entref==.
			destring luref, replace
			sort luref
			by luref: egen temp = count(luref)
			drop if temp<=1
			sort luref entref
			egen tag = tag(luref entref)
			replace tag=. if tag==0
			sort luref
			by luref: egen marker = count(tag)
			drop if marker!=1
			egen tag2 = tag(luref)
			drop if tag2==0
			keep luref entref
			cd $created_datadir
			save luref_temp.dta, replace
		restore
		
		destring luref, replace
		quietly merge m:1 luref using luref_temp.dta, update nogen keep(1 3 4 5)  
		save ashe_`k'_numeric, replace
	}

	erase luref_temp.dta
	erase entref_temp.dta

	********************************************************************************
	*** Append all the individual ASHE cross sections to form panel 1997-2016
	********************************************************************************

	* ASHE 1997 missing variables: agp sjob wcoa pt djob mjob anipay empsta
	global varlist  = "piden age lop adr gpay gpox thrs he hexo ovpay bhr entref year sic* occ* colag idbrnemp idbrsta wgor warea sex ft luref"
	global varlist2 = "agp djob mjob empsta wcoa"

	cd $created_datadir
	use $varlist using ashe_1997_numeric, clear
	quietly append using ashe_1998_numeric, keep($varlist sjob)
	quietly append using ashe_1999_numeric, keep($varlist sjob agp)
	quietly append using ashe_2000_numeric, keep($varlist sjob agp)
	quietly append using ashe_2001_numeric, keep($varlist sjob agp djob mjob)
	quietly append using ashe_2002_numeric, keep($varlist sjob agp djob mjob empsta)
	quietly append using ashe_2003_numeric, keep($varlist sjob $varlist2)
	quietly append using ashe_2004_numeric, keep($varlist sjob $varlist2)
	quietly append using ashe_2005_numeric, keep($varlist sjob $varlist2)
	quietly append using ashe_2006_numeric, keep($varlist sjob $varlist2)
	quietly append using ashe_2007_numeric, keep($varlist sjob $varlist2)
	quietly append using ashe_2008_numeric, keep($varlist sjob $varlist2)
	* variable name change in ASHE
	rename sjob sjd
	rename occ03 occ
	quietly append using ashe_2009_numeric, keep($varlist sjd $varlist2)
	quietly append using ashe_2010_numeric, keep($varlist sjd $varlist2)
	rename occ occ00
	quietly append using ashe_2011_numeric, keep($varlist sjd $varlist2)
	quietly append using ashe_2012_numeric, keep($varlist sjd $varlist2)
	quietly append using ashe_2013_numeric, keep($varlist sjd $varlist2)
	quietly append using ashe_2014_numeric, keep($varlist sjd $varlist2)
	quietly append using ashe_2015_numeric, keep($varlist sjd $varlist2)
	quietly append using ashe_2016_numeric, keep($varlist sjd $varlist2)

	cd $created_datadir
	save ashe_panel_1997_2016.dta, replace
	
}

*** Create additional variables in the ASHE panel dataset (tenure, logpay),
*** adjust employment start dates (consistency), add the UK National Minimum Wage, 
*** convert SIC2007 to SIC2000, and impute consistent employment numbers (idbrnemp)
if $creation_variables==1{

	cd $created_datadir
	use ashe_panel_1997_2016.dta, clear

	* Set employment start date to missing if illegal date
	replace empsta=. if empsta==0 | year<=2002

	* Keep only main jobs - necessary for panel analysis of jobs ("same job" ambiguous otherwise)
	drop if year==2011 & djob==1 & mjob==0
	drop djob mjob
	xtset piden year
	
	* Impute the previous year's entref if sjd==1 and this year's entref is missing
	bysort piden (year): replace entref=L.entref if sjd==1 & entref==. & L.entref!=.

	/*
	Problems with EMPSTA:
	- EMPSTA later than April of the current year - illegal, set to missing
	- EMPSTA is a "one-off mistake", previous and next year have between them identical values, but this year differs
	- EMPSTA dates which are earlier than previous years' dates
	- Missing values even though EMPSTA in later years covers those missing obs
	*/

	* Create start date of employment spell
	g temp_month = int(empsta/10000)
	g temp_year = empsta - temp_month*10000
	g start=temp_year+temp_month/12
	g now = year+4/12
	drop empsta temp_month temp_year

	* Start date prior to adulthood - set to missing
	replace start=. if start<(year-age+15)

	* EMPSTA later than April of the current year - set to missing
	replace start=. if start>now

	* EMPSTA is "one-off" mistake (same start in next and previous year, as well as entref)
	* Inspection shows that discrepancy is usally just one month
	g asd=.
	bysort piden (year): replace asd=1 if L.start!=start & F.start!=start & L.start==F.start & L.entref==entref & F.entref==entref & entref!=. & start!=. & L.start!=. & F.start!=.
	bysort piden (year): replace asd=2 if asd==1 & (L.asd==1 | F.asd==1) | L.asd==2 | F.asd==2
	bysort piden (year): replace start=L.start if asd==1
	drop asd

	/*
	If an employee has been employed by a company for some time and returns after 
	a short break to that company, this employee has to be treated differently from 
	completly new employees who enter this company for the first time. Therefore,
	the following code uses the earliest start date with a company. A "returning" worker
	is not a new hire.
	*/
	g asd = .
	bysort piden (year): replace asd=1 if L.start!=start & F.start!=start & L.start==F.start & L.entref==entref & F.entref==entref & entref!=. & start!=. & L.start!=. & F.start!=.
	bysort piden (year): egen temp = min(start) if asd==1
	replace start=temp if asd==1
	drop asd temp

	* If a worker is continuously employed with the same firm and empsta is missing, then
	* impute the employment start date in those missing years if value is legal
	g asd=.
	bysort piden (year): replace asd=1 if year+1==year[_n+1] & sjd[_n+1]==1 & entref==entref[_n+1]
	bysort piden (year): replace asd=1 if year==year[_N] & sjd[_N]==1 & entref[_N]==entref[_N-1]
	sort piden entref asd
	by piden entref asd: egen min_start = min(start)
	sort piden year
	forvalue i = 1/10{
		by piden: replace min_start=min_start[_n+`i'] if min_start>min_start[_n+`i']
	}
	by piden: replace start=min_start if min_start<=now & start==.
	drop min_start asd

	* impute entref backwards based on employment start date
	g asd=.
	g qwe=.
	bysort piden (year): replace asd=1 if entref==. & start!=. & start==start[_n+1] & entref[_n+1]!=.
	bysort piden (year): replace qwe=entref[_n+1] if asd==1 
	forvalue i = 2/10{
		by piden: replace asd=`i' if asd[_n+1]==`i'-1
		by piden: replace qwe=qwe[_n+1] if asd==`i'
	}
	replace entref=qwe if qwe!=.
	drop asd qwe

	* Use luref within cross-section to impute missing entref. Only use unambiguous lurefs
	preserve
		drop if entref==.
		sort year luref
		by year luref: egen temp = count(luref)
		drop if temp<=1
		sort year luref entref
		egen tag = tag(year luref entref)
		replace tag=. if tag==0
		sort year luref
		by year luref: egen marker = count(tag)
		drop if marker!=1
		egen tag2 = tag(year luref)
		drop if tag2==0
		keep year luref entref
		cd $created_datadir
		save luref_temp.dta, replace
	restore
		
	quietly merge m:1 year luref using luref_temp.dta, update nogen keep(1 3 4 5) 
	erase luref_temp.dta

	drop if entref==. | sjd==.
	drop if start==. & year>2002

	* Convert various measures of collective coverage into indicator variable
	replace colag=1 if colag>1 & colag!=.

	/* create filter variable
	exclude those less than age 16, those with loss of pay through absence in reference period (April)
	also, keep only those age 64 or below filter observations with missing basic hours or pay
	*/

	capture drop filter
	* Mark obs employee age below 16y, earnings were affected by absence, employee received trainee/junior rate, and age is above 64y
	g filter = 1 if (age<16 | lop!=2 | adr==2 | age>64)
	* Mark observations where hours or pay data is missing or zero
	replace filter = 2 if hexo==. | gpox==. | bhr==. | hexo<=0 | gpox<=0 | bhr<=0
	* Mark problematic/unrealistic hours observations
	replace filter = 3 if  bhr>100 & bhr!=.
	replace filter = 4 if  bhr<1 
	replace filter = 5 if  thrs==. | thrs<0
	replace filter = 6 if  gpay==. | gpay<0
	drop if filter != .
	drop filter

	* Correct FT marker - improve consistency across years - all years perfectly mark full-time workers 
	* as those with over 30 basic hours, in a few years there are a few spurious / erroneous cases
	replace ft=1 if bhr>30 
	replace ft=0 if bhr<=30

	/* Import historical minimum wages
	Mark all observations with hourly rate excluding overtime below minimum wage (20% tolerance)
	Accounts partly also for some unrealistically large hours observations
	Source: Low Pay Commission, UK - accessed 30/5/2016
	Note, there are three UK rates (those on apprentice rates should be excluded by filter above)
	Age groups for rates change between 2009-2010
	Min. wage comes into force in October each year, other than April 99 - apply April 99 data to NES 99 observations 
	*/

	preserve
		cd $other_data
		import delimited nmw.csv, clear
		save nmw.dta, replace
	restore
	quietly merge m:1 year using nmw.dta, nogen

	replace hexo = hexo/100
	replace he = he/100

	capture drop below_min
	gen below_min = .
	replace below_min = 1 if (age>=16 & age<=17 & hexo< 0.8*nmw_1617 & year>=2004)
	replace below_min = 1 if (age>=18 & age<=21 & hexo< 0.8*nmw_dev & year>=1999 & year <=2009)
	replace below_min = 1 if (age>=18 & age<=20 & hexo< 0.8*nmw_dev & year>=2010)
	replace below_min = 1 if (age>=22 & hexo< 0.8*nmw_adult & year>=1999 & year <=2009)
	replace below_min = 1 if (age>=21 & hexo< 0.8*nmw_adult & year>=2010)
	replace below_min = 1 if (age>=25 & hexo< 0.8*nmw_25 & year>=2016)

	drop if below_min == 1
	drop nmw_dev nmw_1617 nmw_adult nmw_25 below_min

	* Import price deflator index = 100 in 2002
	preserve
		cd $other_data
		import delimited RPI.csv, clear
		label variable rpi "RPI Index (base 2002 = 100)"
		drop if year<1997
		save RPI.dta, replace
	restore
	quietly merge m:1 year using RPI.dta, nogen

	preserve
		cd $other_data
		import delimited CPI.csv, clear
		label variable cpi "CPI Index (base 2002 = 100)"
		drop if year<1997
		save CPI.dta, replace
	restore
	quietly merge m:1 year using CPI.dta, nogen

	 
	*Deflate monetary values - 2002 prices
	foreach i in gpay gpox hexo he{
		replace `i' = . if `i'==0
	}

	* Generate real earnings variables in logs
	foreach k in cpi rpi{
		g logwage_`k' = ln(hexo*(100/`k')) if hexo>0 
		g logearnings_`k' = ln(gpox*(100/`k')) if gpox>0
		g logpay_`k'= ln(gpay*(100/`k')) if gpay>0
		g logpayrate_`k'= ln(he*(100/`k')) if he>0
		label variable logwage_`k' "Log of real hourly wage, excl overtime `k'"
		label variable logearnings_`k' "Log of gross weekly earnings, excl overtime `k'"
		label variable logpay_`k' "Log of gross weekly earnings, incl overtime, bonuses etc `k'"
		label variable logpayrate_`k' "Log of real hourly wage, incl overtime, bonuses etc `k'"
	}
	
	g loghours = ln(bhr) if bhr>0
	g logthrs  = ln(thrs) if thrs>0
	label variable loghours "Log of weekly hours, excluding overtime"
	label variable logthrs "Log of weekly hours, incl overtime"

	/* SIC 2007 - conversion to 2003

	Details of crosswalk:

	File name:  			converting sic2007 to sic2003
	Version:			    01.00
	Format:					Stata
	]-= and SPSS
	Created by:				Professor Richard Harris, University of Durham
	Date created:			31st OCtober 2011
	Released to References drive:	27th March 2014
	Contact for info:		Richard Welpton, Secure Lab Manager (rwelpton@essex.ac.uk)


	**INFORMATION**

	This conversion file was created by Professor Richard Harris, and kindly offered to the Secure Lab community.

	The file was created by using the 2008 ARD data which contains both codes.

	Cases occur where a given SIC2003 classification is now disaggregated into a number of SIC2007 codes.  As researchers work longitudinally with the data, Richard created mappings to allow researchers to apply the SIC2003 codes to observations with SIC2007 classifications.

	For example, SIC2003 classification 1110 is now disaggregated into SIC2007 codes 1110, 1120, 1140, 1150, 1160 etc.

	Richard mapped the SIC2007 codes to previous SIC2003 codes on the basis of gross output (not employment).  For example, if a given SIC2003 code was assigned two new SIC2007 codes, Richard mapped the SIC2007 to the SIC2003 for which ever of the two SIC2007 coded-industries bore the greater share of economic output (based on gross output data from the ARD).

	*/

	preserve
		use "R:\Classifications\ONS SICs and SOCs\SIC2003_SIC2007_conversions\Derived by Richard Harris_v01_00\converting SIC2007 to sic2003.dta", clear
		rename SIC07 sic07
		sort sic07
		cd $other_data
		save sic_conversion.dta, replace
	restore

	sort sic07
	quietly merge m:1 sic07 using sic_conversion.dta, nogen keepusing(SIC2003) keep(1 3 4 5)
	replace sic03 = SIC2003 if sic03==. & sic07!=.
	drop SIC2003 sic07
	rename sic03 sic

	* Standardise the various names for SOC00 across different years
	capture drop soc00_4d
	gen soc00_4d = .
	replace soc00_4d = occ00 if year<2012
	rename occ10 soc10_4d
	drop occ00 occ90

	* Generate markers for top 1% of wage or earnings distribution
	foreach i in logwage_cpi logearnings_cpi{
		sort year
		by year: egen `i'x_99 = pctile(`i'), p(99)
		g `i'_99 = 1 if `i'>=`i'x_99 & `i'!=.
		capture drop `i'x_99
	}

	g tenure = now - start
	label variable tenure "Tenure with firm in years"

	* Compute the number of years where a firm is present in the dataset
	sort entref year
	by entref: egen firm_end=max(year) if year>=2003
	by entref: egen firm_start=min(year) if year>=2003
	gen firm_life=firm_end-firm_start+1
	label variable firm_life "Time that firm exists in dataset 2003-2016"

	/*
	Some ENTREF have multiple entries for IDBRNEMP within year;
	For year>=2003, wcoa is an indicator for varying idrbnemp, prior to 2003, no marker is available.
	*/

	* Create marker for missing obs of wcoa (worker census output area), YEAR>=2003
	g marker = .
	replace marker = 1 if wcoa == "" & year>=2003

	sort year entref
	by year entref: egen num = count(marker) if year>=2003
	replace num = 1 if num>=1 & year>=2003

	g idbrnemp2 = idbrnemp if num==1
	sort year entref
	by year entref: egen mod = mode(idbrnemp2), maxmode

	replace idbrnemp = mod if num==1 & year>=2003
	drop num marker mod wcoa idbrnemp2

	* Pre 2002, wcoa is not available as a marker. Use the modal value of idbrnemp
	sort year entref idbrnemp
	by year entref idbrnemp: gen temp = _n if year<=2002
	sort year entref
	by year entref: gen temp2 = _n if year<=2002
	gen diff = temp-temp2 if year<=2002
	replace diff=. if diff==0 & year<=2002
	by year entref: egen temp3 = count(diff) if year<=2002
	by year entref: egen mod = mode(idbrnemp) if year<=2002 & temp3!=0
	by year entref: egen med = median(idbrnemp) if year<=2002
	replace mod = med if year<=2002 & mod==.

	replace idbrnemp = mod if year<=2002 & temp3!=0 
	drop temp temp2 temp3 diff mod med
	
	cd $created_datadir
	save ashe_1997_2016, replace

	drop if year<=2002
	save ashe_2003_2016, replace

	* create chain volume measure of productivity in stata format
	preserve
		cd $other_data
		import excel using cvm_industries, clear sheet("stata") firstrow
		rename time sic
		quiet reshape long year, i(sic) j(asd)
		rename year cvm
		rename asd year
		save cvm_index.dta, replace
	restore
	
	* Service sector producer price index
	preserve
		cd $other_data
		import delimited SPPI.csv, clear
		g asd = sppi[6]
		replace sppi = sppi/asd*100
		drop asd
		label variable sppi "SPPI Index (base 2002 = 100)"
		drop if year<1997
		save SPPI.dta, replace
	restore
	
	* Time series of unemployment and labour productivity
	preserve
		cd $other_data
		import delimited econ.csv, clear
		quiet merge 1:1 year using CPI, nogen
		quiet merge 1:1 year using SPPI, nogen
		gen log_prod_gdp = ln(prod_gdp*sppi/cpi)
		gen log_prod_ser = ln(prod_ser*sppi/cpi)
		drop cpi prod* sppi
		cd $other_data
		save econ.dta, replace
	restore
	
}

*** Create the baseline sample which is used for the main analysis (Table 3, Row 1, 2, 5, 6)
if $create_baseline==1{

	/*
	The sample of entry-level jobs is first defined in 2003-2016, and subsequently
	new hires in those jobs during 1997-2002 are identified.
	*/
	
	cd $created_datadir
	use ashe_2003_2016, clear
	
	global min_hires 	= 3		// Min number of hires per firm-occ-year
	global max_tenure	= 1		// Max years of tenure to be considered a new hire
	global min_life		= 3		// Min years firm is required to exist
	global soc_digits	= "4d"	// Digits in the occupations coding that define a job within firms
	global min_time_pc  = 0.5	// Min percent of years of firm being present in dataset, when a job has to fulfil conditions above to be in baseline sample
	
	* Create marker for a new hire into firm
	g entry = .
	replace entry = 1 if tenure<=$max_tenure & tenure!=.
	label variable entry "Indicator for new hire"

	* Drop firms which are not observed sufficiently often
	drop if firm_life<$min_life

	***************************************************************************
	*** Conversion of SOC10 and SOC00 into a time-consistent classification ***
	***************************************************************************
	
	/*
	Create conversion of SOC10 into SOC00 to identify entry-jobs across all years. 
	Use ASHE2011 which is available in SOC00 and SOC11 to match occupations within firms. 
	Use entry jobs for matching first, since this is the most important conversion.
	Basic idea: We only require consistence of SOC00-SOC10 conversion WITHIN a firm, NOT across firms.
	*/

	* Entry one-to-one mappings
	preserve
		keep if year==2011 & entry==1
		keep entref soc00_$soc_digits soc10_$soc_digits

		* WITHIN firm, identify 1-1 match between SOC10 and SOC00 for new hires
		sort entref soc10_$soc_digits soc00_$soc_digits
		by entref soc10_$soc_digits : gen temp = _n == 1
		egen tag = tag(entref soc10_$soc_digits soc00_$soc_digits)
		g diff = .
		replace diff=1 if temp!=tag
		by entref soc10_$soc_digits : egen ind = count(diff)

		drop if tag==0 
		drop if ind!=0
		drop diff ind tag temp

		sort entref soc10_$soc_digits soc00_$soc_digits
		cd $created_datadir
		save soc10_to_soc00_entry.dta, replace
	restore

	* All other within-firm one-to-one mappings
	preserve
		keep if year==2011 & entry!=1
		keep entref soc00_$soc_digits soc10_$soc_digits
		
		* WITHIN firm, identify 1-1 match between SOC10 and SOC00 for non-new hires
		sort entref soc10_$soc_digits soc00_$soc_digits
		by entref soc10_$soc_digits : gen temp = _n == 1
		egen tag = tag(entref soc10_$soc_digits soc00_$soc_digits)
		g diff = .
		replace diff=1 if temp!=tag
		by entref soc10_$soc_digits : egen ind = count(diff)

		drop if tag==0 
		drop if ind!=0
		drop diff ind tag temp

		sort entref soc10_$soc_digits soc00_$soc_digits
		cd $created_datadir
		save soc10_to_soc00_all.dta, replace
	restore

	/*
	First, match only entry job-occ. Then, missing values can be filled with company-wide occ correspondence.
	This second step is important for companies without matches in 2011, but who still have consistent soc00-soc10 matching.
	*/

	* Merge created conversion files in. Create WITHIN firm the SOC00 code corresponding to SOC10
	sort entref soc10_$soc_digits soc00_$soc_digits
	quiet merge m:1 entref soc10_$soc_digits using soc10_to_soc00_entry, nogen update
	quiet merge m:1 entref soc10_$soc_digits using soc10_to_soc00_all, nogen update
	erase soc10_to_soc00_entry.dta
	erase soc10_to_soc00_all.dta
	
	/* 
	For the remaining jobs, use cross-walks to convert occupations into a unified classification.
	First, convert SOC00 to ISCO88, then convert SOC10 into ISCO08, then cross-walk ISCO08 to ISCO88.
	*/

	* SOC00 to ISCO88. This mapping produced by Paul Lambert via OIU index file. Last updated 6.5.2005.

	recode soc00_4d (1111 = 1110)  (1112 = 1210)  (1113 = 1110)  (1114 = 1140)  (1121 = 1222)  (1122 = 1223)  (1123 = 1222)  (1131 = 1231)  (1132 = 1233)  (1133 = 1235)  (1134 = 1234)  (1135 = 1232)  (1136 = 1236)  (1137 = 1237)  (1141 = 1239)  (1142 = 1239)  (1151 = 1227)  (1152 = 1231)  (1161 = 1226)  (1162 = 1226)  (1163 = 1224)  (1171 = 100)  (1172 = 3450)  (1173 = 1229)  (1174 = 1239)  (1181 = 1229)  (1182 = 1319)  (1183 = 1319)  (1184 = 1229)  (1185 = 1318)  (1211 = 1311)  (1212 = 1311)  (1219 = 1311)  (1221 = 1315)  (1222 = 1227)  (1223 = 1315)  (1224 = 1315)  (1225 = 1319)  (1226 = 1316)  (1231 = 1317)  (1232 = 1314)  (1233 = 1318)  (1234 = 1314)  (1235 = 1319)  (1239 = 1319)  (2111 = 2113)  (2112 = 2211)  (2113 = 2110)  (2121 = 2142)  (2122 = 2145)  (2123 = 2143)  (2124 = 2144)  (2125 = 2146)  (2126 = 2149)  (2127 = 2149)  (2128 = 2149)  (2129 = 2149)  (2131 = 2130)  (2132 = 2130)  (2211 = 2221)  (2212 = 2445)  (2213 = 2224)  (2214 = 2229)  (2215 = 2222)  (2216 = 2223)  (2311 = 2310)  (2312 = 2310)  (2313 = 2352)  (2314 = 2320)  (2315 = 2330)  (2316 = 2340)  (2317 = 2359)  (2319 = 2359)  (2321 = 2110)  (2322 = 2440)  (2329 = 2310)  (2411 = 2420)  (2419 = 2429)  (2421 = 2411)  (2422 = 2411)  (2423 = 2419)  (2431 = 2141)  (2432 = 2141)  (2433 = 2148)  (2434 = 2148)  (2441 = 2470)  (2442 = 2446)  (2443 = 2446)  (2444 = 2460)  (2451 = 2432)  (2452 = 2431)  (3111 = 3111)  (3112 = 3114)  (3113 = 3110)  (3114 = 3112)  (3115 = 3119)  (3119 = 3119)  (3121 = 3119)  (3122 = 3118)  (3123 = 3151)  (3131 = 3120)  (3132 = 3120)  (3211 = 3231)  (3212 = 3232)  (3213 = 3221)  (3214 = 3133)  (3215 = 3226)  (3216 = 3224)  (3217 = 3228)  (3218 = 3220)  (3221 = 3226)  (3222 = 3226)  (3223 = 3226)  (3229 = 3226)  (3231 = 3460)  (3232 = 3460)  (3311 = 100)  (3312 = 5162)  (3313 = 5161)  (3314 = 5163)  (3319 = 5169)  (3411 = 2452)  (3412 = 2451)  (3413 = 3470)  (3414 = 3473)  (3415 = 3473)  (3416 = 2455)  (3421 = 3471)  (3422 = 3471)  (3431 = 2451)  (3432 = 3472)  (3433 = 3419)  (3434 = 3131)  (3441 = 3475)  (3442 = 3475)  (3443 = 3475)  (3449 = 3475)  (3511 = 3144)  (3512 = 3143)  (3513 = 3142)  (3514 = 8311)  (3520 = 3432)  (3531 = 3417)  (3532 = 3411)  (3533 = 3412)  (3534 = 3419)  (3535 = 3442)  (3536 = 3422)  (3537 = 3433)  (3539 = 3419)  (3541 = 3416)  (3542 = 3415)  (3543 = 3419)  (3544 = 3413)  (3551 = 3210)  (3552 = 3210)  (3561 = 3449)  (3562 = 2412)  (3563 = 3340)  (3564 = 2412)  (3565 = 3152)  (3566 = 3152)  (3567 = 3152)  (3568 = 3152)  (4111 = 4190)  (4112 = 4190)  (4113 = 4190)  (4114 = 4190)  (4121 = 4120)  (4122 = 4120)  (4123 = 4210)  (4131 = 4141)  (4132 = 4190)  (4133 = 4131)  (4134 = 4133)  (4135 = 4141)  (4136 = 4113)  (4137 = 4190)  (4141 = 4223)  (4142 = 4223)  (4150 = 4190)  (4211 = 4115)  (4212 = 4115)  (4213 = 4115)  (4214 = 4115)  (4215 = 4115)  (4216 = 4222)  (4217 = 4110)  (5111 = 6130)  (5112 = 6112)  (5113 = 6112)  (5119 = 6150)  (5211 = 7221)  (5212 = 7211)  (5213 = 7213)  (5214 = 7214)  (5215 = 7212)  (5216 = 7136)  (5221 = 7223)  (5222 = 7222)  (5223 = 7230)  (5224 = 7311)  (5231 = 7231)  (5232 = 7213)  (5233 = 7241)  (5234 = 7141)  (5241 = 7137)  (5242 = 7244)  (5243 = 7245)  (5244 = 7242)  (5245 = 7242)  (5249 = 7242)  (5311 = 7214)  (5312 = 7122)  (5313 = 7131)  (5314 = 7136)  (5315 = 7124)  (5316 = 7135)  (5319 = 7121)  (5321 = 7133)  (5322 = 7132)  (5323 = 7141)  (5411 = 7432)  (5412 = 7437)  (5413 = 7442)  (5414 = 7433)  (5419 = 7430)  (5421 = 7341)  (5422 = 7341)  (5423 = 7345)  (5424 = 7346)  (5431 = 7411)  (5432 = 7412)  (5433 = 7411)  (5434 = 5122)  (5491 = 7320)  (5492 = 7422)  (5493 = 7422)  (5494 = 7312)  (5495 = 7313)  (5496 = 3471)  (5499 = 7330)  (6111 = 5132)  (6112 = 5132)  (6113 = 5132)  (6114 = 5132)  (6115 = 5133)  (6121 = 5131)  (6122 = 5131)  (6123 = 5131)  (6124 = 5131)  (6131 = 3227)  (6139 = 3227)  (6211 = 5149)  (6212 = 4221)  (6213 = 5113)  (6214 = 5111)  (6215 = 5112)  (6219 = 5110)  (6221 = 5141)  (6222 = 5141)  (6231 = 5121)  (6232 = 9141)  (6291 = 5143)  (6292 = 7143)  (7111 = 5220)  (7112 = 5220)  (7113 = 9113)  (7121 = 9113)  (7122 = 9153)  (7123 = 9113)  (7124 = 5220)  (7125 = 3471)  (7129 = 3415)  (7211 = 4220)  (7212 = 4220)  (8111 = 8270)  (8112 = 8130)  (8113 = 8260)  (8114 = 8150)  (8115 = 8231)  (8116 = 8232)  (8117 = 8120)  (8118 = 8223)  (8119 = 8100)  (8121 = 8140)  (8122 = 8111)  (8123 = 8112)  (8124 = 8160)  (8125 = 8211)  (8126 = 8163)  (8129 = 8290)  (8131 = 8282)  (8132 = 8281)  (8133 = 8290)  (8134 = 8290)  (8135 = 7231)  (8136 = 8269)  (8137 = 8263)  (8138 = 8290)  (8139 = 8290)  (8141 = 7129)  (8142 = 9312)  (8143 = 9312)  (8149 = 9313)  (8211 = 8324)  (8212 = 8322)  (8213 = 8323)  (8214 = 8322)  (8215 = 3340)  (8216 = 8312)  (8217 = 8340)  (8218 = 9330)  (8219 = 9330)  (8221 = 8333)  (8222 = 8334)  (8223 = 8331)  (8229 = 8330)  (9111 = 9211)  (9112 = 9212)  (9119 = 9210)  (9121 = 9313)  (9129 = 9312)  (9131 = 9320)  (9132 = 9132)  (9133 = 9320)  (9134 = 9320)  (9139 = 9320)  (9141 = 9330)  (9149 = 9330)  (9211 = 9151)  (9219 = 9151)  (9221 = 9132)  (9222 = 9150)  (9223 = 9132)  (9224 = 5123)  (9225 = 5123)  (9226 = 9152)  (9229 = 9150)  (9231 = 9142)  (9232 = 9162)  (9233 = 9130)  (9234 = 9133)  (9235 = 9161)  (9239 = 9162)  (9241 = 9152)  (9242 = 5169)  (9243 = 9152)  (9244 = 5131)  (9245 = 9152)  (9249 = 9152)  (9251 = 5220)  (9259 = 9151) (nonmissing = 10000), gen(isco88_00)

	* SOC10 to ISCO88 (SOC10 to ISCO08 to ISCO88)
	* Sources: SOC10 to ISCO08, ONS: https://www.ons.gov.uk/file?uri=/methodology/classificationsandstandards/standardoccupationalclassificationssoc/soc10/ug201002soc2010toisco08v2_tcm77-283163.xls
	* Sources: ISCO08 to ISCO88, www.ilo.org/public/english/bureau/stat/isco/docs/corrtab88-08.xls
	preserve
		cd $other_data
		import delimited isco08.csv, clear
		sort occ10
		drop if occ10 == .
		rename occ10 soc10_4d
		save isco08.dta, replace
	restore

	sort soc10_4d
	quietly merge m:1 soc10_4d using isco08.dta, nogen keepusing(isco88_10) 

	g isco88_4d = .
	replace isco88_4d = isco88_00
	replace isco88_4d = isco88_10 if isco88_4d==.
	drop isco88_00 isco88_10
	drop soc*

	* Generate number of new entries for each year by occupation x firm.
	sort entref year isco88_$soc_digits 
	bysort entref year isco88_$soc_digits : egen hires_occ = count(piden) if entry==1
	
	* Save the data at this point to create different versions for robustness checks later
	cd $created_datadir
	save data_before_min_hires.dta, replace
	
	/*
	Generate the total number for all years when an occupation accounted for 
	at least $min_hire new hires of all new hires within a year for a given firm.
	*/
	sort entref isco88_$soc_digits year
	egen temp = tag(entref isco88_$soc_digits year) if hires_occ>=$min_hires & entry==1
	bysort entref isco88_$soc_digits: egen rel_years = sum(temp) if entry==1
	drop hires_occ temp

	* Include in baseline sample if relevant criteria are fulfiled for a certain percentage
	* of the years the firms exists.
	g poe=.
	replace poe=1 if (rel_years/firm_life)>=$min_time_pc & rel_years!=.
	label variable poe "Newly hired employee in POE job"
	drop rel_years

	* Create marker when a firm is in the poe sample
	sort entref
	bysort entref: egen poe_firm=sum(poe)
	replace poe_firm=1 if poe_firm>=1
	label variable poe_firm "Firm which is hiring through POE jobs"

	sort entref isco88_$soc_digits
	bysort entref isco88_$soc_digits: egen poe_job=sum(poe)
	replace poe_job=1 if poe_job>=1
	label variable poe_job "POE job"

	* Identify firms prior to 2003 as POE firms based on 2003-2016 sample
	preserve
		keep entref poe_firm
		drop if poe_firm==0

		sort entref
		egen tag = tag(entref)
		drop if tag==0
		drop tag
		cd $other_data
		save temp1.dta, replace
		
		* Merge the poe_firm marker into 1997-2002 data
		cd $created_datadir
		use * if (year<=2002 & entref!=.) using ashe_1997_2016.dta, clear
		cd $other_data
		quietly merge m:1 entref using temp1, nogen keep(1 3 4 5)
		
		* SOC10 and SOC00 conversion as above
		recode soc00_4d (1111 = 1110)  (1112 = 1210)  (1113 = 1110)  (1114 = 1140)  (1121 = 1222)  (1122 = 1223)  (1123 = 1222)  (1131 = 1231)  (1132 = 1233)  (1133 = 1235)  (1134 = 1234)  (1135 = 1232)  (1136 = 1236)  (1137 = 1237)  (1141 = 1239)  (1142 = 1239)  (1151 = 1227)  (1152 = 1231)  (1161 = 1226)  (1162 = 1226)  (1163 = 1224)  (1171 = 100)  (1172 = 3450)  (1173 = 1229)  (1174 = 1239)  (1181 = 1229)  (1182 = 1319)  (1183 = 1319)  (1184 = 1229)  (1185 = 1318)  (1211 = 1311)  (1212 = 1311)  (1219 = 1311)  (1221 = 1315)  (1222 = 1227)  (1223 = 1315)  (1224 = 1315)  (1225 = 1319)  (1226 = 1316)  (1231 = 1317)  (1232 = 1314)  (1233 = 1318)  (1234 = 1314)  (1235 = 1319)  (1239 = 1319)  (2111 = 2113)  (2112 = 2211)  (2113 = 2110)  (2121 = 2142)  (2122 = 2145)  (2123 = 2143)  (2124 = 2144)  (2125 = 2146)  (2126 = 2149)  (2127 = 2149)  (2128 = 2149)  (2129 = 2149)  (2131 = 2130)  (2132 = 2130)  (2211 = 2221)  (2212 = 2445)  (2213 = 2224)  (2214 = 2229)  (2215 = 2222)  (2216 = 2223)  (2311 = 2310)  (2312 = 2310)  (2313 = 2352)  (2314 = 2320)  (2315 = 2330)  (2316 = 2340)  (2317 = 2359)  (2319 = 2359)  (2321 = 2110)  (2322 = 2440)  (2329 = 2310)  (2411 = 2420)  (2419 = 2429)  (2421 = 2411)  (2422 = 2411)  (2423 = 2419)  (2431 = 2141)  (2432 = 2141)  (2433 = 2148)  (2434 = 2148)  (2441 = 2470)  (2442 = 2446)  (2443 = 2446)  (2444 = 2460)  (2451 = 2432)  (2452 = 2431)  (3111 = 3111)  (3112 = 3114)  (3113 = 3110)  (3114 = 3112)  (3115 = 3119)  (3119 = 3119)  (3121 = 3119)  (3122 = 3118)  (3123 = 3151)  (3131 = 3120)  (3132 = 3120)  (3211 = 3231)  (3212 = 3232)  (3213 = 3221)  (3214 = 3133)  (3215 = 3226)  (3216 = 3224)  (3217 = 3228)  (3218 = 3220)  (3221 = 3226)  (3222 = 3226)  (3223 = 3226)  (3229 = 3226)  (3231 = 3460)  (3232 = 3460)  (3311 = 100)  (3312 = 5162)  (3313 = 5161)  (3314 = 5163)  (3319 = 5169)  (3411 = 2452)  (3412 = 2451)  (3413 = 3470)  (3414 = 3473)  (3415 = 3473)  (3416 = 2455)  (3421 = 3471)  (3422 = 3471)  (3431 = 2451)  (3432 = 3472)  (3433 = 3419)  (3434 = 3131)  (3441 = 3475)  (3442 = 3475)  (3443 = 3475)  (3449 = 3475)  (3511 = 3144)  (3512 = 3143)  (3513 = 3142)  (3514 = 8311)  (3520 = 3432)  (3531 = 3417)  (3532 = 3411)  (3533 = 3412)  (3534 = 3419)  (3535 = 3442)  (3536 = 3422)  (3537 = 3433)  (3539 = 3419)  (3541 = 3416)  (3542 = 3415)  (3543 = 3419)  (3544 = 3413)  (3551 = 3210)  (3552 = 3210)  (3561 = 3449)  (3562 = 2412)  (3563 = 3340)  (3564 = 2412)  (3565 = 3152)  (3566 = 3152)  (3567 = 3152)  (3568 = 3152)  (4111 = 4190)  (4112 = 4190)  (4113 = 4190)  (4114 = 4190)  (4121 = 4120)  (4122 = 4120)  (4123 = 4210)  (4131 = 4141)  (4132 = 4190)  (4133 = 4131)  (4134 = 4133)  (4135 = 4141)  (4136 = 4113)  (4137 = 4190)  (4141 = 4223)  (4142 = 4223)  (4150 = 4190)  (4211 = 4115)  (4212 = 4115)  (4213 = 4115)  (4214 = 4115)  (4215 = 4115)  (4216 = 4222)  (4217 = 4110)  (5111 = 6130)  (5112 = 6112)  (5113 = 6112)  (5119 = 6150)  (5211 = 7221)  (5212 = 7211)  (5213 = 7213)  (5214 = 7214)  (5215 = 7212)  (5216 = 7136)  (5221 = 7223)  (5222 = 7222)  (5223 = 7230)  (5224 = 7311)  (5231 = 7231)  (5232 = 7213)  (5233 = 7241)  (5234 = 7141)  (5241 = 7137)  (5242 = 7244)  (5243 = 7245)  (5244 = 7242)  (5245 = 7242)  (5249 = 7242)  (5311 = 7214)  (5312 = 7122)  (5313 = 7131)  (5314 = 7136)  (5315 = 7124)  (5316 = 7135)  (5319 = 7121)  (5321 = 7133)  (5322 = 7132)  (5323 = 7141)  (5411 = 7432)  (5412 = 7437)  (5413 = 7442)  (5414 = 7433)  (5419 = 7430)  (5421 = 7341)  (5422 = 7341)  (5423 = 7345)  (5424 = 7346)  (5431 = 7411)  (5432 = 7412)  (5433 = 7411)  (5434 = 5122)  (5491 = 7320)  (5492 = 7422)  (5493 = 7422)  (5494 = 7312)  (5495 = 7313)  (5496 = 3471)  (5499 = 7330)  (6111 = 5132)  (6112 = 5132)  (6113 = 5132)  (6114 = 5132)  (6115 = 5133)  (6121 = 5131)  (6122 = 5131)  (6123 = 5131)  (6124 = 5131)  (6131 = 3227)  (6139 = 3227)  (6211 = 5149)  (6212 = 4221)  (6213 = 5113)  (6214 = 5111)  (6215 = 5112)  (6219 = 5110)  (6221 = 5141)  (6222 = 5141)  (6231 = 5121)  (6232 = 9141)  (6291 = 5143)  (6292 = 7143)  (7111 = 5220)  (7112 = 5220)  (7113 = 9113)  (7121 = 9113)  (7122 = 9153)  (7123 = 9113)  (7124 = 5220)  (7125 = 3471)  (7129 = 3415)  (7211 = 4220)  (7212 = 4220)  (8111 = 8270)  (8112 = 8130)  (8113 = 8260)  (8114 = 8150)  (8115 = 8231)  (8116 = 8232)  (8117 = 8120)  (8118 = 8223)  (8119 = 8100)  (8121 = 8140)  (8122 = 8111)  (8123 = 8112)  (8124 = 8160)  (8125 = 8211)  (8126 = 8163)  (8129 = 8290)  (8131 = 8282)  (8132 = 8281)  (8133 = 8290)  (8134 = 8290)  (8135 = 7231)  (8136 = 8269)  (8137 = 8263)  (8138 = 8290)  (8139 = 8290)  (8141 = 7129)  (8142 = 9312)  (8143 = 9312)  (8149 = 9313)  (8211 = 8324)  (8212 = 8322)  (8213 = 8323)  (8214 = 8322)  (8215 = 3340)  (8216 = 8312)  (8217 = 8340)  (8218 = 9330)  (8219 = 9330)  (8221 = 8333)  (8222 = 8334)  (8223 = 8331)  (8229 = 8330)  (9111 = 9211)  (9112 = 9212)  (9119 = 9210)  (9121 = 9313)  (9129 = 9312)  (9131 = 9320)  (9132 = 9132)  (9133 = 9320)  (9134 = 9320)  (9139 = 9320)  (9141 = 9330)  (9149 = 9330)  (9211 = 9151)  (9219 = 9151)  (9221 = 9132)  (9222 = 9150)  (9223 = 9132)  (9224 = 5123)  (9225 = 5123)  (9226 = 9152)  (9229 = 9150)  (9231 = 9142)  (9232 = 9162)  (9233 = 9130)  (9234 = 9133)  (9235 = 9161)  (9239 = 9162)  (9241 = 9152)  (9242 = 5169)  (9243 = 9152)  (9244 = 5131)  (9245 = 9152)  (9249 = 9152)  (9251 = 5220)  (9259 = 9151) (nonmissing = 10000), gen(isco88_4d)
		drop soc*
		cd $other_data
		save temp2.dta, replace 
	restore

	* Append 2003-2016 dataset with poe_firms 1997-2002
	append using temp2.dta
	erase temp1.dta
	erase temp2.dta

	* Extract poe jobs from 2003-2016 sample to impute poe jobs <2003
	preserve
		keep year isco88_4d entref poe_job
		drop if year<2003
		capture drop tag
		egen tag = tag(entref isco88_4d) if poe_job==1
		drop if tag==0
		drop tag year
		cd $other_data
		save temp_poe.dta, replace
	restore

	* Identify POE jobs and new hires into those jobs over the years 1997-2002
	sort entref isco88_$soc_digits
	quietly merge m:1 entref isco88_$soc_digits using temp_poe, nogen update keepusing(poe_job)
	replace entry = 1 if tenure<=$max_tenure & year<2003
	replace poe   = 1 if poe_job==1 & year<2003 & sjd==2
	erase temp_poe.dta

	* express tenure in years and impute missing obs for new poe hires with 0
	replace tenure=floor(tenure)
	replace tenure=0 if poe==1

	* Drop top 1% of income earners
	drop if logwage_cpi_99==1 | logearnings_cpi_99==1
	drop logwage_cpi_99 logearnings_cpi_99

	keep log* sex age tenure poe* colag ft idbr* sjd wgor he* gp*/*
	*/   entry year isco88_$soc_digits firm_start entref sic piden start now

	drop if wgor==0 | wgor==.
	
	* Job id (unique across years)
	sort entref isco88_$soc_digits
	egen jobid = group(entref isco88_$soc_digits)
	label variable jobid "Job ID"

	* drop missing or not classified sectoral codes
	drop if idbrsta==0 | idbrsta==8 | idbrsta==.  

	preserve
		*** Generate fraction of poe jobs per year of total poe jobs - weights for robustness
		* Keep only private enterprises
		drop if poe_firm!=1
		keep if idbrsta==1 | idbrsta==2 | idbrsta==3
		egen tag = tag(jobid year)
		drop if tag!=1
		sort year
		by year: egen num = count(tag)
		egen tot = count(tag)
		gen weight = num/tot
		egen tag2= tag(weight year)
		drop if tag2!=1
		drop if year==1997
		keep year weight
		cd $created_datadir
		save poe_year_weights.dta, replace
	restore
	
	* Save data
	preserve 
		drop if poe_firm!=1
		cd $created_datadir
		save slim_1997_2016.dta, replace
	restore

	preserve
		drop if year <=2002
		drop if poe_firm!=1
		cd $created_datadir
		save slim_2003_2016.dta, replace
	restore

	cd $created_datadir
	save slim_1997_2016_all.dta, replace

	drop if year <=2002
	cd $created_datadir
	save slim_2003_2016_all.dta, replace
	
}

*** Table 3, Row 3 dataset. REQUIRES that baseline sample creation code has been run previously
if $create_row3_data==1{
	
	*** Adjust variables accordingly to creat different sample based on selection criteria ***
	
	global min_hires 	= 3		// Min number of hires per firm-occ-year
	global max_tenure	= 1		// Max years of tenure to be considered a new hire (years)
	global soc_digits	= "4d"	// Digits in the occupations coding that define a job within firms
	
	* Changed (baseline was 3)
	global min_life		= 5		// Min years firm is required to exist
	
	* Changed (baseline was 0.5)
	global min_time_pc  = 0.25	// Min percent of years of firm being present in dataset, when a job has to fulfil conditions above to be in baseline sample
	
	* THIS DATASET HAS BEEN CREATED WHEN "BASELINE SAMPLE" WAS CREATED *
	cd $created_datadir
	use data_before_min_hires.dta, clear

	* The following code is identical to "Baseline Creation", 
	* explanations of the code can be found there.
	
	drop if firm_life<$min_life

	sort entref isco88_$soc_digits year
	egen temp = tag(entref isco88_$soc_digits year) if hires_occ>=$min_hires & entry==1
	bysort entref isco88_$soc_digits: egen rel_years = sum(temp) if entry==1
	drop hires_occ temp

	g poe=.
	replace poe=1 if (rel_years/firm_life)>=$min_time_pc & rel_years!=.
	label variable poe "Newly hired employee in POE job"
	drop rel_years

	sort entref
	bysort entref: egen poe_firm=sum(poe)
	replace poe_firm=1 if poe_firm>=1
	label variable poe_firm "Firm which is hiring through POE jobs"

	sort entref isco88_$soc_digits
	bysort entref isco88_$soc_digits: egen poe_job=sum(poe)
	replace poe_job=1 if poe_job>=1
	label variable poe_job "POE job"

	preserve
		keep entref poe_firm
		drop if poe_firm==0

		sort entref
		egen tag = tag(entref)
		drop if tag==0
		drop tag
		cd $other_data
		save temp1.dta, replace
		
		cd $created_datadir
		use * if (year<=2002 & entref!=.) using ashe_1997_2016.dta, clear
		cd $other_data
		quietly merge m:1 entref using temp1, nogen keep(1 3 4 5)
		
		recode soc00_4d (1111 = 1110)  (1112 = 1210)  (1113 = 1110)  (1114 = 1140)  (1121 = 1222)  (1122 = 1223)  (1123 = 1222)  (1131 = 1231)  (1132 = 1233)  (1133 = 1235)  (1134 = 1234)  (1135 = 1232)  (1136 = 1236)  (1137 = 1237)  (1141 = 1239)  (1142 = 1239)  (1151 = 1227)  (1152 = 1231)  (1161 = 1226)  (1162 = 1226)  (1163 = 1224)  (1171 = 100)  (1172 = 3450)  (1173 = 1229)  (1174 = 1239)  (1181 = 1229)  (1182 = 1319)  (1183 = 1319)  (1184 = 1229)  (1185 = 1318)  (1211 = 1311)  (1212 = 1311)  (1219 = 1311)  (1221 = 1315)  (1222 = 1227)  (1223 = 1315)  (1224 = 1315)  (1225 = 1319)  (1226 = 1316)  (1231 = 1317)  (1232 = 1314)  (1233 = 1318)  (1234 = 1314)  (1235 = 1319)  (1239 = 1319)  (2111 = 2113)  (2112 = 2211)  (2113 = 2110)  (2121 = 2142)  (2122 = 2145)  (2123 = 2143)  (2124 = 2144)  (2125 = 2146)  (2126 = 2149)  (2127 = 2149)  (2128 = 2149)  (2129 = 2149)  (2131 = 2130)  (2132 = 2130)  (2211 = 2221)  (2212 = 2445)  (2213 = 2224)  (2214 = 2229)  (2215 = 2222)  (2216 = 2223)  (2311 = 2310)  (2312 = 2310)  (2313 = 2352)  (2314 = 2320)  (2315 = 2330)  (2316 = 2340)  (2317 = 2359)  (2319 = 2359)  (2321 = 2110)  (2322 = 2440)  (2329 = 2310)  (2411 = 2420)  (2419 = 2429)  (2421 = 2411)  (2422 = 2411)  (2423 = 2419)  (2431 = 2141)  (2432 = 2141)  (2433 = 2148)  (2434 = 2148)  (2441 = 2470)  (2442 = 2446)  (2443 = 2446)  (2444 = 2460)  (2451 = 2432)  (2452 = 2431)  (3111 = 3111)  (3112 = 3114)  (3113 = 3110)  (3114 = 3112)  (3115 = 3119)  (3119 = 3119)  (3121 = 3119)  (3122 = 3118)  (3123 = 3151)  (3131 = 3120)  (3132 = 3120)  (3211 = 3231)  (3212 = 3232)  (3213 = 3221)  (3214 = 3133)  (3215 = 3226)  (3216 = 3224)  (3217 = 3228)  (3218 = 3220)  (3221 = 3226)  (3222 = 3226)  (3223 = 3226)  (3229 = 3226)  (3231 = 3460)  (3232 = 3460)  (3311 = 100)  (3312 = 5162)  (3313 = 5161)  (3314 = 5163)  (3319 = 5169)  (3411 = 2452)  (3412 = 2451)  (3413 = 3470)  (3414 = 3473)  (3415 = 3473)  (3416 = 2455)  (3421 = 3471)  (3422 = 3471)  (3431 = 2451)  (3432 = 3472)  (3433 = 3419)  (3434 = 3131)  (3441 = 3475)  (3442 = 3475)  (3443 = 3475)  (3449 = 3475)  (3511 = 3144)  (3512 = 3143)  (3513 = 3142)  (3514 = 8311)  (3520 = 3432)  (3531 = 3417)  (3532 = 3411)  (3533 = 3412)  (3534 = 3419)  (3535 = 3442)  (3536 = 3422)  (3537 = 3433)  (3539 = 3419)  (3541 = 3416)  (3542 = 3415)  (3543 = 3419)  (3544 = 3413)  (3551 = 3210)  (3552 = 3210)  (3561 = 3449)  (3562 = 2412)  (3563 = 3340)  (3564 = 2412)  (3565 = 3152)  (3566 = 3152)  (3567 = 3152)  (3568 = 3152)  (4111 = 4190)  (4112 = 4190)  (4113 = 4190)  (4114 = 4190)  (4121 = 4120)  (4122 = 4120)  (4123 = 4210)  (4131 = 4141)  (4132 = 4190)  (4133 = 4131)  (4134 = 4133)  (4135 = 4141)  (4136 = 4113)  (4137 = 4190)  (4141 = 4223)  (4142 = 4223)  (4150 = 4190)  (4211 = 4115)  (4212 = 4115)  (4213 = 4115)  (4214 = 4115)  (4215 = 4115)  (4216 = 4222)  (4217 = 4110)  (5111 = 6130)  (5112 = 6112)  (5113 = 6112)  (5119 = 6150)  (5211 = 7221)  (5212 = 7211)  (5213 = 7213)  (5214 = 7214)  (5215 = 7212)  (5216 = 7136)  (5221 = 7223)  (5222 = 7222)  (5223 = 7230)  (5224 = 7311)  (5231 = 7231)  (5232 = 7213)  (5233 = 7241)  (5234 = 7141)  (5241 = 7137)  (5242 = 7244)  (5243 = 7245)  (5244 = 7242)  (5245 = 7242)  (5249 = 7242)  (5311 = 7214)  (5312 = 7122)  (5313 = 7131)  (5314 = 7136)  (5315 = 7124)  (5316 = 7135)  (5319 = 7121)  (5321 = 7133)  (5322 = 7132)  (5323 = 7141)  (5411 = 7432)  (5412 = 7437)  (5413 = 7442)  (5414 = 7433)  (5419 = 7430)  (5421 = 7341)  (5422 = 7341)  (5423 = 7345)  (5424 = 7346)  (5431 = 7411)  (5432 = 7412)  (5433 = 7411)  (5434 = 5122)  (5491 = 7320)  (5492 = 7422)  (5493 = 7422)  (5494 = 7312)  (5495 = 7313)  (5496 = 3471)  (5499 = 7330)  (6111 = 5132)  (6112 = 5132)  (6113 = 5132)  (6114 = 5132)  (6115 = 5133)  (6121 = 5131)  (6122 = 5131)  (6123 = 5131)  (6124 = 5131)  (6131 = 3227)  (6139 = 3227)  (6211 = 5149)  (6212 = 4221)  (6213 = 5113)  (6214 = 5111)  (6215 = 5112)  (6219 = 5110)  (6221 = 5141)  (6222 = 5141)  (6231 = 5121)  (6232 = 9141)  (6291 = 5143)  (6292 = 7143)  (7111 = 5220)  (7112 = 5220)  (7113 = 9113)  (7121 = 9113)  (7122 = 9153)  (7123 = 9113)  (7124 = 5220)  (7125 = 3471)  (7129 = 3415)  (7211 = 4220)  (7212 = 4220)  (8111 = 8270)  (8112 = 8130)  (8113 = 8260)  (8114 = 8150)  (8115 = 8231)  (8116 = 8232)  (8117 = 8120)  (8118 = 8223)  (8119 = 8100)  (8121 = 8140)  (8122 = 8111)  (8123 = 8112)  (8124 = 8160)  (8125 = 8211)  (8126 = 8163)  (8129 = 8290)  (8131 = 8282)  (8132 = 8281)  (8133 = 8290)  (8134 = 8290)  (8135 = 7231)  (8136 = 8269)  (8137 = 8263)  (8138 = 8290)  (8139 = 8290)  (8141 = 7129)  (8142 = 9312)  (8143 = 9312)  (8149 = 9313)  (8211 = 8324)  (8212 = 8322)  (8213 = 8323)  (8214 = 8322)  (8215 = 3340)  (8216 = 8312)  (8217 = 8340)  (8218 = 9330)  (8219 = 9330)  (8221 = 8333)  (8222 = 8334)  (8223 = 8331)  (8229 = 8330)  (9111 = 9211)  (9112 = 9212)  (9119 = 9210)  (9121 = 9313)  (9129 = 9312)  (9131 = 9320)  (9132 = 9132)  (9133 = 9320)  (9134 = 9320)  (9139 = 9320)  (9141 = 9330)  (9149 = 9330)  (9211 = 9151)  (9219 = 9151)  (9221 = 9132)  (9222 = 9150)  (9223 = 9132)  (9224 = 5123)  (9225 = 5123)  (9226 = 9152)  (9229 = 9150)  (9231 = 9142)  (9232 = 9162)  (9233 = 9130)  (9234 = 9133)  (9235 = 9161)  (9239 = 9162)  (9241 = 9152)  (9242 = 5169)  (9243 = 9152)  (9244 = 5131)  (9245 = 9152)  (9249 = 9152)  (9251 = 5220)  (9259 = 9151) (nonmissing = 10000), gen(isco88_4d)
		drop soc*
		cd $other_data
		save temp2.dta, replace 
	restore

	append using temp2.dta
	erase temp1.dta
	erase temp2.dta

	preserve
		keep year isco88_4d entref poe_job
		drop if year<2003
		capture drop tag
		egen tag = tag(entref isco88_4d) if poe_job==1
		drop if tag==0
		drop tag year
		cd $other_data
		save temp_poe.dta, replace
	restore
	
	sort entref isco88_$soc_digits
	quietly merge m:1 entref isco88_$soc_digits using temp_poe, nogen update keepusing(poe_job)
	replace entry = 1 if tenure<=$max_tenure & year<2003
	replace poe   = 1 if poe_job==1 & year<2003 & sjd==2
	erase temp_poe.dta

	replace tenure=floor(tenure)
	replace tenure=0 if poe==1

	drop if logwage_cpi_99==1 | logearnings_cpi_99==1
	drop logwage_cpi_99 logearnings_cpi_99

	keep log* sex age tenure poe* colag ft idbr* sjd wgor he* gp*/*
	*/   entry year isco88_$soc_digits firm_start entref sic piden start now

	drop if wgor==0 | wgor==.
	drop if idbrsta==0 | idbrsta==8 | idbrsta==. 
	
	sort entref isco88_$soc_digits
	egen jobid = group(entref isco88_$soc_digits)
	label variable jobid "Job ID"

	drop if poe_firm!=1
	cd $reg_results_poe_criteria
	save slim_1997_2016_2.dta, replace
	
}

*** Table 3, Row 4 dataset. REQUIRES that baseline sample creation code has been run previously
if $create_row4_data==1{

	*** Adjust variables accordingly to creat different sample based on selection criteria ***
	
	* Changed (baseline was 3)
	global min_hires 	= 1		// Min number of hires per firm-occ-year
	
	global max_tenure	= 1		// Max years of tenure to be considered a new hire (years)
	global min_life		= 3		// Min years firm is required to exist
	global soc_digits	= "4d"	// Digits in the occupations coding that define a job within firms
	
	* THIS DATASET HAS BEEN CREATED WHEN "BASELINE SAMPLE" WAS CREATED *
	cd $created_datadir
	use data_before_min_hires.dta, clear

	* The following code is identical to "Baseline Creation", 
	* explanations of the code can be found there.
	
	drop if firm_life<$min_life

	sort entref isco88_$soc_digits year
	egen tag = tag(entref isco88_$soc_digits year) if entry==1
	replace tag=. if tag==0
	by entref isco88_$soc_digits: egen temp = count(tag)
	g poe=.
	replace poe=1 if entry==1 & temp>=2
	drop temp tag
	label variable poe "Newly hired employee in POE job"

	sort entref
	bysort entref: egen poe_firm=sum(poe)
	replace poe_firm=1 if poe_firm>=1
	label variable poe_firm "Firm which is hiring through POE jobs"

	sort entref isco88_$soc_digits
	bysort entref isco88_$soc_digits: egen poe_job=sum(poe)
	replace poe_job=1 if poe_job>=1
	label variable poe_job "POE job"

	preserve
		keep entref poe_firm
		drop if poe_firm==0

		sort entref
		egen tag = tag(entref)
		drop if tag==0
		drop tag
		cd $other_data
		save temp1.dta, replace
		
		cd $created_datadir
		use * if (year<=2002 & entref!=.) using ashe_1997_2016.dta, clear
		cd $other_data
		quietly merge m:1 entref using temp1, nogen keep(1 3 4 5)
		
		recode soc00_4d (1111 = 1110)  (1112 = 1210)  (1113 = 1110)  (1114 = 1140)  (1121 = 1222)  (1122 = 1223)  (1123 = 1222)  (1131 = 1231)  (1132 = 1233)  (1133 = 1235)  (1134 = 1234)  (1135 = 1232)  (1136 = 1236)  (1137 = 1237)  (1141 = 1239)  (1142 = 1239)  (1151 = 1227)  (1152 = 1231)  (1161 = 1226)  (1162 = 1226)  (1163 = 1224)  (1171 = 100)  (1172 = 3450)  (1173 = 1229)  (1174 = 1239)  (1181 = 1229)  (1182 = 1319)  (1183 = 1319)  (1184 = 1229)  (1185 = 1318)  (1211 = 1311)  (1212 = 1311)  (1219 = 1311)  (1221 = 1315)  (1222 = 1227)  (1223 = 1315)  (1224 = 1315)  (1225 = 1319)  (1226 = 1316)  (1231 = 1317)  (1232 = 1314)  (1233 = 1318)  (1234 = 1314)  (1235 = 1319)  (1239 = 1319)  (2111 = 2113)  (2112 = 2211)  (2113 = 2110)  (2121 = 2142)  (2122 = 2145)  (2123 = 2143)  (2124 = 2144)  (2125 = 2146)  (2126 = 2149)  (2127 = 2149)  (2128 = 2149)  (2129 = 2149)  (2131 = 2130)  (2132 = 2130)  (2211 = 2221)  (2212 = 2445)  (2213 = 2224)  (2214 = 2229)  (2215 = 2222)  (2216 = 2223)  (2311 = 2310)  (2312 = 2310)  (2313 = 2352)  (2314 = 2320)  (2315 = 2330)  (2316 = 2340)  (2317 = 2359)  (2319 = 2359)  (2321 = 2110)  (2322 = 2440)  (2329 = 2310)  (2411 = 2420)  (2419 = 2429)  (2421 = 2411)  (2422 = 2411)  (2423 = 2419)  (2431 = 2141)  (2432 = 2141)  (2433 = 2148)  (2434 = 2148)  (2441 = 2470)  (2442 = 2446)  (2443 = 2446)  (2444 = 2460)  (2451 = 2432)  (2452 = 2431)  (3111 = 3111)  (3112 = 3114)  (3113 = 3110)  (3114 = 3112)  (3115 = 3119)  (3119 = 3119)  (3121 = 3119)  (3122 = 3118)  (3123 = 3151)  (3131 = 3120)  (3132 = 3120)  (3211 = 3231)  (3212 = 3232)  (3213 = 3221)  (3214 = 3133)  (3215 = 3226)  (3216 = 3224)  (3217 = 3228)  (3218 = 3220)  (3221 = 3226)  (3222 = 3226)  (3223 = 3226)  (3229 = 3226)  (3231 = 3460)  (3232 = 3460)  (3311 = 100)  (3312 = 5162)  (3313 = 5161)  (3314 = 5163)  (3319 = 5169)  (3411 = 2452)  (3412 = 2451)  (3413 = 3470)  (3414 = 3473)  (3415 = 3473)  (3416 = 2455)  (3421 = 3471)  (3422 = 3471)  (3431 = 2451)  (3432 = 3472)  (3433 = 3419)  (3434 = 3131)  (3441 = 3475)  (3442 = 3475)  (3443 = 3475)  (3449 = 3475)  (3511 = 3144)  (3512 = 3143)  (3513 = 3142)  (3514 = 8311)  (3520 = 3432)  (3531 = 3417)  (3532 = 3411)  (3533 = 3412)  (3534 = 3419)  (3535 = 3442)  (3536 = 3422)  (3537 = 3433)  (3539 = 3419)  (3541 = 3416)  (3542 = 3415)  (3543 = 3419)  (3544 = 3413)  (3551 = 3210)  (3552 = 3210)  (3561 = 3449)  (3562 = 2412)  (3563 = 3340)  (3564 = 2412)  (3565 = 3152)  (3566 = 3152)  (3567 = 3152)  (3568 = 3152)  (4111 = 4190)  (4112 = 4190)  (4113 = 4190)  (4114 = 4190)  (4121 = 4120)  (4122 = 4120)  (4123 = 4210)  (4131 = 4141)  (4132 = 4190)  (4133 = 4131)  (4134 = 4133)  (4135 = 4141)  (4136 = 4113)  (4137 = 4190)  (4141 = 4223)  (4142 = 4223)  (4150 = 4190)  (4211 = 4115)  (4212 = 4115)  (4213 = 4115)  (4214 = 4115)  (4215 = 4115)  (4216 = 4222)  (4217 = 4110)  (5111 = 6130)  (5112 = 6112)  (5113 = 6112)  (5119 = 6150)  (5211 = 7221)  (5212 = 7211)  (5213 = 7213)  (5214 = 7214)  (5215 = 7212)  (5216 = 7136)  (5221 = 7223)  (5222 = 7222)  (5223 = 7230)  (5224 = 7311)  (5231 = 7231)  (5232 = 7213)  (5233 = 7241)  (5234 = 7141)  (5241 = 7137)  (5242 = 7244)  (5243 = 7245)  (5244 = 7242)  (5245 = 7242)  (5249 = 7242)  (5311 = 7214)  (5312 = 7122)  (5313 = 7131)  (5314 = 7136)  (5315 = 7124)  (5316 = 7135)  (5319 = 7121)  (5321 = 7133)  (5322 = 7132)  (5323 = 7141)  (5411 = 7432)  (5412 = 7437)  (5413 = 7442)  (5414 = 7433)  (5419 = 7430)  (5421 = 7341)  (5422 = 7341)  (5423 = 7345)  (5424 = 7346)  (5431 = 7411)  (5432 = 7412)  (5433 = 7411)  (5434 = 5122)  (5491 = 7320)  (5492 = 7422)  (5493 = 7422)  (5494 = 7312)  (5495 = 7313)  (5496 = 3471)  (5499 = 7330)  (6111 = 5132)  (6112 = 5132)  (6113 = 5132)  (6114 = 5132)  (6115 = 5133)  (6121 = 5131)  (6122 = 5131)  (6123 = 5131)  (6124 = 5131)  (6131 = 3227)  (6139 = 3227)  (6211 = 5149)  (6212 = 4221)  (6213 = 5113)  (6214 = 5111)  (6215 = 5112)  (6219 = 5110)  (6221 = 5141)  (6222 = 5141)  (6231 = 5121)  (6232 = 9141)  (6291 = 5143)  (6292 = 7143)  (7111 = 5220)  (7112 = 5220)  (7113 = 9113)  (7121 = 9113)  (7122 = 9153)  (7123 = 9113)  (7124 = 5220)  (7125 = 3471)  (7129 = 3415)  (7211 = 4220)  (7212 = 4220)  (8111 = 8270)  (8112 = 8130)  (8113 = 8260)  (8114 = 8150)  (8115 = 8231)  (8116 = 8232)  (8117 = 8120)  (8118 = 8223)  (8119 = 8100)  (8121 = 8140)  (8122 = 8111)  (8123 = 8112)  (8124 = 8160)  (8125 = 8211)  (8126 = 8163)  (8129 = 8290)  (8131 = 8282)  (8132 = 8281)  (8133 = 8290)  (8134 = 8290)  (8135 = 7231)  (8136 = 8269)  (8137 = 8263)  (8138 = 8290)  (8139 = 8290)  (8141 = 7129)  (8142 = 9312)  (8143 = 9312)  (8149 = 9313)  (8211 = 8324)  (8212 = 8322)  (8213 = 8323)  (8214 = 8322)  (8215 = 3340)  (8216 = 8312)  (8217 = 8340)  (8218 = 9330)  (8219 = 9330)  (8221 = 8333)  (8222 = 8334)  (8223 = 8331)  (8229 = 8330)  (9111 = 9211)  (9112 = 9212)  (9119 = 9210)  (9121 = 9313)  (9129 = 9312)  (9131 = 9320)  (9132 = 9132)  (9133 = 9320)  (9134 = 9320)  (9139 = 9320)  (9141 = 9330)  (9149 = 9330)  (9211 = 9151)  (9219 = 9151)  (9221 = 9132)  (9222 = 9150)  (9223 = 9132)  (9224 = 5123)  (9225 = 5123)  (9226 = 9152)  (9229 = 9150)  (9231 = 9142)  (9232 = 9162)  (9233 = 9130)  (9234 = 9133)  (9235 = 9161)  (9239 = 9162)  (9241 = 9152)  (9242 = 5169)  (9243 = 9152)  (9244 = 5131)  (9245 = 9152)  (9249 = 9152)  (9251 = 5220)  (9259 = 9151) (nonmissing = 10000), gen(isco88_4d)
		drop soc*
		cd $other_data
		save temp2.dta, replace 
	restore

	append using temp2.dta
	erase temp1.dta
	erase temp2.dta

	preserve
		keep year isco88_4d entref poe_job
		drop if year<2003
		capture drop tag
		egen tag = tag(entref isco88_4d) if poe_job==1
		drop if tag==0
		drop tag year
		cd $other_data
		save temp_poe.dta, replace
	restore
	
	sort entref isco88_$soc_digits
	quietly merge m:1 entref isco88_$soc_digits using temp_poe, nogen update keepusing(poe_job)
	replace entry = 1 if tenure<=$max_tenure & year<2003
	replace poe   = 1 if poe_job==1 & year<2003 & sjd==2
	erase temp_poe.dta

	replace tenure=floor(tenure)
	replace tenure=0 if poe==1

	drop if logwage_cpi_99==1 | logearnings_cpi_99==1
	drop logwage_cpi_99 logearnings_cpi_99

	keep log* sex age tenure poe* colag ft idbr* sjd wgor he* gp*/*
	*/   entry year isco88_$soc_digits firm_start entref sic piden start now

	drop if wgor==0 | wgor==.
	drop if idbrsta==0 | idbrsta==8 | idbrsta==.
	
	sort entref isco88_$soc_digits
	egen jobid = group(entref isco88_$soc_digits)
	label variable jobid "Job ID"

	drop if poe_firm!=1
	cd $reg_results_poe_criteria
	save slim_1997_2016_all_max.dta, replace
	
}

*** Table 3, Row 7 dataset. REQUIRES that baseline sample creation code has been run previously
if $create_row7_data==1{
	
	*** Adjust variables accordingly to creat different sample based on selection criteria ***
	
	global min_hires 	= 3		// Min number of hires per firm-occ-year
	global max_tenure	= 1		// Max years of tenure to be considered a new hire (years)
	global min_life		= 3		// Min years firm is required to exist
	
	* Changed (baseline was "4d")
	global soc_digits	= "3d"	// Digits in the occupations coding that define a job within firms
	
	global min_time_pc  = 0.5	// Min percent of years of firm being present in dataset, when a job has to fulfil conditions above to be in baseline sample
	
	* THIS DATASET HAS BEEN CREATED WHEN "BASELINE SAMPLE" WAS CREATED *
	cd $created_datadir
	use data_before_min_hires.dta, clear
	
	g isco88_3d = floor(isco88_4d/10)
	
	* The following code is identical to "Baseline Creation", 
	* explanations of the code can be found there.
	
	drop hires_occ
	sort entref year isco88_$soc_digits 
	bysort entref year isco88_$soc_digits : egen hires_occ = count(piden) if entry==1

	drop if firm_life<$min_life

	sort entref isco88_$soc_digits year
	egen temp = tag(entref isco88_$soc_digits year) if hires_occ>=$min_hires & entry==1
	bysort entref isco88_$soc_digits: egen rel_years = sum(temp) if entry==1
	drop hires_occ temp

	g poe=.
	replace poe=1 if (rel_years/firm_life)>=$min_time_pc & rel_years!=.
	label variable poe "Newly hired employee in POE job"
	drop rel_years

	sort entref
	bysort entref: egen poe_firm=sum(poe)
	replace poe_firm=1 if poe_firm>=1
	label variable poe_firm "Firm which is hiring through POE jobs"

	sort entref isco88_$soc_digits
	bysort entref isco88_$soc_digits: egen poe_job=sum(poe)
	replace poe_job=1 if poe_job>=1
	label variable poe_job "POE job"

	preserve
		keep entref poe_firm
		drop if poe_firm==0

		sort entref
		egen tag = tag(entref)
		drop if tag==0
		drop tag
		cd $other_data
		save temp1.dta, replace
		
		cd $created_datadir
		use * if (year<=2002 & entref!=.) using ashe_1997_2016.dta, clear
		cd $other_data
		quietly merge m:1 entref using temp1, nogen keep(1 3 4 5)
		
		recode soc00_4d (1111 = 1110)  (1112 = 1210)  (1113 = 1110)  (1114 = 1140)  (1121 = 1222)  (1122 = 1223)  (1123 = 1222)  (1131 = 1231)  (1132 = 1233)  (1133 = 1235)  (1134 = 1234)  (1135 = 1232)  (1136 = 1236)  (1137 = 1237)  (1141 = 1239)  (1142 = 1239)  (1151 = 1227)  (1152 = 1231)  (1161 = 1226)  (1162 = 1226)  (1163 = 1224)  (1171 = 100)  (1172 = 3450)  (1173 = 1229)  (1174 = 1239)  (1181 = 1229)  (1182 = 1319)  (1183 = 1319)  (1184 = 1229)  (1185 = 1318)  (1211 = 1311)  (1212 = 1311)  (1219 = 1311)  (1221 = 1315)  (1222 = 1227)  (1223 = 1315)  (1224 = 1315)  (1225 = 1319)  (1226 = 1316)  (1231 = 1317)  (1232 = 1314)  (1233 = 1318)  (1234 = 1314)  (1235 = 1319)  (1239 = 1319)  (2111 = 2113)  (2112 = 2211)  (2113 = 2110)  (2121 = 2142)  (2122 = 2145)  (2123 = 2143)  (2124 = 2144)  (2125 = 2146)  (2126 = 2149)  (2127 = 2149)  (2128 = 2149)  (2129 = 2149)  (2131 = 2130)  (2132 = 2130)  (2211 = 2221)  (2212 = 2445)  (2213 = 2224)  (2214 = 2229)  (2215 = 2222)  (2216 = 2223)  (2311 = 2310)  (2312 = 2310)  (2313 = 2352)  (2314 = 2320)  (2315 = 2330)  (2316 = 2340)  (2317 = 2359)  (2319 = 2359)  (2321 = 2110)  (2322 = 2440)  (2329 = 2310)  (2411 = 2420)  (2419 = 2429)  (2421 = 2411)  (2422 = 2411)  (2423 = 2419)  (2431 = 2141)  (2432 = 2141)  (2433 = 2148)  (2434 = 2148)  (2441 = 2470)  (2442 = 2446)  (2443 = 2446)  (2444 = 2460)  (2451 = 2432)  (2452 = 2431)  (3111 = 3111)  (3112 = 3114)  (3113 = 3110)  (3114 = 3112)  (3115 = 3119)  (3119 = 3119)  (3121 = 3119)  (3122 = 3118)  (3123 = 3151)  (3131 = 3120)  (3132 = 3120)  (3211 = 3231)  (3212 = 3232)  (3213 = 3221)  (3214 = 3133)  (3215 = 3226)  (3216 = 3224)  (3217 = 3228)  (3218 = 3220)  (3221 = 3226)  (3222 = 3226)  (3223 = 3226)  (3229 = 3226)  (3231 = 3460)  (3232 = 3460)  (3311 = 100)  (3312 = 5162)  (3313 = 5161)  (3314 = 5163)  (3319 = 5169)  (3411 = 2452)  (3412 = 2451)  (3413 = 3470)  (3414 = 3473)  (3415 = 3473)  (3416 = 2455)  (3421 = 3471)  (3422 = 3471)  (3431 = 2451)  (3432 = 3472)  (3433 = 3419)  (3434 = 3131)  (3441 = 3475)  (3442 = 3475)  (3443 = 3475)  (3449 = 3475)  (3511 = 3144)  (3512 = 3143)  (3513 = 3142)  (3514 = 8311)  (3520 = 3432)  (3531 = 3417)  (3532 = 3411)  (3533 = 3412)  (3534 = 3419)  (3535 = 3442)  (3536 = 3422)  (3537 = 3433)  (3539 = 3419)  (3541 = 3416)  (3542 = 3415)  (3543 = 3419)  (3544 = 3413)  (3551 = 3210)  (3552 = 3210)  (3561 = 3449)  (3562 = 2412)  (3563 = 3340)  (3564 = 2412)  (3565 = 3152)  (3566 = 3152)  (3567 = 3152)  (3568 = 3152)  (4111 = 4190)  (4112 = 4190)  (4113 = 4190)  (4114 = 4190)  (4121 = 4120)  (4122 = 4120)  (4123 = 4210)  (4131 = 4141)  (4132 = 4190)  (4133 = 4131)  (4134 = 4133)  (4135 = 4141)  (4136 = 4113)  (4137 = 4190)  (4141 = 4223)  (4142 = 4223)  (4150 = 4190)  (4211 = 4115)  (4212 = 4115)  (4213 = 4115)  (4214 = 4115)  (4215 = 4115)  (4216 = 4222)  (4217 = 4110)  (5111 = 6130)  (5112 = 6112)  (5113 = 6112)  (5119 = 6150)  (5211 = 7221)  (5212 = 7211)  (5213 = 7213)  (5214 = 7214)  (5215 = 7212)  (5216 = 7136)  (5221 = 7223)  (5222 = 7222)  (5223 = 7230)  (5224 = 7311)  (5231 = 7231)  (5232 = 7213)  (5233 = 7241)  (5234 = 7141)  (5241 = 7137)  (5242 = 7244)  (5243 = 7245)  (5244 = 7242)  (5245 = 7242)  (5249 = 7242)  (5311 = 7214)  (5312 = 7122)  (5313 = 7131)  (5314 = 7136)  (5315 = 7124)  (5316 = 7135)  (5319 = 7121)  (5321 = 7133)  (5322 = 7132)  (5323 = 7141)  (5411 = 7432)  (5412 = 7437)  (5413 = 7442)  (5414 = 7433)  (5419 = 7430)  (5421 = 7341)  (5422 = 7341)  (5423 = 7345)  (5424 = 7346)  (5431 = 7411)  (5432 = 7412)  (5433 = 7411)  (5434 = 5122)  (5491 = 7320)  (5492 = 7422)  (5493 = 7422)  (5494 = 7312)  (5495 = 7313)  (5496 = 3471)  (5499 = 7330)  (6111 = 5132)  (6112 = 5132)  (6113 = 5132)  (6114 = 5132)  (6115 = 5133)  (6121 = 5131)  (6122 = 5131)  (6123 = 5131)  (6124 = 5131)  (6131 = 3227)  (6139 = 3227)  (6211 = 5149)  (6212 = 4221)  (6213 = 5113)  (6214 = 5111)  (6215 = 5112)  (6219 = 5110)  (6221 = 5141)  (6222 = 5141)  (6231 = 5121)  (6232 = 9141)  (6291 = 5143)  (6292 = 7143)  (7111 = 5220)  (7112 = 5220)  (7113 = 9113)  (7121 = 9113)  (7122 = 9153)  (7123 = 9113)  (7124 = 5220)  (7125 = 3471)  (7129 = 3415)  (7211 = 4220)  (7212 = 4220)  (8111 = 8270)  (8112 = 8130)  (8113 = 8260)  (8114 = 8150)  (8115 = 8231)  (8116 = 8232)  (8117 = 8120)  (8118 = 8223)  (8119 = 8100)  (8121 = 8140)  (8122 = 8111)  (8123 = 8112)  (8124 = 8160)  (8125 = 8211)  (8126 = 8163)  (8129 = 8290)  (8131 = 8282)  (8132 = 8281)  (8133 = 8290)  (8134 = 8290)  (8135 = 7231)  (8136 = 8269)  (8137 = 8263)  (8138 = 8290)  (8139 = 8290)  (8141 = 7129)  (8142 = 9312)  (8143 = 9312)  (8149 = 9313)  (8211 = 8324)  (8212 = 8322)  (8213 = 8323)  (8214 = 8322)  (8215 = 3340)  (8216 = 8312)  (8217 = 8340)  (8218 = 9330)  (8219 = 9330)  (8221 = 8333)  (8222 = 8334)  (8223 = 8331)  (8229 = 8330)  (9111 = 9211)  (9112 = 9212)  (9119 = 9210)  (9121 = 9313)  (9129 = 9312)  (9131 = 9320)  (9132 = 9132)  (9133 = 9320)  (9134 = 9320)  (9139 = 9320)  (9141 = 9330)  (9149 = 9330)  (9211 = 9151)  (9219 = 9151)  (9221 = 9132)  (9222 = 9150)  (9223 = 9132)  (9224 = 5123)  (9225 = 5123)  (9226 = 9152)  (9229 = 9150)  (9231 = 9142)  (9232 = 9162)  (9233 = 9130)  (9234 = 9133)  (9235 = 9161)  (9239 = 9162)  (9241 = 9152)  (9242 = 5169)  (9243 = 9152)  (9244 = 5131)  (9245 = 9152)  (9249 = 9152)  (9251 = 5220)  (9259 = 9151) (nonmissing = 10000), gen(isco88_4d)
		g isco88_3d = floor(isco88_4d/10)
		drop soc*
		cd $other_data
		save temp2.dta, replace 
	restore

	append using temp2.dta
	erase temp1.dta
	erase temp2.dta

	preserve
		keep year isco88_$soc_digits entref poe_job
		drop if year<2003
		capture drop tag
		egen tag = tag(entref isco88_$soc_digits) if poe_job==1
		drop if tag==0
		drop tag year
		cd $other_data
		save temp_poe.dta, replace
	restore
	
	sort entref isco88_$soc_digits
	quietly merge m:1 entref isco88_$soc_digits using temp_poe, nogen update keepusing(poe_job)
	replace entry = 1 if tenure<=$max_tenure & year<2003
	replace poe   = 1 if poe_job==1 & year<2003 & sjd==2
	erase temp_poe.dta

	replace tenure=floor(tenure)
	replace tenure=0 if poe==1

	drop if logwage_cpi_99==1 | logearnings_cpi_99==1
	drop logwage_cpi_99 logearnings_cpi_99

	keep log* sex age tenure poe* colag ft idbr* sjd wgor he* gp*/*
	*/   entry year isco88_$soc_digits firm_start entref sic piden start now

	drop if wgor==0 | wgor==.
	drop if idbrsta==0 | idbrsta==8 | idbrsta==. 
	
	sort entref isco88_$soc_digits
	egen jobid = group(entref isco88_$soc_digits)
	label variable jobid "Job ID"

	drop if poe_firm!=1
	cd $reg_results_3d
	save slim_1997_2016_3d.dta, replace
	
}

*** Figure 2 & 3, Table C6-C9. REQUIRES that baseline sample creation code has been run previously
if $tenure_data==1{

	cd $created_datadir
	use slim_1997_2016, clear

	keep if idbrsta==1 | idbrsta==2 | idbrsta==3
	drop w*
	drop if year==1997

	xtset, clear
	xtset piden year

	* Keep only indivduals who worked at least ones in a POE job
	sort piden
	by piden: egen temp = count(poe)
	drop if temp==0
	drop temp

	* Keep only POE job-stayers
	sort piden year
	g temp=.
	by piden: replace temp=0 if poe==1
	by piden: replace temp=1 if L.temp==0 & L.jobid==jobid & poe!=1 
	by piden: replace temp=2 if L.temp==1 & L.jobid==jobid & poe!=1 
	by piden: replace temp=3 if L.temp==2 & L.jobid==jobid & poe!=1 
	by piden: replace temp=4 if L.temp==3 & L.jobid==jobid & poe!=1 
	by piden: replace temp=5 if L.temp==4 & L.jobid==jobid & poe!=1 
	drop if temp==.

	** Generate Match variable
	sort piden year
	g ts = 0 if temp!=.
	replace ts = 1 if temp==0
	g sts = sum(ts)
	replace sts = . if ts==.

	** Generate Hiring Cohort variable
	sort sts year
	g cohort = year-temp
	
	* Save the data to create figure 2
	cd $tenure_dir
	save figure2_data, replace

	** Keep only those with at least one year tenure in MATCH for regression analysis
	sort sts year
	capture drop asd
	by sts: egen asd = total(temp)
	drop if asd == 0

	* tenure in POE job
	forvalues i = 1/4{
	capture drop T`i'
	}
	quietly tab temp, gen(T)

	* generate year dummies
	forvalues i = 1/19{
	capture drop d`i'
	}
	quietly tab year, gen(d)

	* year-tenure interaction, k has to start at 2 not 1!
	forvalue i = 1/19{
		forvalue k = 2/4{
			capture drop int`i'_`k'
			quiet gen int`i'_`k' = .
			quiet replace int`i'_`k' = d`i'*T`k'
			local j = `k' - 1 
			local t = `i' + 1997
			capture drop int`t'_`j'
			rename int`i'_`k' int`t'_`j'
		}
	}

	drop d*
	drop T*

	* Zero by definition, drop those
	drop int1998_1
	drop int1998_2
	drop int1998_3
	drop int1999_2
	drop int1999_3
	drop int2000_3

	g sqage = (age-30)*(age-30)

	gen idbrnempsq = idbrnemp*idbrnemp
	drop if year<2001
	drop int2001_1
	drop int2001_2
	drop int2001_3
	drop int2002_2
	drop int2002_3
	drop int2003_3

	quiet areg logwage_cpi int2002_1-int2016_3 sqage idbrnemp idbrnempsq, absorb(sts) vce(robust)
	preserve
		clear
		set obs 4
		gen tenure = _n-1	
		forvalue i = 2001/2013{
			capture drop b`i'
			capture drop se`i'
			quietly gen b`i' = .
			quietly gen se`i' = .
			forvalue k = 1/3{
				local j = `i'+`k'
				quiet replace b`i'=_b[int`j'_`k'] if tenure==`k'
				quiet replace se`i'=_se[int`j'_`k'] if tenure==`k'
			}
		}	
		cd $tenure_dir
		save poe_tenure_wage.dta, replace
	restore

	*** Hours
	quiet areg loghours int2002_1-int2016_3 sqage idbrnemp idbrnempsq, absorb(sts) vce(robust)
	preserve
		clear
		set obs 4
		gen tenure = _n-1	
		forvalue i = 2001/2013{
			capture drop b`i'
			capture drop se`i'
			quietly gen b`i' = .
			quietly gen se`i' = .
			forvalue k = 1/3{
				local j = `i'+`k'
				quietly replace b`i'=_b[int`j'_`k'] if tenure==`k'
				quietly replace se`i'=_se[int`j'_`k'] if tenure==`k'
			}
		}	
		cd $tenure_dir
		save poe_tenure_hours.dta, replace
	restore

	* Create datasets for TABLE C6
	preserve
		cd $tenure_dir
		use poe_tenure_wage.dta, clear
		tsset tenure
		drop if tenure==0

		quietly reshape long b se, i(tenure) j(start)
		
		replace b 	= b*100
		replace se 	= se*100
		
		format b  %4.2f
		format se %4.2f
		
		g type = "wage"
		
		drop if start==2001
		cd $tenure_dir
		save table_C6_wages.dta, replace
	restore	
	
	preserve
		cd $tenure_dir
		use poe_tenure_hours.dta, clear
		tsset tenure
		drop if tenure==0

		quietly reshape long b se, i(tenure) j(start)
	
		replace b 	= b*100
		replace se 	= se*100
		
		format b  %4.2f
		format se %4.2f
		
		g type = "hours"
		
		drop if start==2001
		cd $tenure_dir
		save table_C6_hours.dta, replace
	restore	

}

*** Table B2 datasets. REQUIRES that baseline sample creation code has been run previously
if $create_B2_data==1{

	global max_tenure	= 1		// Max years of tenure to be considered a new hire (years)
	global min_life		= 3		// Min years firm is required to exist
	global soc_digits	= "4d"	// Digits in the occupations coding that define a job within firms
	global min_time_pc  = 0.5	// Min percent of years of firm being present in dataset, when a job has to fulfil conditions above to be in baseline sample
	
	* Changed (baseline was 3)
	global min_hires 	= 2		// Min number of hires per firm-occ-year
	
	* THIS DATASET HAS BEEN CREATED WHEN "BASELINE SAMPLE" WAS CREATED *
	cd $created_datadir
	use data_before_min_hires.dta, clear

	* The following code is identical to "Baseline Creation", 
	* explanations of the code can be found there.
	
	drop if firm_life<$min_life

	sort entref isco88_$soc_digits year
	egen temp = tag(entref isco88_$soc_digits year) if hires_occ>=$min_hires & entry==1
	bysort entref isco88_$soc_digits: egen rel_years = sum(temp) if entry==1
	drop hires_occ temp

	g poe=.
	replace poe=1 if (rel_years/firm_life)>=$min_time_pc & rel_years!=.
	label variable poe "Newly hired employee in POE job"
	drop rel_years

	sort entref
	bysort entref: egen poe_firm=sum(poe)
	replace poe_firm=1 if poe_firm>=1
	label variable poe_firm "Firm which is hiring through POE jobs"

	sort entref isco88_$soc_digits
	bysort entref isco88_$soc_digits: egen poe_job=sum(poe)
	replace poe_job=1 if poe_job>=1
	label variable poe_job "POE job"

	preserve
		keep entref poe_firm
		drop if poe_firm==0

		sort entref
		egen tag = tag(entref)
		drop if tag==0
		drop tag
		cd $other_data
		save temp1.dta, replace
		
		cd $created_datadir
		use * if (year<=2002 & entref!=.) using ashe_1997_2016.dta, clear
		cd $other_data
		quietly merge m:1 entref using temp1, nogen keep(1 3 4 5)
		
		recode soc00_4d (1111 = 1110)  (1112 = 1210)  (1113 = 1110)  (1114 = 1140)  (1121 = 1222)  (1122 = 1223)  (1123 = 1222)  (1131 = 1231)  (1132 = 1233)  (1133 = 1235)  (1134 = 1234)  (1135 = 1232)  (1136 = 1236)  (1137 = 1237)  (1141 = 1239)  (1142 = 1239)  (1151 = 1227)  (1152 = 1231)  (1161 = 1226)  (1162 = 1226)  (1163 = 1224)  (1171 = 100)  (1172 = 3450)  (1173 = 1229)  (1174 = 1239)  (1181 = 1229)  (1182 = 1319)  (1183 = 1319)  (1184 = 1229)  (1185 = 1318)  (1211 = 1311)  (1212 = 1311)  (1219 = 1311)  (1221 = 1315)  (1222 = 1227)  (1223 = 1315)  (1224 = 1315)  (1225 = 1319)  (1226 = 1316)  (1231 = 1317)  (1232 = 1314)  (1233 = 1318)  (1234 = 1314)  (1235 = 1319)  (1239 = 1319)  (2111 = 2113)  (2112 = 2211)  (2113 = 2110)  (2121 = 2142)  (2122 = 2145)  (2123 = 2143)  (2124 = 2144)  (2125 = 2146)  (2126 = 2149)  (2127 = 2149)  (2128 = 2149)  (2129 = 2149)  (2131 = 2130)  (2132 = 2130)  (2211 = 2221)  (2212 = 2445)  (2213 = 2224)  (2214 = 2229)  (2215 = 2222)  (2216 = 2223)  (2311 = 2310)  (2312 = 2310)  (2313 = 2352)  (2314 = 2320)  (2315 = 2330)  (2316 = 2340)  (2317 = 2359)  (2319 = 2359)  (2321 = 2110)  (2322 = 2440)  (2329 = 2310)  (2411 = 2420)  (2419 = 2429)  (2421 = 2411)  (2422 = 2411)  (2423 = 2419)  (2431 = 2141)  (2432 = 2141)  (2433 = 2148)  (2434 = 2148)  (2441 = 2470)  (2442 = 2446)  (2443 = 2446)  (2444 = 2460)  (2451 = 2432)  (2452 = 2431)  (3111 = 3111)  (3112 = 3114)  (3113 = 3110)  (3114 = 3112)  (3115 = 3119)  (3119 = 3119)  (3121 = 3119)  (3122 = 3118)  (3123 = 3151)  (3131 = 3120)  (3132 = 3120)  (3211 = 3231)  (3212 = 3232)  (3213 = 3221)  (3214 = 3133)  (3215 = 3226)  (3216 = 3224)  (3217 = 3228)  (3218 = 3220)  (3221 = 3226)  (3222 = 3226)  (3223 = 3226)  (3229 = 3226)  (3231 = 3460)  (3232 = 3460)  (3311 = 100)  (3312 = 5162)  (3313 = 5161)  (3314 = 5163)  (3319 = 5169)  (3411 = 2452)  (3412 = 2451)  (3413 = 3470)  (3414 = 3473)  (3415 = 3473)  (3416 = 2455)  (3421 = 3471)  (3422 = 3471)  (3431 = 2451)  (3432 = 3472)  (3433 = 3419)  (3434 = 3131)  (3441 = 3475)  (3442 = 3475)  (3443 = 3475)  (3449 = 3475)  (3511 = 3144)  (3512 = 3143)  (3513 = 3142)  (3514 = 8311)  (3520 = 3432)  (3531 = 3417)  (3532 = 3411)  (3533 = 3412)  (3534 = 3419)  (3535 = 3442)  (3536 = 3422)  (3537 = 3433)  (3539 = 3419)  (3541 = 3416)  (3542 = 3415)  (3543 = 3419)  (3544 = 3413)  (3551 = 3210)  (3552 = 3210)  (3561 = 3449)  (3562 = 2412)  (3563 = 3340)  (3564 = 2412)  (3565 = 3152)  (3566 = 3152)  (3567 = 3152)  (3568 = 3152)  (4111 = 4190)  (4112 = 4190)  (4113 = 4190)  (4114 = 4190)  (4121 = 4120)  (4122 = 4120)  (4123 = 4210)  (4131 = 4141)  (4132 = 4190)  (4133 = 4131)  (4134 = 4133)  (4135 = 4141)  (4136 = 4113)  (4137 = 4190)  (4141 = 4223)  (4142 = 4223)  (4150 = 4190)  (4211 = 4115)  (4212 = 4115)  (4213 = 4115)  (4214 = 4115)  (4215 = 4115)  (4216 = 4222)  (4217 = 4110)  (5111 = 6130)  (5112 = 6112)  (5113 = 6112)  (5119 = 6150)  (5211 = 7221)  (5212 = 7211)  (5213 = 7213)  (5214 = 7214)  (5215 = 7212)  (5216 = 7136)  (5221 = 7223)  (5222 = 7222)  (5223 = 7230)  (5224 = 7311)  (5231 = 7231)  (5232 = 7213)  (5233 = 7241)  (5234 = 7141)  (5241 = 7137)  (5242 = 7244)  (5243 = 7245)  (5244 = 7242)  (5245 = 7242)  (5249 = 7242)  (5311 = 7214)  (5312 = 7122)  (5313 = 7131)  (5314 = 7136)  (5315 = 7124)  (5316 = 7135)  (5319 = 7121)  (5321 = 7133)  (5322 = 7132)  (5323 = 7141)  (5411 = 7432)  (5412 = 7437)  (5413 = 7442)  (5414 = 7433)  (5419 = 7430)  (5421 = 7341)  (5422 = 7341)  (5423 = 7345)  (5424 = 7346)  (5431 = 7411)  (5432 = 7412)  (5433 = 7411)  (5434 = 5122)  (5491 = 7320)  (5492 = 7422)  (5493 = 7422)  (5494 = 7312)  (5495 = 7313)  (5496 = 3471)  (5499 = 7330)  (6111 = 5132)  (6112 = 5132)  (6113 = 5132)  (6114 = 5132)  (6115 = 5133)  (6121 = 5131)  (6122 = 5131)  (6123 = 5131)  (6124 = 5131)  (6131 = 3227)  (6139 = 3227)  (6211 = 5149)  (6212 = 4221)  (6213 = 5113)  (6214 = 5111)  (6215 = 5112)  (6219 = 5110)  (6221 = 5141)  (6222 = 5141)  (6231 = 5121)  (6232 = 9141)  (6291 = 5143)  (6292 = 7143)  (7111 = 5220)  (7112 = 5220)  (7113 = 9113)  (7121 = 9113)  (7122 = 9153)  (7123 = 9113)  (7124 = 5220)  (7125 = 3471)  (7129 = 3415)  (7211 = 4220)  (7212 = 4220)  (8111 = 8270)  (8112 = 8130)  (8113 = 8260)  (8114 = 8150)  (8115 = 8231)  (8116 = 8232)  (8117 = 8120)  (8118 = 8223)  (8119 = 8100)  (8121 = 8140)  (8122 = 8111)  (8123 = 8112)  (8124 = 8160)  (8125 = 8211)  (8126 = 8163)  (8129 = 8290)  (8131 = 8282)  (8132 = 8281)  (8133 = 8290)  (8134 = 8290)  (8135 = 7231)  (8136 = 8269)  (8137 = 8263)  (8138 = 8290)  (8139 = 8290)  (8141 = 7129)  (8142 = 9312)  (8143 = 9312)  (8149 = 9313)  (8211 = 8324)  (8212 = 8322)  (8213 = 8323)  (8214 = 8322)  (8215 = 3340)  (8216 = 8312)  (8217 = 8340)  (8218 = 9330)  (8219 = 9330)  (8221 = 8333)  (8222 = 8334)  (8223 = 8331)  (8229 = 8330)  (9111 = 9211)  (9112 = 9212)  (9119 = 9210)  (9121 = 9313)  (9129 = 9312)  (9131 = 9320)  (9132 = 9132)  (9133 = 9320)  (9134 = 9320)  (9139 = 9320)  (9141 = 9330)  (9149 = 9330)  (9211 = 9151)  (9219 = 9151)  (9221 = 9132)  (9222 = 9150)  (9223 = 9132)  (9224 = 5123)  (9225 = 5123)  (9226 = 9152)  (9229 = 9150)  (9231 = 9142)  (9232 = 9162)  (9233 = 9130)  (9234 = 9133)  (9235 = 9161)  (9239 = 9162)  (9241 = 9152)  (9242 = 5169)  (9243 = 9152)  (9244 = 5131)  (9245 = 9152)  (9249 = 9152)  (9251 = 5220)  (9259 = 9151) (nonmissing = 10000), gen(isco88_4d)
		drop soc*
		cd $other_data
		save temp2.dta, replace 
	restore

	append using temp2.dta
	erase temp1.dta
	erase temp2.dta

	preserve
		keep year isco88_4d entref poe_job
		drop if year<2003
		capture drop tag
		egen tag = tag(entref isco88_4d) if poe_job==1
		drop if tag==0
		drop tag year
		cd $other_data
		save temp_poe.dta, replace
	restore
	
	sort entref isco88_$soc_digits
	quietly merge m:1 entref isco88_$soc_digits using temp_poe, nogen update keepusing(poe_job)
	replace entry = 1 if tenure<=$max_tenure & year<2003
	replace poe   = 1 if poe_job==1 & year<2003 & sjd==2
	erase temp_poe.dta

	replace tenure=floor(tenure)
	replace tenure=0 if poe==1

	drop if logwage_cpi_99==1 | logearnings_cpi_99==1
	drop logwage_cpi_99 logearnings_cpi_99

	keep log* sex age tenure poe* colag ft idbr* sjd wgor he* gp*/*
	*/   entry year isco88_$soc_digits firm_start entref sic piden start now

	drop if wgor==0 | wgor==.
	drop if idbrsta==0 | idbrsta==8 | idbrsta==.
	
	sort entref isco88_$soc_digits
	egen jobid = group(entref isco88_$soc_digits)
	label variable jobid "Job ID"

	drop if poe_firm!=1
	cd $reg_results_poe_criteria
	save slim_1997_2016_3.dta, replace

	forvalue i = 4/10{
	
		global max_tenure	= 1		// Max years of tenure to be considered a new hire (years)
		global min_life		= 3		// Min years firm is required to exist
		global soc_digits	= "4d"	// Digits in the occupations coding that define a job within firms
		global min_hires_pc = 0.1	// Min number of hires in percent, firm-occ-year/total hires
		global min_time_pc  = 0.5	// Min percent of years of firm being present in dataset, when a job has to fulfil conditions above to be in baseline sample
		
		* THIS DATASET HAS BEEN CREATED WHEN "BASELINE SAMPLE" WAS CREATED *
		cd $created_datadir
		use data_before_min_hires.dta, clear

		* The following code is identical to "Baseline Creation", 
		* explanations of the code can be found there.
		
		drop if firm_life<$min_life

		sort entref isco88_$soc_digits year
		egen temp = tag(entref isco88_$soc_digits year) if (hires_occ >= `i') & entry==1
		bysort entref isco88_$soc_digits: egen rel_years = sum(temp) if entry==1
		drop hires_occ temp

		g poe=.
		replace poe=1 if (rel_years/firm_life)>=$min_time_pc & rel_years!=.
		label variable poe "Newly hired employee in POE job"
		drop rel_years

		sort entref
		bysort entref: egen poe_firm=sum(poe)
		replace poe_firm=1 if poe_firm>=1
		label variable poe_firm "Firm which is hiring through POE jobs"

		sort entref isco88_$soc_digits
		bysort entref isco88_$soc_digits: egen poe_job=sum(poe)
		replace poe_job=1 if poe_job>=1
		label variable poe_job "POE job"

		preserve
			keep entref poe_firm
			drop if poe_firm==0

			sort entref
			egen tag = tag(entref)
			drop if tag==0
			drop tag
			cd $other_data
			save temp1.dta, replace
			
			cd $created_datadir
			use * if (year<=2002 & entref!=.) using ashe_1997_2016.dta, clear
			cd $other_data
			quietly merge m:1 entref using temp1, nogen keep(1 3 4 5)
			
			recode soc00_4d (1111 = 1110)  (1112 = 1210)  (1113 = 1110)  (1114 = 1140)  (1121 = 1222)  (1122 = 1223)  (1123 = 1222)  (1131 = 1231)  (1132 = 1233)  (1133 = 1235)  (1134 = 1234)  (1135 = 1232)  (1136 = 1236)  (1137 = 1237)  (1141 = 1239)  (1142 = 1239)  (1151 = 1227)  (1152 = 1231)  (1161 = 1226)  (1162 = 1226)  (1163 = 1224)  (1171 = 100)  (1172 = 3450)  (1173 = 1229)  (1174 = 1239)  (1181 = 1229)  (1182 = 1319)  (1183 = 1319)  (1184 = 1229)  (1185 = 1318)  (1211 = 1311)  (1212 = 1311)  (1219 = 1311)  (1221 = 1315)  (1222 = 1227)  (1223 = 1315)  (1224 = 1315)  (1225 = 1319)  (1226 = 1316)  (1231 = 1317)  (1232 = 1314)  (1233 = 1318)  (1234 = 1314)  (1235 = 1319)  (1239 = 1319)  (2111 = 2113)  (2112 = 2211)  (2113 = 2110)  (2121 = 2142)  (2122 = 2145)  (2123 = 2143)  (2124 = 2144)  (2125 = 2146)  (2126 = 2149)  (2127 = 2149)  (2128 = 2149)  (2129 = 2149)  (2131 = 2130)  (2132 = 2130)  (2211 = 2221)  (2212 = 2445)  (2213 = 2224)  (2214 = 2229)  (2215 = 2222)  (2216 = 2223)  (2311 = 2310)  (2312 = 2310)  (2313 = 2352)  (2314 = 2320)  (2315 = 2330)  (2316 = 2340)  (2317 = 2359)  (2319 = 2359)  (2321 = 2110)  (2322 = 2440)  (2329 = 2310)  (2411 = 2420)  (2419 = 2429)  (2421 = 2411)  (2422 = 2411)  (2423 = 2419)  (2431 = 2141)  (2432 = 2141)  (2433 = 2148)  (2434 = 2148)  (2441 = 2470)  (2442 = 2446)  (2443 = 2446)  (2444 = 2460)  (2451 = 2432)  (2452 = 2431)  (3111 = 3111)  (3112 = 3114)  (3113 = 3110)  (3114 = 3112)  (3115 = 3119)  (3119 = 3119)  (3121 = 3119)  (3122 = 3118)  (3123 = 3151)  (3131 = 3120)  (3132 = 3120)  (3211 = 3231)  (3212 = 3232)  (3213 = 3221)  (3214 = 3133)  (3215 = 3226)  (3216 = 3224)  (3217 = 3228)  (3218 = 3220)  (3221 = 3226)  (3222 = 3226)  (3223 = 3226)  (3229 = 3226)  (3231 = 3460)  (3232 = 3460)  (3311 = 100)  (3312 = 5162)  (3313 = 5161)  (3314 = 5163)  (3319 = 5169)  (3411 = 2452)  (3412 = 2451)  (3413 = 3470)  (3414 = 3473)  (3415 = 3473)  (3416 = 2455)  (3421 = 3471)  (3422 = 3471)  (3431 = 2451)  (3432 = 3472)  (3433 = 3419)  (3434 = 3131)  (3441 = 3475)  (3442 = 3475)  (3443 = 3475)  (3449 = 3475)  (3511 = 3144)  (3512 = 3143)  (3513 = 3142)  (3514 = 8311)  (3520 = 3432)  (3531 = 3417)  (3532 = 3411)  (3533 = 3412)  (3534 = 3419)  (3535 = 3442)  (3536 = 3422)  (3537 = 3433)  (3539 = 3419)  (3541 = 3416)  (3542 = 3415)  (3543 = 3419)  (3544 = 3413)  (3551 = 3210)  (3552 = 3210)  (3561 = 3449)  (3562 = 2412)  (3563 = 3340)  (3564 = 2412)  (3565 = 3152)  (3566 = 3152)  (3567 = 3152)  (3568 = 3152)  (4111 = 4190)  (4112 = 4190)  (4113 = 4190)  (4114 = 4190)  (4121 = 4120)  (4122 = 4120)  (4123 = 4210)  (4131 = 4141)  (4132 = 4190)  (4133 = 4131)  (4134 = 4133)  (4135 = 4141)  (4136 = 4113)  (4137 = 4190)  (4141 = 4223)  (4142 = 4223)  (4150 = 4190)  (4211 = 4115)  (4212 = 4115)  (4213 = 4115)  (4214 = 4115)  (4215 = 4115)  (4216 = 4222)  (4217 = 4110)  (5111 = 6130)  (5112 = 6112)  (5113 = 6112)  (5119 = 6150)  (5211 = 7221)  (5212 = 7211)  (5213 = 7213)  (5214 = 7214)  (5215 = 7212)  (5216 = 7136)  (5221 = 7223)  (5222 = 7222)  (5223 = 7230)  (5224 = 7311)  (5231 = 7231)  (5232 = 7213)  (5233 = 7241)  (5234 = 7141)  (5241 = 7137)  (5242 = 7244)  (5243 = 7245)  (5244 = 7242)  (5245 = 7242)  (5249 = 7242)  (5311 = 7214)  (5312 = 7122)  (5313 = 7131)  (5314 = 7136)  (5315 = 7124)  (5316 = 7135)  (5319 = 7121)  (5321 = 7133)  (5322 = 7132)  (5323 = 7141)  (5411 = 7432)  (5412 = 7437)  (5413 = 7442)  (5414 = 7433)  (5419 = 7430)  (5421 = 7341)  (5422 = 7341)  (5423 = 7345)  (5424 = 7346)  (5431 = 7411)  (5432 = 7412)  (5433 = 7411)  (5434 = 5122)  (5491 = 7320)  (5492 = 7422)  (5493 = 7422)  (5494 = 7312)  (5495 = 7313)  (5496 = 3471)  (5499 = 7330)  (6111 = 5132)  (6112 = 5132)  (6113 = 5132)  (6114 = 5132)  (6115 = 5133)  (6121 = 5131)  (6122 = 5131)  (6123 = 5131)  (6124 = 5131)  (6131 = 3227)  (6139 = 3227)  (6211 = 5149)  (6212 = 4221)  (6213 = 5113)  (6214 = 5111)  (6215 = 5112)  (6219 = 5110)  (6221 = 5141)  (6222 = 5141)  (6231 = 5121)  (6232 = 9141)  (6291 = 5143)  (6292 = 7143)  (7111 = 5220)  (7112 = 5220)  (7113 = 9113)  (7121 = 9113)  (7122 = 9153)  (7123 = 9113)  (7124 = 5220)  (7125 = 3471)  (7129 = 3415)  (7211 = 4220)  (7212 = 4220)  (8111 = 8270)  (8112 = 8130)  (8113 = 8260)  (8114 = 8150)  (8115 = 8231)  (8116 = 8232)  (8117 = 8120)  (8118 = 8223)  (8119 = 8100)  (8121 = 8140)  (8122 = 8111)  (8123 = 8112)  (8124 = 8160)  (8125 = 8211)  (8126 = 8163)  (8129 = 8290)  (8131 = 8282)  (8132 = 8281)  (8133 = 8290)  (8134 = 8290)  (8135 = 7231)  (8136 = 8269)  (8137 = 8263)  (8138 = 8290)  (8139 = 8290)  (8141 = 7129)  (8142 = 9312)  (8143 = 9312)  (8149 = 9313)  (8211 = 8324)  (8212 = 8322)  (8213 = 8323)  (8214 = 8322)  (8215 = 3340)  (8216 = 8312)  (8217 = 8340)  (8218 = 9330)  (8219 = 9330)  (8221 = 8333)  (8222 = 8334)  (8223 = 8331)  (8229 = 8330)  (9111 = 9211)  (9112 = 9212)  (9119 = 9210)  (9121 = 9313)  (9129 = 9312)  (9131 = 9320)  (9132 = 9132)  (9133 = 9320)  (9134 = 9320)  (9139 = 9320)  (9141 = 9330)  (9149 = 9330)  (9211 = 9151)  (9219 = 9151)  (9221 = 9132)  (9222 = 9150)  (9223 = 9132)  (9224 = 5123)  (9225 = 5123)  (9226 = 9152)  (9229 = 9150)  (9231 = 9142)  (9232 = 9162)  (9233 = 9130)  (9234 = 9133)  (9235 = 9161)  (9239 = 9162)  (9241 = 9152)  (9242 = 5169)  (9243 = 9152)  (9244 = 5131)  (9245 = 9152)  (9249 = 9152)  (9251 = 5220)  (9259 = 9151) (nonmissing = 10000), gen(isco88_4d)
			drop soc*
			cd $other_data
			save temp2.dta, replace 
		restore

		append using temp2.dta
		erase temp1.dta
		erase temp2.dta

		preserve
			keep year isco88_4d entref poe_job
			drop if year<2003
			capture drop tag
			egen tag = tag(entref isco88_4d) if poe_job==1
			drop if tag==0
			drop tag year
			cd $other_data
			save temp_poe.dta, replace
		restore
		
		sort entref isco88_$soc_digits
		quietly merge m:1 entref isco88_$soc_digits using temp_poe, nogen update keepusing(poe_job)
		replace entry = 1 if tenure<=$max_tenure & year<2003
		replace poe   = 1 if poe_job==1 & year<2003 & sjd==2
		erase temp_poe.dta

		replace tenure=floor(tenure)
		replace tenure=0 if poe==1

		drop if logwage_cpi_99==1 | logearnings_cpi_99==1
		drop logwage_cpi_99 logearnings_cpi_99

		keep log* sex age tenure poe* colag ft idbr* sjd wgor he* gp*/*
		*/   entry year isco88_$soc_digits firm_start entref sic piden start now

		drop if wgor==0 | wgor==.
		drop if idbrsta==0 | idbrsta==8 | idbrsta==.
		
		sort entref isco88_$soc_digits
		egen jobid = group(entref isco88_$soc_digits)
		label variable jobid "Job ID"

		drop if poe_firm!=1
		cd $reg_results_poe_criteria
		save slim_1997_2016_`i'.dta, replace

	}

}

}

*** RUN REGRESSION ***
if $regressions==1{
	
/* TABLE 3 & 6 */{

	* Set globals, i.e. which results are generated
	global reg_baseline	= 1 // Baseline results
	global FT_controls	= 1 // Controlling for full-time employee share
	global create_row3	= 1 // Job hires in at 25% of years when firm exists
	global max_sample	= 1 // All jobs observed at least twice
	global wls_1_stage	= 1 // WLS (number of employees)
	global other_pay	= 1 // Other pay and overtime included
	global occ_3d		= 1 // 3-digit occupations define a job

	if $reg_baseline==1{
	/* Define regression programme */{
		capture program drop reg_wages
		program define reg_wages

		* Keep only private enterprises
		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		sort jobid year
		
		*** COVARIATES
		foreach k in age idbrnemp{
			by jobid year: egen `k'_j = median(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		replace sex = 0 if sex==2
		foreach k in colag sex{
			by jobid year: egen `k'_j = mean(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		foreach p in logwage_cpi loghours{
			by jobid year: egen `p'_med = median(`p')
			drop `p'
			}

		* Keep one obs per job and year
		egen tag = tag(jobid year)
		keep if tag==1
		drop tag
		
		* Compute the average age over all new hires in all years for normalisation
		egen asd_age = mean(age)
		* Create covariates
		g agesq 		= (age-asd_age)^2
		g agecub 		= (age-asd_age)^3
		g idbrnempsq 	= idbrnemp^2

		* Set panel and time series variables
		xtset, clear
		xtset jobid year

		* Year dummies
		quietly tab year, gen(d)
		
		foreach k in logwage_cpi_med loghours_med{
			preserve
				quietly areg `k' d2-d19 age agesq agecub idbrnemp idbrnempsq sex colag, absorb(jobid) vce(cluster jobid)
				matrix b = e(b)
				clear
				svmat b
				forvalue i=1/18 {
				rename b`i' c`i'
				}
				drop b*
				xpose, clear
				capture drop year
				gen year=_n + 1998
				gen se=.
				forvalue i = 2/19{
					quietly replace se=_se[d`i'] if year==1997+`i'
				}	
				quietly rename se `k'_se`1'
				quietly rename v1 `k'`1'
				cd $reg_resultsdir_97_16 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_resultsdir_97_16 
		use beta_logwage_cpi_med, clear
		quietly merge 1:1 year using beta_loghours_med, nogen
		save results_`1'.dta, replace
		
		capture erase beta_logwage_cpi_med.dta
		capture erase beta_loghours_med.dta
		
		end

		* end areg programme
	}
	/* New hires - wages and hours */{

		cd $created_datadir
		use slim_1997_2016, clear

		* define sample to be analysed
		drop if poe!=1

		* Run the regression program
		reg_wages 1
		
	}
	/* Job stayers - wages and hours */{

		cd $created_datadir
		use slim_1997_2016, clear

		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		xtset, clear
		xtset piden year

		drop poe* w*
		drop if idbrnemp==0

		replace sex = 0 if sex==1
		replace sex = 1 if sex==2

		forvalues i = 2016(-1)1999{
			preserve
				local k = `i' - 1
				keep if (year == `i') | (year == `k')
				keep piden jobid year age tenure idbrnemp log* sjd entref sex colag ft sic
				
				* Keep only employees who are observed in the same job consecutively
				sort piden year
				capture drop f`i'
				quiet gen f`i' = .
				quiet by piden: replace f`i'=1 if L.jobid==jobid & year == `i' & sjd==1 

				capture drop b`k'
				quiet gen b`k' = .
				quiet by piden: replace b`k'=1 if F.jobid==jobid & year == `k' & F.sjd==1
				
				sort jobid year
				capture drop temp
				capture drop temp2
				by jobid year: egen temp 	= count(f`i')
				by jobid year: egen temp2 	= count(b`k')
				
				* Drop if the minimum number of job stayers is not fulfilled - 3 in the baseline sample
				drop if temp<3 & year == `i'
				drop if temp2<3 & year == `k'
				
				sort jobid year
				foreach x of varlist colag sex ft sic{
					* Compute the variables at the job level for job stayers
					by jobid year: egen asd_`x'_`i' = mean(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = mean(`x') if b`k'==1
					* Simply copy the above computed values for all workers
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}
				foreach x of varlist age tenure idbrnemp{
					by jobid year: egen asd_`x'_`i' = median(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = median(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}		
				foreach x of varlist logwage_cpi loghours{
					by jobid year: egen asd_`x'_`i' = median(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = median(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				} 		
				
				drop f`i' b`k'
				
				* keep one obs per job (not necessary to condition on job stayer, because values of job stayers at job-level have been copied to all workers in the code above)
				capture drop tag
				egen tag = tag(jobid)
				drop if tag==0
				drop tag

				* compute the mean age and tenure for normalisation
				egen asd_age = mean(age_`i')
				egen asd_ten = mean(tenure_`i')
				sort jobid
				foreach x of varlist age_`k' age_`i'{
					by jobid: gen sq`x' = (`x'-asd_age)^2
					by jobid: gen cub`x' = (`x'-asd_age)^3
				}	
				foreach x of varlist tenure_`k' tenure_`i'{
					by jobid: gen sq`x' = (`x'-asd_ten)^2
					by jobid: gen cub`x' = (`x'-asd_ten)^3
				}				
				
				keep jobid temp2 sic age_* loghours_* colag_* sex_* ft_* sqtenure_* sqage_* cubtenure_* cubage_* idbrnemp_* logwage_cpi_* entref

				quietly reshape long age_ loghours_ colag_ sex_ ft_ sqtenure_ sqage_ cubtenure_ cubage_ idbrnemp_ logwage_cpi_ , i(jobid) j(year)
				
				rename idbrnemp_ asd
				g id = `i'
				rename asd idbrnemp_
				
				cd $reg_resultsdir_97_16
				save temp`i'.dta, replace
			restore
		}

		* create empty dataset
		cd $reg_resultsdir_97_16
		use temp2016.dta, clear
		forvalues i = 2015(-1)1999{
			append using temp`i'.dta
			capture erase temp`i'.dta
		}

		rename *_ *

		cd $reg_resultsdir_97_16
		save stayer_data_baseline.dta, replace
		capture erase temp2016.dta

		sort entref
		by entref: egen firm_end=max(year)
		by entref: egen firm_start=min(year)
		g firm_life=firm_end-firm_start+1
		drop entref

		* Keep only jobs which are observed for at least 50% of the years for which the firm exists
		sort jobid
		egen tag = tag(jobid year)
		replace tag=. if tag==0
		by jobid: egen rel_years = sum(tag)
		drop if (rel_years/firm_life)<0.5 & rel_years!=.
		drop rel_years tag firm*

		*** create weights for WLS in second stage
		preserve
			sort year
			egen tag = tag(jobid year)
			replace tag=. if tag==0
			by year: egen y_sum = count(tag)
			egen tot = count(tag)
			gen stayer_weights = y_sum/tot
			capture drop tag
			egen tag = tag(year)
			drop if tag==0
			keep year stayer_weights
			
			cd $created_datadir
			save stayer_year_weights.dta, replace
		restore

		* temp2 is the number of job stayers in each job per year
		rename temp2 weighting

		egen temp = group(jobid id)
		drop jobid id
		rename temp jobid

		xtset, clear
		xtset jobid year

		quietly tab year, gen(d)

		gen ind = 0 
		by jobid: replace ind = 1 if _n==2
		* save number of stayer jobs per year for weighted productivity regressions
		preserve
			keep if ind == 1
			keep year sic
			cd $created_datadir
			save stayer_weights_prod.dta, replace
		restore
		
		foreach k in logwage_cpi loghours{
			quietly areg `k' d2-d19 idbrnemp sqage sqtenure cubage cubtenure colag, absorb(jobid) vce(cluster jobid)
			preserve
				clear
				set obs 18
				gen year = _n + 1998
				gen beta = .
				gen beta_se = .
				forvalue i = 2/19{
					quietly replace beta=_b[d`i'] if year == 1997+`i'
					quietly replace beta_se=_se[d`i'] if year == 1997+`i'
				}
				
				quietly rename beta_se `k'_med_se2
				quietly rename beta `k'_med2
				cd $reg_resultsdir_97_16 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_resultsdir_97_16
		use beta_logwage_cpi, clear
		quietly merge 1:1 year using beta_loghours, nogen
		save results_2.dta, replace
			
		capture erase temp2016.dta
		capture erase beta_loghours.dta
		capture erase beta_logwage_cpi.dta

	}

	cd $other_data
	use econ, clear
	cd $reg_resultsdir_97_16
	quietly merge 1:1 year using results_1, nogen
	quietly merge 1:1 year using results_2, nogen
	drop if year==1997
	
	save results_97_16.dta, replace
	capture erase results_1.dta
	capture erase results_2.dta
	
	/* Second step regression */{
	
		tsset year

		foreach p in logwage_cpi loghours{
			foreach k in unemp log_prod_gdp log_prod_ser{
				forvalue i =1/2{
					preserve
						quietly newey `p'_med`i' `k' year, lag(1)
						clear
						set obs 1
						gen b_`k' = _b[`k']
						gen se_`k' = _se[`k']
						gen spec= `i'
						cd $reg_results_2nd_stage
						save `p'`k'`i'.dta, replace
					restore
				}
			}
		}

		foreach p in logwage_cpi loghours{
			foreach k in unemp log_prod_gdp log_prod_ser{
				cd $reg_results_2nd_stage
				use `p'`k'1, clear
				quietly append using `p'`k'2
				erase `p'`k'2.dta
				save `p'`k'.dta, replace
				erase `p'`k'1.dta
			}
		}

		foreach p in logwage_cpi loghours{
			cd $reg_results_2nd_stage
			use `p'unemp, clear
			foreach k in log_prod_gdp log_prod_ser{
				quietly merge 1:1 spec using `p'`k', nogen
				save `p'.dta, replace
				erase `p'`k'.dta
			}
			erase `p'unemp.dta
		}

		
}

}

	if $FT_controls==1{
	/* Define regression programme */{
		capture program drop reg_wages
		program define reg_wages

		* Keep only private enterprises
		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		sort jobid year
		
		*** COVARIATES
		foreach k in age idbrnemp{
			by jobid year: egen `k'_j = median(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		replace sex = 0 if sex==2
		foreach k in colag sex ft{
			by jobid year: egen `k'_j = mean(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		foreach p in logwage_cpi loghours{
			by jobid year: egen `p'_med = median(`p')
			drop `p'
			}

		* Keep one obs per job and year
		egen tag = tag(jobid year)
		keep if tag==1
		drop tag

		* Compute the average age over all new hires in all years for normalisation
		egen asd_age = mean(age)
		* Create covariates
		g agesq 		= (age-asd_age)^2
		g agecub 		= (age-asd_age)^3
		g idbrnempsq 	= idbrnemp^2

		* Set panel and time series variables
		xtset, clear
		xtset jobid year

		* Year dummies
		quietly tab year, gen(d)
		
		foreach k in logwage_cpi_med loghours_med{
			preserve
				quietly areg `k' d2-d19 ft age agesq agecub idbrnemp idbrnempsq sex colag, absorb(jobid) vce(cluster jobid)
				matrix b = e(b)
				clear
				svmat b
				forvalue i=1/18 {
				rename b`i' c`i'
				}
				drop b*
				xpose, clear
				capture drop year
				gen year=_n + 1998
				gen se=.
				forvalue i = 2/19{
					quietly replace se=_se[d`i'] if year==1997+`i'
				}	
				quietly rename se `k'_se`1'
				quietly rename v1 `k'`1'
				cd $reg_results_ft 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_ft 
		use beta_logwage_cpi_med, clear
		quietly merge 1:1 year using beta_loghours_med, nogen
		save results_`1'.dta, replace
		
		capture erase beta_logwage_cpi_med.dta
		capture erase beta_loghours_med.dta
		
		end

		* end areg programme
	}
	/* New hires - wages and hours */{

		cd $created_datadir
		use slim_1997_2016, clear

		* define sample to be analysed
		drop if poe!=1

		* Run the regression program
		reg_wages 1
		
	}
	/* Job stayers - wages and hours */{

		cd $reg_resultsdir_97_16
		use stayer_data_baseline.dta, clear

		sort entref
		by entref: egen firm_end=max(year)
		by entref: egen firm_start=min(year)
		gen firm_life=firm_end-firm_start+1
		drop entref

		* Keep only jobs which are observed for at least 50% of the years for which the firm exists
		sort jobid
		egen tag = tag(jobid year)
		replace tag=. if tag==0
		by jobid: egen rel_years = sum(tag)
		drop if (rel_years/firm_life)<0.5 & rel_years!=.
		drop rel_years tag firm*

		* temp2 is the number of job stayers in each job per year
		rename temp2 weighting

		egen temp = group(jobid id)
		drop jobid id
		rename temp jobid

		xtset, clear
		xtset jobid year

		quietly tab year, gen(d)

		g ind = 0 
		by jobid: replace ind = 1 if _n==2
		
		foreach k in logwage_cpi loghours{
			quietly areg `k' d2-d19 ft idbrnemp sqage sqtenure cubage cubtenure colag, absorb(jobid) vce(cluster jobid)
			preserve
				clear
				set obs 18
				gen year = _n + 1998
				gen beta = .
				gen beta_se = .
				forvalue i = 2/19{
					quietly replace beta=_b[d`i'] if year == 1997+`i'
					quietly replace beta_se=_se[d`i'] if year == 1997+`i'
				}
				
				quietly rename beta_se `k'_med_se2
				quietly rename beta `k'_med2
				cd $reg_results_ft 
				save beta_`k'.dta, replace
			restore
		}
		
		cd $reg_results_ft
		use beta_logwage_cpi, clear
		quietly merge 1:1 year using beta_loghours, nogen
		save results_2.dta, replace

		capture erase beta_loghours.dta
		capture erase beta_logwage_cpi.dta
		
	}

	* Combine the data
	cd $other_data
	use econ, clear
	cd $reg_results_ft
	quietly merge 1:1 year using results_1, nogen
	quietly merge 1:1 year using results_2, nogen
	drop if year==1997

	save results_97_16.dta, replace
	capture erase results_1.dta
	capture erase results_2.dta

	/* Second step regression */{
	
		tsset year

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				forvalue i =1/2{
					preserve
						quietly newey `p'_med`i' `k' year, lag(1)
						clear
						set obs 1
						gen b_`k' = _b[`k']
						gen se_`k' = _se[`k']
						gen spec= `i'
						cd $reg_results_ft
						save `p'`k'`i'.dta, replace
					restore
				}
			}
		}

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				cd $reg_results_ft
				use `p'`k'1, clear
				quietly append using `p'`k'2
				erase `p'`k'2.dta
				save `p'`k'.dta, replace
				erase `p'`k'1.dta
			}
		}

		foreach p in logwage_cpi loghours{
			cd $reg_results_ft
			use `p'unemp, clear
			save `p'.dta, replace
			erase `p'unemp.dta
		}

		
}

}

	if $create_row3==1{
	/* Define regression programme */{
		capture program drop reg_wages
		program define reg_wages

		* Keep only private enterprises
		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		sort jobid year
		
		*** COVARIATES
		foreach k in age idbrnemp{
			by jobid year: egen `k'_j = median(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		replace sex = 0 if sex==2
		foreach k in colag sex{
			by jobid year: egen `k'_j = mean(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		foreach p in logwage_cpi loghours{
			by jobid year: egen `p'_med = median(`p')
			drop `p'
			}

		* Keep one obs per job and year
		egen tag = tag(jobid year)
		keep if tag==1
		drop tag

		* Compute the average age over all new hires in all years for normalisation
		egen asd_age = mean(age)
		* Create covariates
		g agesq 		= (age-asd_age)^2
		g agecub 		= (age-asd_age)^3
		g idbrnempsq 	= idbrnemp^2

		* Set panel and time series variables
		xtset, clear
		xtset jobid year

		* Year dummies
		quietly tab year, gen(d)
		
		foreach k in logwage_cpi_med loghours_med{
			preserve
				quietly areg `k' d2-d19 age agesq agecub idbrnemp idbrnempsq sex colag, absorb(jobid) vce(cluster jobid)
				matrix b = e(b)
				clear
				svmat b
				forvalue i=1/18 {
				rename b`i' c`i'
				}
				drop b*
				xpose, clear
				capture drop year
				gen year=_n + 1998
				gen se=.
				forvalue i = 2/19{
					quietly replace se=_se[d`i'] if year==1997+`i'
				}	
				quietly rename se `k'_se`1'
				quietly rename v1 `k'`1'
				cd $reg_results_poe_criteria 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_poe_criteria 
		use beta_logwage_cpi_med, clear
		quietly merge 1:1 year using beta_loghours_med, nogen
		save results_`1'.dta, replace
		
		capture erase beta_logwage_cpi_med.dta
		capture erase beta_loghours_med.dta
		
		end

		* end areg programme
	}
	/* New hires - wages and hours */{

		cd $reg_results_poe_criteria
		use slim_1997_2016_2, clear

		* define sample to be analysed
		drop if poe!=1

		* Run the regression program
		reg_wages 1
		
	}
	/* Job stayers - wages and hours */{

		cd $reg_resultsdir_97_16
		use stayer_data_baseline.dta, clear

		sort entref
		by entref: egen firm_end=max(year)
		by entref: egen firm_start=min(year)
		g firm_life=firm_end-firm_start+1
		drop if firm_life<5
		drop entref

		* Keep only jobs which are observed for at least 50% of the years for which the firm exists
		sort jobid
		egen tag = tag(jobid year)
		replace tag=. if tag==0
		by jobid: egen rel_years = sum(tag)
		drop if (rel_years/firm_life)<0.25 & rel_years!=.
		drop rel_years tag firm*

		* temp2 is the number of job stayers in each job per year
		rename temp2 weighting

		egen temp = group(jobid id)
		drop jobid id
		rename temp jobid

		xtset, clear
		xtset jobid year

		quietly tab year, gen(d)

		g ind = 0 
		by jobid: replace ind = 1 if _n==2
		
		foreach k in logwage_cpi loghours{
			quietly areg `k' d2-d19 idbrnemp sqage sqtenure cubage cubtenure colag, absorb(jobid) vce(cluster jobid)
			preserve
				clear
				set obs 18
				gen year = _n + 1998
				gen beta = .
				gen beta_se = .
				forvalue i = 2/19{
					quietly replace beta=_b[d`i'] if year == 1997+`i'
					quietly replace beta_se=_se[d`i'] if year == 1997+`i'
				}
				
				quietly rename beta_se `k'_med_se2
				quietly rename beta `k'_med2
				cd $reg_results_poe_criteria 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_poe_criteria
		use beta_logwage_cpi, clear
		quietly merge 1:1 year using beta_loghours, nogen
		save results_2.dta, replace
			
		capture erase temp2016.dta
		capture erase beta_loghours.dta
		capture erase beta_logwage_cpi.dta

	}

	cd $other_data
	use econ, clear
	cd $reg_results_poe_criteria
	quietly merge 1:1 year using results_1, nogen
	quietly merge 1:1 year using results_2, nogen
	drop if year==1997

	save results_97_16_2.dta, replace
	capture erase results_1.dta
	capture erase results_2.dta

	/* Second step regression */{
	
		tsset year

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				forvalue i =1/2{
					preserve
						quietly newey `p'_med`i' `k' year, lag(1)
						clear
						set obs 1
						gen b_`k' = _b[`k']
						gen se_`k' = _se[`k']
						gen spec= `i'
						cd $reg_results_poe_criteria
						save `p'`k'`i'.dta, replace
					restore
				}
			}
		}

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				cd $reg_results_poe_criteria
				use `p'`k'1, clear
				quietly append using `p'`k'2
				erase `p'`k'2.dta
				save `p'`k'.dta, replace
				erase `p'`k'1.dta
			}
		}

		foreach p in logwage_cpi loghours{
			cd $reg_results_poe_criteria
			use `p'unemp, clear
			save `p'2.dta, replace
			erase `p'unemp.dta
		}

		
	}
	
}

	if $max_sample==1{
	/* Define regression programme */{
		capture program drop reg_wages
		program define reg_wages

		* Keep only private enterprises
		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		sort jobid year
		
		*** COVARIATES
		foreach k in age idbrnemp{
			by jobid year: egen `k'_j = median(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		replace sex = 0 if sex==2
		foreach k in colag sex{
			by jobid year: egen `k'_j = mean(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		foreach p in logwage_cpi loghours{
			by jobid year: egen `p'_med = median(`p')
			drop `p'
			}

		* Keep one obs per job and year
		egen tag = tag(jobid year)
		keep if tag==1
		drop tag

		* Compute the average age over all new hires in all years for normalisation
		egen asd_age = mean(age)
		* Create covariates
		g agesq 		= (age-asd_age)^2
		g agecub 		= (age-asd_age)^3
		g idbrnempsq 	= idbrnemp^2

		* Set panel and time series variables
		xtset, clear
		xtset jobid year

		* Year dummies
		quietly tab year, gen(d)
		
		foreach k in logwage_cpi_med loghours_med{
			preserve
				quietly areg `k' d2-d19 age agesq agecub idbrnemp idbrnempsq sex colag, absorb(jobid) vce(cluster jobid)
				matrix b = e(b)
				clear
				svmat b
				forvalue i=1/18 {
				rename b`i' c`i'
				}
				drop b*
				xpose, clear
				capture drop year
				gen year=_n + 1998
				gen se=.
				forvalue i = 2/19{
					quietly replace se=_se[d`i'] if year==1997+`i'
				}	
				quietly rename se `k'_se`1'
				quietly rename v1 `k'`1'
				cd $reg_results_poe_criteria 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_poe_criteria 
		use beta_logwage_cpi_med, clear
		quietly merge 1:1 year using beta_loghours_med, nogen
		save results_`1'.dta, replace
		
		capture erase beta_logwage_cpi_med.dta
		capture erase beta_loghours_med.dta
		
		end

		* end areg programme
	}
	/* New hires - wages and hours */{

		cd $reg_results_poe_criteria
		use slim_1997_2016_all_max, clear

		* define sample to be analysed
		drop if poe!=1

		* Run the regression program
		reg_wages 1
		
	}
	/* Job stayers - wages and hours */{

		cd $reg_results_poe_criteria
		use slim_1997_2016_all_max, clear

		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		xtset, clear
		xtset piden year

		drop poe* w*
		drop if idbrnemp==0

		replace sex = 0 if sex==1
		replace sex = 1 if sex==2

		forvalues i = 2016(-1)1999{
			preserve
				local k = `i' - 1
				keep if (year == `i') | (year == `k')
				keep piden jobid year age tenure idbrnemp log* sjd entref sex colag ft sic
				
				* Keep only employees who are observed in the same job consecutively
				sort piden year
				capture drop f`i'
				quiet gen f`i' = .
				quiet by piden: replace f`i'=1 if L.jobid==jobid & year == `i' & sjd==1 

				capture drop b`k'
				quiet gen b`k' = .
				quiet by piden: replace b`k'=1 if F.jobid==jobid & year == `k' & F.sjd==1
				
				sort jobid year
				capture drop temp
				capture drop temp2
				by jobid year: egen temp 	= count(f`i')
				by jobid year: egen temp2 	= count(b`k')
				
				* Drop if the minimum number of job stayers is not fulfilled - 3 in the baseline sample
				drop if temp<1 & year == `i'
				drop if temp2<1 & year == `k'
				
				*drop temp temp2
				
				sort jobid year
				foreach x of varlist colag sex ft sic{
					by jobid year: egen asd_`x'_`i' = mean(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = mean(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}
				foreach x of varlist age tenure idbrnemp{
					by jobid year: egen asd_`x'_`i' = median(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = median(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}		
				foreach x of varlist logwage_cpi loghours{
					by jobid year: egen asd_`x'_`i' = median(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = median(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				} 		
				drop f`i' b`k'
				
				capture drop tag
				egen tag = tag(jobid)
				drop if tag==0
				drop tag

				* compute the mean age and tenure for normalisation
				egen asd_age = mean(age_`i')
				egen asd_ten = mean(tenure_`i')
				sort jobid
				foreach x of varlist age_`k' age_`i'{
					by jobid: gen sq`x' = (`x'-asd_age)^2
					by jobid: gen cub`x' = (`x'-asd_age)^3
				}	
				foreach x of varlist tenure_`k' tenure_`i'{
					by jobid: gen sq`x' = (`x'-asd_ten)^2
					by jobid: gen cub`x' = (`x'-asd_ten)^3
				}				
				
				keep jobid temp2 sic age_* loghours_* colag_* sex_* ft_* sqtenure_* sqage_* cubtenure_* cubage_* idbrnemp_* logwage_cpi_* entref

				quietly reshape long age_ loghours_ colag_ sex_ ft_ sqtenure_ sqage_ cubtenure_ cubage_ idbrnemp_ logwage_cpi_ , i(jobid) j(year)
				
				rename idbrnemp_ asd
			
				g id = `i'
				
				rename asd idbrnemp_
				
				cd $reg_results_poe_criteria
				save temp`i'.dta, replace
			restore
		}

		* create empty dataset
		cd $reg_results_poe_criteria
		use temp2016.dta, clear
		forvalues i = 2015(-1)1999{
			append using temp`i'.dta
			capture erase temp`i'.dta
		}

		rename *_ *

		* temp2 is the number of job stayers in each job per year
		rename temp2 weighting

		egen temp = group(jobid id)
		drop jobid id
		rename temp jobid

		xtset, clear
		xtset jobid year

		quietly tab year, gen(d)
		
		foreach k in logwage_cpi loghours{
			quietly areg `k' d2-d19 idbrnemp sqage sqtenure cubage cubtenure colag, absorb(jobid) vce(cluster jobid)
			preserve
				clear
				set obs 18
				gen year = _n + 1998
				gen beta = .
				gen beta_se = .
				forvalue i = 2/19{
					quietly replace beta=_b[d`i'] if year == 1997+`i'
					quietly replace beta_se=_se[d`i'] if year == 1997+`i'
				}
				
				quietly rename beta_se `k'_med_se2
				quietly rename beta `k'_med2
				cd $reg_results_poe_criteria 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_poe_criteria
		use beta_logwage_cpi, clear
		quietly merge 1:1 year using beta_loghours, nogen
		save results_2.dta, replace
			
		capture erase temp2016.dta
		capture erase beta_loghours.dta
		capture erase beta_logwage_cpi.dta

	}

	cd $other_data
	use econ, clear
	cd $reg_results_poe_criteria
	quietly merge 1:1 year using results_1, nogen
	quietly merge 1:1 year using results_2, nogen
	drop if year==1997
	
	save results_97_16_max.dta, replace
	capture erase results_1.dta
	capture erase results_2.dta

	/* Second step regression */{
	
		tsset year

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				forvalue i =1/2{
					preserve
						quietly newey `p'_med`i' `k' year, lag(1)
						clear
						set obs 1
						gen b_`k' = _b[`k']
						gen se_`k' = _se[`k']
						gen spec= `i'
						cd $reg_results_poe_criteria
						save `p'`k'`i'.dta, replace
					restore
				}
			}
		}

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				cd $reg_results_poe_criteria
				use `p'`k'1, clear
				quietly append using `p'`k'2
				erase `p'`k'2.dta
				save `p'`k'.dta, replace
				erase `p'`k'1.dta
			}
		}

		foreach p in logwage_cpi loghours{
			cd $reg_results_poe_criteria
			use `p'unemp, clear
			save `p'max.dta, replace
			erase `p'unemp.dta
		}

		
	}

}

	if $wls_1_stage==1{
	/* Define regression programme */{
		capture program drop reg_wages
		program define reg_wages

		* Keep only private enterprises
		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		sort jobid year
		
		*** COVARIATES
		foreach k in age idbrnemp{
			by jobid year: egen `k'_j = median(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		replace sex = 0 if sex==2
		foreach k in colag sex{
			by jobid year: egen `k'_j = mean(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		foreach p in logwage_cpi loghours{
			by jobid year: egen `p'_med = median(`p')
			drop `p'
			}
			
		by jobid year: egen weight = count(piden)

		* Keep one obs per job and year
		egen tag = tag(jobid year)
		keep if tag==1
		drop tag

		* Compute the average age over all new hires in all years for normalisation
		egen asd_age = mean(age)
		* Create covariates
		g agesq 		= (age-asd_age)^2
		g agecub 		= (age-asd_age)^3
		g idbrnempsq 	= idbrnemp^2

		* Set panel and time series variables
		xtset, clear
		xtset jobid year

		* Year dummies
		quietly tab year, gen(d)
		
		foreach k in logwage_cpi_med loghours_med{
			preserve
				quietly areg `k' d2-d19 age agesq agecub idbrnemp idbrnempsq sex colag [aweight=weight], absorb(jobid) vce(cluster jobid)
				matrix b = e(b)
				clear
				svmat b
				forvalue i=1/18 {
				rename b`i' c`i'
				}
				drop b*
				xpose, clear
				capture drop year
				gen year=_n + 1998
				gen se=.
				forvalue i = 2/19{
					quietly replace se=_se[d`i'] if year==1997+`i'
				}	
				quietly rename se `k'_se`1'
				quietly rename v1 `k'`1'
				cd $reg_results_wls 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_wls 
		use beta_logwage_cpi_med, clear
		quietly merge 1:1 year using beta_loghours_med, nogen
		save results_`1'.dta, replace
		
		capture erase beta_logwage_cpi_med.dta
		capture erase beta_loghours_med.dta
		
		end

		* end areg programme
	}
	/* New hires - wages and hours */{

		cd $created_datadir
		use slim_1997_2016, clear

		* define sample to be analysed
		drop if poe!=1

		* Run the regression program
		reg_wages 1
		
	}
	/* Job stayers - wages and hours */{

		cd $created_datadir
		use slim_1997_2016, clear

		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		xtset, clear
		xtset piden year

		drop poe* w*
		drop if idbrnemp==0

		replace sex = 0 if sex==1
		replace sex = 1 if sex==2

		forvalues i = 2016(-1)1999{
			preserve
				local k = `i' - 1
				keep if (year == `i') | (year == `k')
				keep piden jobid year age tenure idbrnemp log* sjd entref sex colag ft sic
				
				* Keep only employees who are observed in the same job consecutively
				sort piden year
				capture drop f`i'
				quiet gen f`i' = .
				quiet by piden: replace f`i'=1 if L.jobid==jobid & year == `i' & sjd==1 

				capture drop b`k'
				quiet gen b`k' = .
				quiet by piden: replace b`k'=1 if F.jobid==jobid & year == `k' & F.sjd==1
				
				sort jobid year
				capture drop temp
				capture drop temp2
				by jobid year: egen temp 	= count(f`i')
				by jobid year: egen temp2 	= count(b`k')
				
				* Drop if the minimum number of job stayers is not fulfilled - 3 in the baseline sample
				drop if temp<3 & year == `i'
				drop if temp2<3 & year == `k'
				
				replace temp=. if temp==0
				by jobid: egen heads = mean(temp)
				
				sort jobid year
				foreach x of varlist colag sex ft sic{
					by jobid year: egen asd_`x'_`i' = mean(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = mean(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}
				foreach x of varlist age tenure idbrnemp{
					by jobid year: egen asd_`x'_`i' = median(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = median(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}		
				foreach x of varlist logwage_cpi loghours{
					by jobid year: egen asd_`x'_`i' = median(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = median(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				} 		
				drop f`i' b`k'
				
				capture drop tag
				egen tag = tag(jobid)
				drop if tag==0
				drop tag

				* compute the mean age and tenure for normalisation
				egen asd_age = mean(age_`i')
				egen asd_ten = mean(tenure_`i')
				sort jobid
				foreach x of varlist age_`k' age_`i'{
					by jobid: gen sq`x' = (`x'-asd_age)^2
					by jobid: gen cub`x' = (`x'-asd_age)^3
				}	
				foreach x of varlist tenure_`k' tenure_`i'{
					by jobid: gen sq`x' = (`x'-asd_ten)^2
					by jobid: gen cub`x' = (`x'-asd_ten)^3
				}			
				
				keep jobid heads temp2 sic age_* loghours_* colag_* sex_* ft_* sqtenure_* sqage_* cubtenure_* cubage_* idbrnemp_* logwage_cpi_* entref

				quietly reshape long age_ loghours_ colag_ sex_ ft_ sqtenure_ sqage_ cubtenure_ cubage_ idbrnemp_ logwage_cpi_ , i(jobid) j(year)
				
				rename idbrnemp_ asd
			
				g id = `i'
				
				rename asd idbrnemp_
				
				cd $reg_results_wls
				save temp`i'.dta, replace
			restore
		}

		* create empty dataset
		cd $reg_results_wls
		use temp2016.dta, clear
		forvalues i = 2015(-1)1999{
			append using temp`i'.dta
			capture erase temp`i'.dta
		}

		rename *_ *

		sort entref
		by entref: egen firm_end=max(year)
		by entref: egen firm_start=min(year)
		g firm_life=firm_end-firm_start+1
		drop entref

		* Keep only jobs which are observed for at least 50% of the years for which the firm exists
		sort jobid
		egen tag = tag(jobid year)
		replace tag=. if tag==0
		by jobid: egen rel_years = sum(tag)
		drop if (rel_years/firm_life)<0.5 & rel_years!=.
		drop rel_years tag firm*

		sort jobid year
		by jobid year: egen av = mean(heads)
		egen tot = sum(av)
		g weights = av/tot
		drop tot av heads

		egen temp = group(jobid id)
		drop jobid id
		rename temp jobid

		xtset, clear
		xtset jobid year

		quietly tab year, gen(d)

		g ind = 0 
		by jobid: replace ind = 1 if _n==2

		foreach k in logwage_cpi loghours{
			quietly areg `k' d2-d19 idbrnemp sqage sqtenure cubage cubtenure colag [aweight = weights], absorb(jobid) vce(cluster jobid)
			preserve
				clear
				set obs 18
				gen year = _n + 1998
				gen beta = .
				gen beta_se = .
				forvalue i = 2/19{
					quietly replace beta=_b[d`i'] if year == 1997+`i'
					quietly replace beta_se=_se[d`i'] if year == 1997+`i'
				}
				
				quietly rename beta_se `k'_med_se2
				quietly rename beta `k'_med2
				cd $reg_results_wls 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_wls
		use beta_logwage_cpi, clear
		quietly merge 1:1 year using beta_loghours, nogen
		save results_2.dta, replace
			
		capture erase temp2016.dta
		capture erase beta_loghours.dta
		capture erase beta_logwage_cpi.dta

	}
		
		cd $other_data
		use econ, clear
		cd $reg_results_wls
		quietly merge 1:1 year using results_1, nogen
		quietly merge 1:1 year using results_2, nogen
		drop if year==1997
	
		save results_97_16.dta, replace
		capture erase results_1.dta
		capture erase results_2.dta
		
	/* Second step regression */{
	
		tsset year

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				forvalue i =1/2{
					preserve
						quietly newey `p'_med`i' `k' year, lag(1)
						clear
						set obs 1
						gen b_`k' = _b[`k']
						gen se_`k' = _se[`k']
						gen spec= `i'
						cd $reg_results_poe_criteria
						save `p'`k'`i'.dta, replace
					restore
				}
			}
		}

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				cd $reg_results_poe_criteria
				use `p'`k'1, clear
				quietly append using `p'`k'2
				erase `p'`k'2.dta
				save `p'`k'.dta, replace
				erase `p'`k'1.dta
			}
		}

		foreach p in logwage_cpi loghours{
			cd $reg_results_poe_criteria
			use `p'unemp, clear
			save `p'_1.dta, replace
			erase `p'unemp.dta
		}

		
	}

}

	if $other_pay==1{
	/* Define regression programme */{
		capture program drop reg_wages
		program define reg_wages

		* Keep only private enterprises
		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		sort jobid year
		
		*** COVARIATES
		foreach k in age idbrnemp{
			by jobid year: egen `k'_j = median(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		replace sex = 0 if sex==2
		foreach k in colag sex{
			by jobid year: egen `k'_j = mean(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		foreach p in logpayrate_cpi logthrs{
			by jobid year: egen `p'_med = median(`p')
			drop `p'
			}

		* Keep one obs per job and year
		egen tag = tag(jobid year)
		keep if tag==1
		drop tag

		* Compute the average age over all new hires in all years for normalisation
		egen asd_age = mean(age)
		* Create covariates
		g agesq 		= (age-asd_age)^2
		g agecub 		= (age-asd_age)^3
		g idbrnempsq 	= idbrnemp^2

		* Set panel and time series variables
		xtset, clear
		xtset jobid year

		* Year dummies
		quietly tab year, gen(d)
		
		foreach k in logpayrate_cpi_med logthrs_med{
			preserve
				quietly areg `k' d2-d19 age agesq agecub idbrnemp idbrnempsq sex colag, absorb(jobid) vce(cluster jobid)
				matrix b = e(b)
				clear
				svmat b
				forvalue i=1/18 {
				rename b`i' c`i'
				}
				drop b*
				xpose, clear
				capture drop year
				gen year=_n + 1998
				gen se=.
				forvalue i = 2/19{
					quietly replace se=_se[d`i'] if year==1997+`i'
				}	
				quietly rename se `k'_se`1'
				quietly rename v1 `k'`1'
				cd $reg_results_overtime 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_overtime 
		use beta_logpayrate_cpi_med, clear
		quietly merge 1:1 year using beta_logthrs_med, nogen
		save results_`1'.dta, replace
		
		capture erase beta_logpayrate_cpi_med.dta
		capture erase beta_logthrs_med.dta
		
		end

		* end areg programme
	}
	/* New hires - wages and hours */{

		cd $created_datadir
		use slim_1997_2016, clear

		* define sample to be analysed
		drop if poe!=1

		* Run the regression program
		reg_wages 1
		
	}
	/* Job stayers - wages and hours */{

		cd $created_datadir
		use slim_1997_2016, clear

		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		xtset, clear
		xtset piden year

		drop poe* w*
		drop if idbrnemp==0

		replace sex = 0 if sex==1
		replace sex = 1 if sex==2

		forvalues i = 2016(-1)1999{
			preserve
				local k = `i' - 1
				keep if (year == `i') | (year == `k')
				keep piden jobid year age tenure idbrnemp log* sjd entref sex colag ft sic
				
				* Keep only employees who are observed in the same job consecutively
				sort piden year
				capture drop f`i'
				quiet gen f`i' = .
				quiet by piden: replace f`i'=1 if L.jobid==jobid & year == `i' & sjd==1 

				capture drop b`k'
				quiet gen b`k' = .
				quiet by piden: replace b`k'=1 if F.jobid==jobid & year == `k' & F.sjd==1
				
				sort jobid year
				capture drop temp
				capture drop temp2
				by jobid year: egen temp 	= count(f`i')
				by jobid year: egen temp2 	= count(b`k')
				
				* Drop if the minimum number of job stayers is not fulfilled - 3 in the baseline sample
				drop if temp<3 & year == `i'
				drop if temp2<3 & year == `k'
				
				*drop temp temp2
				
				sort jobid year
				foreach x of varlist colag sex ft sic{
					by jobid year: egen asd_`x'_`i' = mean(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = mean(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}
				foreach x of varlist age tenure idbrnemp{
					by jobid year: egen asd_`x'_`i' = median(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = median(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}		
				foreach x of varlist logpayrate_cpi logthrs{
					by jobid year: egen asd_`x'_`i' = median(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = median(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				} 		
				drop f`i' b`k'
				
				capture drop tag
				egen tag = tag(jobid)
				drop if tag==0
				drop tag

				* compute the mean age and tenure for normalisation
				egen asd_age = mean(age_`i')
				egen asd_ten = mean(tenure_`i')
				sort jobid
				foreach x of varlist age_`k' age_`i'{
					by jobid: gen sq`x' = (`x'-asd_age)^2
					by jobid: gen cub`x' = (`x'-asd_age)^3
				}	
				foreach x of varlist tenure_`k' tenure_`i'{
					by jobid: gen sq`x' = (`x'-asd_ten)^2
					by jobid: gen cub`x' = (`x'-asd_ten)^3
				}				
				
				keep jobid temp2 sic age_* logthrs_* colag_* sex_* ft_* sqtenure_* sqage_* cubtenure_* cubage_* idbrnemp_* logpayrate_cpi_* entref

				quietly reshape long age_ logthrs_ colag_ sex_ ft_ sqtenure_ sqage_ cubtenure_ cubage_ idbrnemp_ logpayrate_cpi_ , i(jobid) j(year)
				
				rename idbrnemp_ asd
			
				g id = `i'
				
				rename asd idbrnemp_
				
				cd $reg_results_overtime
				save temp`i'.dta, replace
			restore
		}

		* create empty dataset
		cd $reg_results_overtime
		use temp2016.dta, clear
		forvalues i = 2015(-1)1999{
			append using temp`i'.dta
			capture erase temp`i'.dta
		}

		rename *_ *

		sort entref
		by entref: egen firm_end=max(year)
		by entref: egen firm_start=min(year)
		g firm_life=firm_end-firm_start+1
		drop entref

		* Keep only jobs which are observed for at least 50% of the years for which the firm exists
		sort jobid
		egen tag = tag(jobid year)
		replace tag=. if tag==0
		by jobid: egen rel_years = sum(tag)
		drop if (rel_years/firm_life)<0.5 & rel_years!=.
		drop rel_years tag firm*

		* temp2 is the number of job stayers in each job per year
		rename temp2 weighting

		egen temp = group(jobid id)
		drop jobid id
		rename temp jobid

		xtset, clear
		xtset jobid year

		quietly tab year, gen(d)

		g ind = 0 
		by jobid: replace ind = 1 if _n==2

		* save number of stayer jobs per year for weighted productivity regressions
		preserve
			keep if ind == 1
			keep year sic
			cd $created_datadir
			save stayer_weights_prod.dta, replace
		restore
		
		foreach k in logpayrate_cpi logthrs{
			quietly areg `k' d2-d19 idbrnemp sqage sqtenure cubage cubtenure colag, absorb(jobid) vce(cluster jobid)
			preserve
				clear
				set obs 18
				gen year = _n + 1998
				gen beta = .
				gen beta_se = .
				forvalue i = 2/19{
					quietly replace beta=_b[d`i'] if year == 1997+`i'
					quietly replace beta_se=_se[d`i'] if year == 1997+`i'
				}
				
				quietly rename beta_se `k'_med_se2
				quietly rename beta `k'_med2
				cd $reg_results_overtime 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_overtime
		use beta_logpayrate_cpi, clear
		quietly merge 1:1 year using beta_logthrs, nogen
		save results_2.dta, replace
			
		capture erase temp2016.dta
		capture erase beta_logthrs.dta
		capture erase beta_logpayrate_cpi.dta

	}

	cd $other_data
	use econ, clear
	cd $reg_results_overtime
	quietly merge 1:1 year using results_1, nogen
	quietly merge 1:1 year using results_2, nogen
	drop if year==1997
	
	save results_97_16.dta, replace
	capture erase results_1.dta
	capture erase results_2.dta

	/* Second step regression */{
	
		tsset year

		foreach p in logpayrate_cpi logthrs{
			foreach k in unemp{
				forvalue i =1/2{
					preserve
						quietly newey `p'_med`i' `k' year, lag(1)
						clear
						set obs 1
						gen b_`k' = _b[`k']
						gen se_`k' = _se[`k']
						gen spec= `i'
						cd $reg_results_overtime
						save `p'`k'`i'.dta, replace
					restore
				}
			}
		}

		foreach p in logpayrate_cpi logthrs{
			foreach k in unemp{
				cd $reg_results_overtime
				use `p'`k'1, clear
				quietly append using `p'`k'2
				erase `p'`k'2.dta
				save `p'`k'.dta, replace
				erase `p'`k'1.dta
			}
		}

		foreach p in logpayrate_cpi logthrs{
			cd $reg_results_overtime
			use `p'unemp, clear
			save `p'.dta, replace
			erase `p'unemp.dta
		}

		
	}

}

	if $occ_3d==1{
	/* Define regression programme */{
		capture program drop reg_wages
		program define reg_wages

		* Keep only private enterprises
		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		sort jobid year
		
		*** COVARIATES
		foreach k in age idbrnemp{
			by jobid year: egen `k'_j = median(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		replace sex = 0 if sex==2
		foreach k in colag sex{
			by jobid year: egen `k'_j = mean(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		foreach p in logwage_cpi loghours{
			by jobid year: egen `p'_med = median(`p')
			drop `p'
			}

		* Keep one obs per job and year
		egen tag = tag(jobid year)
		keep if tag==1
		drop tag

		* Compute the average age over all new hires in all years for normalisation
		egen asd_age = mean(age)
		* Create covariates
		g agesq 		= (age-asd_age)^2
		g agecub 		= (age-asd_age)^3
		g idbrnempsq 	= idbrnemp^2

		* Set panel and time series variables
		xtset, clear
		xtset jobid year

		* Year dummies
		quietly tab year, gen(d)
		
		foreach k in logwage_cpi_med loghours_med{
			preserve
				quietly areg `k' d2-d19 age agesq agecub idbrnemp idbrnempsq sex colag, absorb(jobid) vce(cluster jobid)
				matrix b = e(b)
				clear
				svmat b
				forvalue i=1/18 {
				rename b`i' c`i'
				}
				drop b*
				xpose, clear
				capture drop year
				gen year=_n + 1998
				gen se=.
				forvalue i = 2/19{
					quietly replace se=_se[d`i'] if year==1997+`i'
				}	
				quietly rename se `k'_se`1'
				quietly rename v1 `k'`1'
				cd $reg_results_3d 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_3d 
		use beta_logwage_cpi_med, clear
		quietly merge 1:1 year using beta_loghours_med, nogen
		save results_`1'.dta, replace
		
		capture erase beta_logwage_cpi_med.dta
		capture erase beta_loghours_med.dta
		
		end

		* end areg programme
	}
	/* New hires - wages and hours */{

		cd $reg_results_3d
		use slim_1997_2016_3d, clear

		* define sample to be analysed
		drop if poe!=1

		* Run the regression program
		reg_wages 1
	
}
	/* Job stayers - wages and hours */{

		cd $reg_results_3d
		use slim_1997_2016_3d, clear
		* Do NOT drop year=1997, as first-diff for 1998 undefined otherwise 

		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		xtset, clear
		xtset piden year

		drop poe* w*
		drop if idbrnemp==0

		replace sex = 0 if sex==1
		replace sex = 1 if sex==2

		forvalues i = 2016(-1)1999{
			preserve
				local k = `i' - 1
				keep if (year == `i') | (year == `k')
				keep piden jobid year age tenure idbrnemp log* sjd entref sex colag ft sic
				
				* Keep only employees who are observed in the same job consecutively
				sort piden year
				capture drop f`i'
				quiet gen f`i' = .
				quiet by piden: replace f`i'=1 if L.jobid==jobid & year == `i' & sjd==1 

				capture drop b`k'
				quiet gen b`k' = .
				quiet by piden: replace b`k'=1 if F.jobid==jobid & year == `k' & F.sjd==1
				
				sort jobid year
				capture drop temp
				capture drop temp2
				by jobid year: egen temp 	= count(f`i')
				by jobid year: egen temp2 	= count(b`k')
				
				* Drop if the minimum number of job stayers is not fulfilled - 3 in the baseline sample
				drop if temp<3 & year == `i'
				drop if temp2<3 & year == `k'
				
				*drop temp temp2
				
				sort jobid year
				foreach x of varlist colag sex ft sic{
					by jobid year: egen asd_`x'_`i' = mean(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = mean(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}
				foreach x of varlist age tenure idbrnemp{
					by jobid year: egen asd_`x'_`i' = median(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = median(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}		
				foreach x of varlist logwage_cpi loghours{
					by jobid year: egen asd_`x'_`i' = median(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = median(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				} 		
				drop f`i' b`k'
				
				capture drop tag
				egen tag = tag(jobid)
				drop if tag==0
				drop tag

				* compute the mean age and tenure for normalisation
				egen asd_age = mean(age_`i')
				egen asd_ten = mean(tenure_`i')
				sort jobid
				foreach x of varlist age_`k' age_`i'{
					by jobid: gen sq`x' = (`x'-asd_age)^2
					by jobid: gen cub`x' = (`x'-asd_age)^3
				}	
				foreach x of varlist tenure_`k' tenure_`i'{
					by jobid: gen sq`x' = (`x'-asd_ten)^2
					by jobid: gen cub`x' = (`x'-asd_ten)^3
				}				
				
				keep jobid temp2 sic age_* loghours_* colag_* sex_* ft_* sqtenure_* sqage_* cubtenure_* cubage_* idbrnemp_* logwage_cpi_* entref

				quietly reshape long age_ loghours_ colag_ sex_ ft_ sqtenure_ sqage_ cubtenure_ cubage_ idbrnemp_ logwage_cpi_ , i(jobid) j(year)
				
				rename idbrnemp_ asd
			
				g id = `i'
				
				rename asd idbrnemp_
				
				cd $reg_results_3d
				save temp`i'.dta, replace
			restore
		}

		* create empty dataset
		cd $reg_results_3d
		use temp2016.dta, clear
		forvalues i = 2015(-1)1999{
			append using temp`i'.dta
			capture erase temp`i'.dta
		}

		rename *_ *

		sort entref
		by entref: egen firm_end=max(year)
		by entref: egen firm_start=min(year)
		g firm_life=firm_end-firm_start+1
		drop entref

		* Keep only jobs which are observed for at least 50% of the years for which the firm exists
		sort jobid
		egen tag = tag(jobid year)
		replace tag=. if tag==0
		by jobid: egen rel_years = sum(tag)
		drop if (rel_years/firm_life)<0.5 & rel_years!=.
		drop rel_years tag firm*

		* temp2 is the number of job stayers in each job per year
		rename temp2 weighting

		egen temp = group(jobid id)
		drop jobid id
		rename temp jobid

		xtset, clear
		xtset jobid year

		quietly tab year, gen(d)

		g ind = 0 
		by jobid: replace ind = 1 if _n==2

		foreach k in logwage_cpi loghours{
			quietly areg `k' d2-d19 idbrnemp sqage sqtenure cubage cubtenure colag, absorb(jobid) vce(cluster jobid)
			preserve
				clear
				set obs 18
				gen year = _n + 1998
				gen beta = .
				gen beta_se = .
				forvalue i = 2/19{
					quietly replace beta=_b[d`i'] if year == 1997+`i'
					quietly replace beta_se=_se[d`i'] if year == 1997+`i'
				}
				
				quietly rename beta_se `k'_med_se2
				quietly rename beta `k'_med2
				cd $reg_results_3d 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_3d
		use beta_logwage_cpi, clear
		quietly merge 1:1 year using beta_loghours, nogen
		save results_2.dta, replace
			
		capture erase temp2016.dta
		capture erase beta_loghours.dta
		capture erase beta_logwage_cpi.dta

	}

	cd $other_data
	use econ, clear
	cd $reg_results_3d
	quietly merge 1:1 year using results_1, nogen
	quietly merge 1:1 year using results_2, nogen
	drop if year==1997
	
	save results_97_16.dta, replace
	capture erase results_1.dta
	capture erase results_2.dta

	/* Second step regression */{
	
		tsset year

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				forvalue i =1/2{
					preserve
						quietly newey `p'_med`i' `k' year, lag(1)
						clear
						set obs 1
						gen b_`k' = _b[`k']
						gen se_`k' = _se[`k']
						gen spec= `i'
						cd $reg_results_3d
						save `p'`k'`i'.dta, replace
					restore
				}
			}
		}

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				cd $reg_results_3d
				use `p'`k'1, clear
				quietly append using `p'`k'2
				erase `p'`k'2.dta
				save `p'`k'.dta, replace
				erase `p'`k'1.dta
			}
		}

		foreach p in logwage_cpi loghours{
			cd $reg_results_3d
			use `p'unemp, clear
			save `p'_3d.dta, replace
			erase `p'unemp.dta
		}

		
	}

}

} 
 
/* TABLE B1 */{

	* Set globals, i.e. which results are generated
	global reg_mean		= 1 // Means (instead of medians) of wages and hours at job level
	global p25			= 1 // 25th percentile of wages and hours within job
	global p75			= 1 // 75th percentile of wages and hours within job
	global no_controls	= 1 // No controls included
	global incl_public	= 1 // Includes the public sector
	global rpi			= 1 // Uses the RPI as deflator (instead of CPI)
 
	if $reg_mean==1{
	/* Define regression programme */{
		capture program drop reg_wages
		program define reg_wages

		* Keep only private enterprises
		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		sort jobid year
		
		*** COVARIATES
		foreach k in age idbrnemp{
			by jobid year: egen `k'_j = median(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		replace sex = 0 if sex==2
		foreach k in colag sex{
			by jobid year: egen `k'_j = mean(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		foreach p in logwage_cpi loghours{
			by jobid year: egen `p'_med = mean(`p')
			drop `p'
			}

		* Keep one obs per job and year
		egen tag = tag(jobid year)
		keep if tag==1
		drop tag

		* Compute the average age over all new hires in all years for normalisation
		egen asd_age = mean(age)
		* Create covariates
		g agesq 		= (age-asd_age)^2
		g agecub 		= (age-asd_age)^3
		g idbrnempsq 	= idbrnemp^2

		* Set panel and time series variables
		xtset, clear
		xtset jobid year

		* Year dummies
		quietly tab year, gen(d)
		
		foreach k in logwage_cpi_med loghours_med{
			preserve
				quietly areg `k' d2-d19 age agesq agecub idbrnemp idbrnempsq sex colag, absorb(jobid) vce(cluster jobid)
				matrix b = e(b)
				clear
				svmat b
				forvalue i=1/18 {
				rename b`i' c`i'
				}
				drop b*
				xpose, clear
				capture drop year
				gen year=_n + 1998
				gen se=.
				forvalue i = 2/19{
					quietly replace se=_se[d`i'] if year==1997+`i'
				}	
				quietly rename se `k'_se`1'
				quietly rename v1 `k'`1'
				cd $reg_results_mean 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_mean 
		use beta_logwage_cpi_med, clear
		quietly merge 1:1 year using beta_loghours_med, nogen
		save results_`1'.dta, replace
		
		capture erase beta_logwage_cpi_med.dta
		capture erase beta_loghours_med.dta
		
		end

		* end areg programme
	}
	/* New hires - wages and hours */{

		cd $created_datadir
		use slim_1997_2016, clear

		* define sample to be analysed
		drop if poe!=1

		* Run the regression program
		reg_wages 1
		
	}
	/* Job stayers - wages and hours */{

		cd $created_datadir
		use slim_1997_2016, clear
		* Do NOT drop year=1997, as first-diff for 1998 undefined otherwise 

		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		xtset, clear
		xtset piden year

		drop poe* w*
		drop if idbrnemp==0

		replace sex = 0 if sex==1
		replace sex = 1 if sex==2

		forvalues i = 2016(-1)1999{
			preserve
				local k = `i' - 1
				keep if (year == `i') | (year == `k')
				keep piden jobid year age tenure idbrnemp log* sjd entref sex colag ft sic
				
				* Keep only employees who are observed in the same job consecutively
				sort piden year
				capture drop f`i'
				quiet gen f`i' = .
				quiet by piden: replace f`i'=1 if L.jobid==jobid & year == `i' & sjd==1 

				capture drop b`k'
				quiet gen b`k' = .
				quiet by piden: replace b`k'=1 if F.jobid==jobid & year == `k' & F.sjd==1
				
				sort jobid year
				capture drop temp
				capture drop temp2
				by jobid year: egen temp 	= count(f`i')
				by jobid year: egen temp2 	= count(b`k')
				
				* Drop if the minimum number of job stayers is not fulfilled - 3 in the baseline sample
				drop if temp<3 & year == `i'
				drop if temp2<3 & year == `k'
				
				*drop temp temp2
				
				sort jobid year
				foreach x of varlist colag sex ft sic{
					by jobid year: egen asd_`x'_`i' = mean(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = mean(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}
				foreach x of varlist age tenure idbrnemp{
					by jobid year: egen asd_`x'_`i' = median(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = median(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}		
				foreach x of varlist logwage_cpi loghours{
					by jobid year: egen asd_`x'_`i' = mean(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = mean(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				} 		
				drop f`i' b`k'
				
				capture drop tag
				egen tag = tag(jobid)
				drop if tag==0
				drop tag

				* compute the mean age and tenure for normalisation
				egen asd_age = mean(age_`i')
				egen asd_ten = mean(tenure_`i')
				sort jobid
				foreach x of varlist age_`k' age_`i'{
					by jobid: gen sq`x' = (`x'-asd_age)^2
					by jobid: gen cub`x' = (`x'-asd_age)^3
				}	
				foreach x of varlist tenure_`k' tenure_`i'{
					by jobid: gen sq`x' = (`x'-asd_ten)^2
					by jobid: gen cub`x' = (`x'-asd_ten)^3
				}				
				
				keep jobid temp2 sic age_* loghours_* colag_* sex_* ft_* sqtenure_* sqage_* cubtenure_* cubage_* idbrnemp_* logwage_cpi_* entref

				quietly reshape long age_ loghours_ colag_ sex_ ft_ sqtenure_ sqage_ cubtenure_ cubage_ idbrnemp_ logwage_cpi_ , i(jobid) j(year)
				
				rename idbrnemp_ asd
			
				g id = `i'
				
				rename asd idbrnemp_
				
				cd $reg_results_mean
				save temp`i'.dta, replace
			restore
		}

		* create empty dataset
		cd $reg_results_mean
		use temp2016.dta, clear
		forvalues i = 2015(-1)1999{
			append using temp`i'.dta
			capture erase temp`i'.dta
		}

		rename *_ *

		sort entref
		by entref: egen firm_end=max(year)
		by entref: egen firm_start=min(year)
		g firm_life=firm_end-firm_start+1
		drop entref

		* Keep only jobs which are observed for at least 50% of the years for which the firm exists
		sort jobid
		egen tag = tag(jobid year)
		replace tag=. if tag==0
		by jobid: egen rel_years = sum(tag)
		drop if (rel_years/firm_life)<0.5 & rel_years!=.
		drop rel_years tag firm*

		* temp2 is the number of job stayers in each job per year
		rename temp2 weighting

		egen temp = group(jobid id)
		drop jobid id
		rename temp jobid

		xtset, clear
		xtset jobid year

		quietly tab year, gen(d)

		g ind = 0 
		by jobid: replace ind = 1 if _n==2
		
		foreach k in logwage_cpi loghours{
			quietly areg `k' d2-d19 idbrnemp sqage sqtenure cubage cubtenure colag, absorb(jobid) vce(cluster jobid)
			preserve
				clear
				set obs 18
				gen year = _n + 1998
				gen beta = .
				gen beta_se = .
				forvalue i = 2/19{
					quietly replace beta=_b[d`i'] if year == 1997+`i'
					quietly replace beta_se=_se[d`i'] if year == 1997+`i'
				}
				
				quietly rename beta_se `k'_med_se2
				quietly rename beta `k'_med2
				cd $reg_results_mean 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_mean
		use beta_logwage_cpi, clear
		quietly merge 1:1 year using beta_loghours, nogen
		save results_2.dta, replace
			
		capture erase temp2016.dta
		capture erase beta_loghours.dta
		capture erase beta_logwage_cpi.dta

	}

	cd $other_data
	use econ, clear
	cd $reg_results_mean
	quietly merge 1:1 year using results_1, nogen
	quietly merge 1:1 year using results_2, nogen
	drop if year==1997
	
	save results_97_16.dta, replace
	capture erase results_1.dta
	capture erase results_2.dta
	
	/* Second step regression */{
	
		tsset year

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				forvalue i =1/2{
					preserve
						quietly newey `p'_med`i' `k' year, lag(1)
						clear
						set obs 1
						gen b_`k' = _b[`k']
						gen se_`k' = _se[`k']
						gen spec= `i'
						cd $reg_results_mean
						save `p'`k'`i'.dta, replace
					restore
				}
			}
		}

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				cd $reg_results_mean
				use `p'`k'1, clear
				quietly append using `p'`k'2
				erase `p'`k'2.dta
				save `p'`k'.dta, replace
				erase `p'`k'1.dta
			}
		}

		foreach p in logwage_cpi loghours{
			cd $reg_results_mean
			use `p'unemp, clear
			save `p'.dta, replace
			erase `p'unemp.dta
		}

		
	}

}

	if $p25==1{
	/* Define regression programme */{
		capture program drop reg_wages
		program define reg_wages

		* Keep only private enterprises
		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		sort jobid year
		
		*** COVARIATES
		foreach k in age idbrnemp{
			by jobid year: egen `k'_j = median(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		replace sex = 0 if sex==2
		foreach k in colag sex{
			by jobid year: egen `k'_j = mean(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		foreach p in logwage_cpi loghours{
			by jobid year: egen `p'_med = pctile(`p'), p(25)
			drop `p'
			}

		* Keep one obs per job and year
		egen tag = tag(jobid year)
		keep if tag==1
		drop tag
		
		* Compute the average age over all new hires in all years for normalisation
		egen asd_age = mean(age)
		* Create covariates
		g agesq 		= (age-asd_age)^2
		g agecub 		= (age-asd_age)^3
		g idbrnempsq 	= idbrnemp^2

		* Set panel and time series variables
		xtset, clear
		xtset jobid year

		* Year dummies
		quietly tab year, gen(d)
		
		foreach k in logwage_cpi_med loghours_med{
			preserve
				quietly areg `k' d2-d19 age agesq agecub idbrnemp idbrnempsq sex colag, absorb(jobid) vce(cluster jobid)
				matrix b = e(b)
				clear
				svmat b
				forvalue i=1/18 {
				rename b`i' c`i'
				}
				drop b*
				xpose, clear
				capture drop year
				gen year=_n + 1998
				gen se=.
				forvalue i = 2/19{
					quietly replace se=_se[d`i'] if year==1997+`i'
				}	
				quietly rename se `k'_se`1'
				quietly rename v1 `k'`1'
				cd $reg_results_p25 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_p25 
		use beta_logwage_cpi_med, clear
		quietly merge 1:1 year using beta_loghours_med, nogen
		save results_`1'.dta, replace
		
		capture erase beta_logwage_cpi_med.dta
		capture erase beta_loghours_med.dta
		
		end

		* end areg programme
	}
	/* New hires - wages and hours */{

		cd $created_datadir
		use slim_1997_2016, clear

		* define sample to be analysed
		drop if poe!=1

		* Run the regression program
		reg_wages 1
		
	}
	/* Job stayers - wages and hours */{

		cd $created_datadir
		use slim_1997_2016, clear
		* Do NOT drop year=1997, as first-diff for 1998 undefined otherwise 

		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		xtset, clear
		xtset piden year

		drop poe* w*
		drop if idbrnemp==0

		replace sex = 0 if sex==1
		replace sex = 1 if sex==2

		forvalues i = 2016(-1)1999{
			preserve
				local k = `i' - 1
				keep if (year == `i') | (year == `k')
				keep piden jobid year age tenure idbrnemp log* sjd entref sex colag ft sic
				
				* Keep only employees who are observed in the same job consecutively
				sort piden year
				capture drop f`i'
				quiet gen f`i' = .
				quiet by piden: replace f`i'=1 if L.jobid==jobid & year == `i' & sjd==1 

				capture drop b`k'
				quiet gen b`k' = .
				quiet by piden: replace b`k'=1 if F.jobid==jobid & year == `k' & F.sjd==1
				
				sort jobid year
				capture drop temp
				capture drop temp2
				by jobid year: egen temp 	= count(f`i')
				by jobid year: egen temp2 	= count(b`k')
				
				* Drop if the minimum number of job stayers is not fulfilled - 3 in the baseline sample
				drop if temp<3 & year == `i'
				drop if temp2<3 & year == `k'
				
				*drop temp temp2
				
				sort jobid year
				foreach x of varlist colag sex ft sic{
					by jobid year: egen asd_`x'_`i' = mean(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = mean(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}
				foreach x of varlist age tenure idbrnemp{
					by jobid year: egen asd_`x'_`i' = median(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = median(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}		
				foreach x of varlist logwage_cpi loghours{
					by jobid year: egen asd_`x'_`i' = pctile(`x') if f`i'==1, p(25) 
					by jobid year: egen asd_`x'_`k' = pctile(`x') if b`k'==1, p(25)
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				} 		
				drop f`i' b`k'
				
				capture drop tag
				egen tag = tag(jobid)
				drop if tag==0
				drop tag

				* compute the mean age and tenure for normalisation
				egen asd_age = mean(age_`i')
				egen asd_ten = mean(tenure_`i')
				sort jobid
				foreach x of varlist age_`k' age_`i'{
					by jobid: gen sq`x' = (`x'-asd_age)^2
					by jobid: gen cub`x' = (`x'-asd_age)^3
				}	
				foreach x of varlist tenure_`k' tenure_`i'{
					by jobid: gen sq`x' = (`x'-asd_ten)^2
					by jobid: gen cub`x' = (`x'-asd_ten)^3
				}				
				
				keep jobid temp2 sic age_* loghours_* colag_* sex_* ft_* sqtenure_* sqage_* cubtenure_* cubage_* idbrnemp_* logwage_cpi_* entref

				quietly reshape long age_ loghours_ colag_ sex_ ft_ sqtenure_ sqage_ cubtenure_ cubage_ idbrnemp_ logwage_cpi_ , i(jobid) j(year)
				
				rename idbrnemp_ asd
			
				g id = `i'
				
				rename asd idbrnemp_
				
				cd $reg_results_p25
				save temp`i'.dta, replace
			restore
		}

		* create empty dataset
		cd $reg_results_p25
		use temp2016.dta, clear
		forvalues i = 2015(-1)1999{
			append using temp`i'.dta
			capture erase temp`i'.dta
		}

		rename *_ *

		sort entref
		by entref: egen firm_end=max(year)
		by entref: egen firm_start=min(year)
		g firm_life=firm_end-firm_start+1
		drop entref

		* Keep only jobs which are observed for at least 50% of the years for which the firm exists
		sort jobid
		egen tag = tag(jobid year)
		replace tag=. if tag==0
		by jobid: egen rel_years = sum(tag)
		drop if (rel_years/firm_life)<0.5 & rel_years!=.
		drop rel_years tag firm*

		* temp2 is the number of job stayers in each job per year
		rename temp2 weighting

		egen temp = group(jobid id)
		drop jobid id
		rename temp jobid

		xtset, clear
		xtset jobid year

		quietly tab year, gen(d)

		g ind = 0 
		by jobid: replace ind = 1 if _n==2
		
		foreach k in logwage_cpi loghours{
			quietly areg `k' d2-d19 idbrnemp sqage sqtenure cubage cubtenure colag, absorb(jobid) vce(cluster jobid)
			preserve
				clear
				set obs 18
				gen year = _n + 1998
				gen beta = .
				gen beta_se = .
				forvalue i = 2/19{
					quietly replace beta=_b[d`i'] if year == 1997+`i'
					quietly replace beta_se=_se[d`i'] if year == 1997+`i'
				}
				
				quietly rename beta_se `k'_med_se2
				quietly rename beta `k'_med2
				cd $reg_results_p25 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_p25
		use beta_logwage_cpi, clear
		quietly merge 1:1 year using beta_loghours, nogen
		save results_2.dta, replace
			
		capture erase temp2016.dta
		capture erase beta_loghours.dta
		capture erase beta_logwage_cpi.dta

	}

	cd $other_data
	use econ, clear
	cd $reg_results_p25
	quietly merge 1:1 year using results_1, nogen
	quietly merge 1:1 year using results_2, nogen
	drop if year==1997
	
	save results_97_16.dta, replace
	capture erase results_1.dta
	capture erase results_2.dta
	
	/* Second step regression */{
	
		tsset year

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				forvalue i =1/2{
					preserve
						quietly newey `p'_med`i' `k' year, lag(1)
						clear
						set obs 1
						gen b_`k' = _b[`k']
						gen se_`k' = _se[`k']
						gen spec= `i'
						cd $reg_results_p25
						save `p'`k'`i'.dta, replace
					restore
				}
			}
		}

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				cd $reg_results_p25
				use `p'`k'1, clear
				quietly append using `p'`k'2
				erase `p'`k'2.dta
				save `p'`k'.dta, replace
				erase `p'`k'1.dta
			}
		}

		foreach p in logwage_cpi loghours{
			cd $reg_results_p25
			use `p'unemp, clear
			save `p'.dta, replace
			erase `p'unemp.dta
		}

		
	}

}

	if $p75==1{
	/* Define regression programme */{
		capture program drop reg_wages
		program define reg_wages

		* Keep only private enterprises
		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		sort jobid year
		
		*** COVARIATES
		foreach k in age idbrnemp{
			by jobid year: egen `k'_j = median(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		replace sex = 0 if sex==2
		foreach k in colag sex{
			by jobid year: egen `k'_j = mean(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		foreach p in logwage_cpi loghours{
			by jobid year: egen `p'_med = pctile(`p'), p(75)
			drop `p'
			}

		* Keep one obs per job and year
		egen tag = tag(jobid year)
		keep if tag==1
		drop tag

		* Compute the average age over all new hires in all years for normalisation
		egen asd_age = mean(age)
		* Create covariates
		g agesq 		= (age-asd_age)^2
		g agecub 		= (age-asd_age)^3
		g idbrnempsq 	= idbrnemp^2

		* Set panel and time series variables
		xtset, clear
		xtset jobid year

		* Year dummies
		quietly tab year, gen(d)
		
		foreach k in logwage_cpi_med loghours_med{
			preserve
				quietly areg `k' d2-d19 age agesq agecub idbrnemp idbrnempsq sex colag, absorb(jobid) vce(cluster jobid)
				matrix b = e(b)
				clear
				svmat b
				forvalue i=1/18 {
				rename b`i' c`i'
				}
				drop b*
				xpose, clear
				capture drop year
				gen year=_n + 1998
				gen se=.
				forvalue i = 2/19{
					quietly replace se=_se[d`i'] if year==1997+`i'
				}	
				quietly rename se `k'_se`1'
				quietly rename v1 `k'`1'
				cd $reg_results_p75 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_p75 
		use beta_logwage_cpi_med, clear
		quietly merge 1:1 year using beta_loghours_med, nogen
		save results_`1'.dta, replace
		
		capture erase beta_logwage_cpi_med.dta
		capture erase beta_loghours_med.dta
		
		end

		* end areg programme
	}
	/* New hires - wages and hours */{

		cd $created_datadir
		use slim_1997_2016, clear

		* define sample to be analysed
		drop if poe!=1

		* Run the regression program
		reg_wages 1
		
	}
	/* Job stayers - wages and hours */{

		cd $created_datadir
		use slim_1997_2016, clear
		* Do NOT drop year=1997, as first-diff for 1998 undefined otherwise 

		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		xtset, clear
		xtset piden year

		drop poe* w*
		drop if idbrnemp==0

		replace sex = 0 if sex==1
		replace sex = 1 if sex==2

		forvalues i = 2016(-1)1999{
			preserve
				local k = `i' - 1
				keep if (year == `i') | (year == `k')
				keep piden jobid year age tenure idbrnemp log* sjd entref sex colag ft sic
				
				* Keep only employees who are observed in the same job consecutively
				sort piden year
				capture drop f`i'
				quiet gen f`i' = .
				quiet by piden: replace f`i'=1 if L.jobid==jobid & year == `i' & sjd==1 

				capture drop b`k'
				quiet gen b`k' = .
				quiet by piden: replace b`k'=1 if F.jobid==jobid & year == `k' & F.sjd==1
				
				sort jobid year
				capture drop temp
				capture drop temp2
				by jobid year: egen temp 	= count(f`i')
				by jobid year: egen temp2 	= count(b`k')
				
				* Drop if the minimum number of job stayers is not fulfilled - 3 in the baseline sample
				drop if temp<3 & year == `i'
				drop if temp2<3 & year == `k'
				
				*drop temp temp2
				
				sort jobid year
				foreach x of varlist colag sex ft sic{
					by jobid year: egen asd_`x'_`i' = mean(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = mean(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}
				foreach x of varlist age tenure idbrnemp{
					by jobid year: egen asd_`x'_`i' = median(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = median(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}		
				foreach x of varlist logwage_cpi loghours{
					by jobid year: egen asd_`x'_`i' = pctile(`x') if f`i'==1, p(75) 
					by jobid year: egen asd_`x'_`k' = pctile(`x') if b`k'==1, p(75)
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				} 		
				drop f`i' b`k'
				
				capture drop tag
				egen tag = tag(jobid)
				drop if tag==0
				drop tag

				* compute the mean age and tenure for normalisation
				egen asd_age = mean(age_`i')
				egen asd_ten = mean(tenure_`i')
				sort jobid
				foreach x of varlist age_`k' age_`i'{
					by jobid: gen sq`x' = (`x'-asd_age)^2
					by jobid: gen cub`x' = (`x'-asd_age)^3
				}	
				foreach x of varlist tenure_`k' tenure_`i'{
					by jobid: gen sq`x' = (`x'-asd_ten)^2
					by jobid: gen cub`x' = (`x'-asd_ten)^3
				}				
				
				keep jobid temp2 sic age_* loghours_* colag_* sex_* ft_* sqtenure_* sqage_* cubtenure_* cubage_* idbrnemp_* logwage_cpi_* entref

				quietly reshape long age_ loghours_ colag_ sex_ ft_ sqtenure_ sqage_ cubtenure_ cubage_ idbrnemp_ logwage_cpi_ , i(jobid) j(year)
				
				rename idbrnemp_ asd
			
				g id = `i'
				
				rename asd idbrnemp_
				
				cd $reg_results_p75
				save temp`i'.dta, replace
			restore
		}

		* create empty dataset
		cd $reg_results_p75
		use temp2016.dta, clear
		forvalues i = 2015(-1)1999{
			append using temp`i'.dta
			capture erase temp`i'.dta
		}

		rename *_ *

		sort entref
		by entref: egen firm_end=max(year)
		by entref: egen firm_start=min(year)
		g firm_life=firm_end-firm_start+1
		drop entref

		* Keep only jobs which are observed for at least 50% of the years for which the firm exists
		sort jobid
		egen tag = tag(jobid year)
		replace tag=. if tag==0
		by jobid: egen rel_years = sum(tag)
		drop if (rel_years/firm_life)<0.5 & rel_years!=.
		drop rel_years tag firm*

		* temp2 is the number of job stayers in each job per year
		rename temp2 weighting

		egen temp = group(jobid id)
		drop jobid id
		rename temp jobid

		xtset, clear
		xtset jobid year

		quietly tab year, gen(d)

		g ind = 0 
		by jobid: replace ind = 1 if _n==2
		
		foreach k in logwage_cpi loghours{
			quietly areg `k' d2-d19 idbrnemp sqage sqtenure cubage cubtenure colag, absorb(jobid) vce(cluster jobid)
			preserve
				clear
				set obs 18
				gen year = _n + 1998
				gen beta = .
				gen beta_se = .
				forvalue i = 2/19{
					quietly replace beta=_b[d`i'] if year == 1997+`i'
					quietly replace beta_se=_se[d`i'] if year == 1997+`i'
				}
				
				quietly rename beta_se `k'_med_se2
				quietly rename beta `k'_med2
				cd $reg_results_p75 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_p75
		use beta_logwage_cpi, clear
		quietly merge 1:1 year using beta_loghours, nogen
		save results_2.dta, replace
			
		capture erase temp2016.dta
		capture erase beta_loghours.dta
		capture erase beta_logwage_cpi.dta

	}

	cd $other_data
	use econ, clear
	cd $reg_results_p75
	quietly merge 1:1 year using results_1, nogen
	quietly merge 1:1 year using results_2, nogen
	drop if year==1997
	
	save results_97_16.dta, replace
	capture erase results_1.dta
	capture erase results_2.dta
	
	/* Second step regression */{
	
		tsset year

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				forvalue i =1/2{
					preserve
						quietly newey `p'_med`i' `k' year, lag(1)
						clear
						set obs 1
						gen b_`k' = _b[`k']
						gen se_`k' = _se[`k']
						gen spec= `i'
						cd $reg_results_p75
						save `p'`k'`i'.dta, replace
					restore
				}
			}
		}

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				cd $reg_results_p75
				use `p'`k'1, clear
				quietly append using `p'`k'2
				erase `p'`k'2.dta
				save `p'`k'.dta, replace
				erase `p'`k'1.dta
			}
		}

		foreach p in logwage_cpi loghours{
			cd $reg_results_p75
			use `p'unemp, clear
			save `p'.dta, replace
			erase `p'unemp.dta
		}

		
	}

}

	if $no_controls==1{
	/* Define regression programme */{
		capture program drop reg_wages
		program define reg_wages

		* Keep only private enterprises
		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		sort jobid year

		foreach p in logwage_cpi loghours{
			by jobid year: egen `p'_med = median(`p')
			drop `p'
			}

		* Keep one obs per job and year
		egen tag = tag(jobid year)
		keep if tag==1
		drop tag

		* Set panel and time series variables
		xtset, clear
		xtset jobid year

		* Year dummies
		quietly tab year, gen(d)
		
		foreach k in logwage_cpi_med loghours_med{
			preserve
				quietly areg `k' d2-d19, absorb(jobid) vce(cluster jobid)
				matrix b = e(b)
				clear
				svmat b
				forvalue i=1/18 {
				rename b`i' c`i'
				}
				drop b*
				xpose, clear
				capture drop year
				gen year=_n + 1998
				gen se=.
				forvalue i = 2/19{
					quietly replace se=_se[d`i'] if year==1997+`i'
				}	
				quietly rename se `k'_se`1'
				quietly rename v1 `k'`1'
				cd $reg_results_no_controls 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_no_controls 
		use beta_logwage_cpi_med, clear
		quietly merge 1:1 year using beta_loghours_med, nogen
		save results_`1'.dta, replace
		
		capture erase beta_logwage_cpi_med.dta
		capture erase beta_loghours_med.dta
		
		end

		* end areg programme
	}
	/* New hires - wages and hours */{

		cd $created_datadir
		use slim_1997_2016, clear

		* define sample to be analysed
		drop if poe!=1

		* Run the regression program
		reg_wages 1
		
	}
	/* Job stayers - wages and hours */{

		cd $reg_resultsdir_97_16
		use stayer_data_baseline.dta, clear

		sort entref
		by entref: egen firm_end=max(year)
		by entref: egen firm_start=min(year)
		gen firm_life=firm_end-firm_start+1
		drop entref

		* Keep only jobs which are observed for at least 50% of the years for which the firm exists
		sort jobid
		egen tag = tag(jobid year)
		replace tag=. if tag==0
		by jobid: egen rel_years = sum(tag)
		drop if (rel_years/firm_life)<0.5 & rel_years!=.
		drop rel_years tag firm*

		* temp2 is the number of job stayers in each job per year
		rename temp2 weighting

		egen temp = group(jobid id)
		drop jobid id
		rename temp jobid

		xtset, clear
		xtset jobid year

		quietly tab year, gen(d)
		
		foreach k in logwage_cpi loghours{
			quietly areg `k' d2-d19, absorb(jobid) vce(cluster jobid)
			preserve
				clear
				set obs 18
				gen year = _n + 1998
				gen beta = .
				gen beta_se = .
				forvalue i = 2/19{
					quietly replace beta=_b[d`i'] if year == 1997+`i'
					quietly replace beta_se=_se[d`i'] if year == 1997+`i'
				}
				
				quietly rename beta_se `k'_med_se2
				quietly rename beta `k'_med2
				cd $reg_results_no_controls 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_no_controls
		use beta_logwage_cpi, clear
		quietly merge 1:1 year using beta_loghours, nogen
		save results_2.dta, replace
			
		capture erase temp2016.dta
		capture erase beta_loghours.dta
		capture erase beta_logwage_cpi.dta

	}

	cd $other_data
	use econ, clear
	cd $reg_results_no_controls
	quietly merge 1:1 year using results_1, nogen
	quietly merge 1:1 year using results_2, nogen
	drop if year==1997
	
	save results_97_16.dta, replace
	capture erase results_1.dta
	capture erase results_2.dta
	
	/* Second step regression */{
	
		tsset year

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				forvalue i =1/2{
					preserve
						quietly newey `p'_med`i' `k' year, lag(1)
						clear
						set obs 1
						gen b_`k' = _b[`k']
						gen se_`k' = _se[`k']
						gen spec= `i'
						cd $reg_results_no_controls
						save `p'`k'`i'.dta, replace
					restore
				}
			}
		}

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				cd $reg_results_no_controls
				use `p'`k'1, clear
				quietly append using `p'`k'2
				erase `p'`k'2.dta
				save `p'`k'.dta, replace
				erase `p'`k'1.dta
			}
		}

		foreach p in logwage_cpi loghours{
			cd $reg_results_no_controls
			use `p'unemp, clear
			save `p'.dta, replace
			erase `p'unemp.dta
		}

		
	}

}

	if $incl_public==1{
	/* Define regression programme */{
		capture program drop reg_wages
		program define reg_wages

		sort jobid year
		
		*** COVARIATES
		foreach k in age idbrnemp{
			by jobid year: egen `k'_j = median(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		replace sex = 0 if sex==2
		foreach k in colag sex{
			by jobid year: egen `k'_j = mean(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		foreach p in logwage_cpi loghours{
			by jobid year: egen `p'_med = median(`p')
			drop `p'
			}

		* Keep one obs per job and year
		egen tag = tag(jobid year)
		keep if tag==1
		drop tag

		* Compute the average age over all new hires in all years for normalisation
		egen asd_age = mean(age)
		* Create covariates
		g agesq 		= (age-asd_age)^2
		g agecub 		= (age-asd_age)^3
		g idbrnempsq 	= idbrnemp^2

		* Set panel and time series variables
		xtset, clear
		xtset jobid year

		* Year dummies
		quietly tab year, gen(d)
		
		foreach k in logwage_cpi_med loghours_med{
			preserve
				quietly areg `k' d2-d19 age agesq agecub idbrnemp idbrnempsq sex colag, absorb(jobid) vce(cluster jobid)
				matrix b = e(b)
				clear
				svmat b
				forvalue i=1/18 {
				rename b`i' c`i'
				}
				drop b*
				xpose, clear
				capture drop year
				gen year=_n + 1998
				gen se=.
				forvalue i = 2/19{
					quietly replace se=_se[d`i'] if year==1997+`i'
				}	
				quietly rename se `k'_se`1'
				quietly rename v1 `k'`1'
				cd $reg_results_public_dir 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_public_dir 
		use beta_logwage_cpi_med, clear
		quietly merge 1:1 year using beta_loghours_med, nogen
		save results_`1'.dta, replace
		
		capture erase beta_logwage_cpi_med.dta
		capture erase beta_loghours_med.dta
		
		end

		* end areg programme
	}
	/* New hires - wages and hours */{

		cd $created_datadir
		use slim_1997_2016, clear

		* define sample to be analysed
		drop if poe!=1

		* Run the regression program
		reg_wages 1
		
	}
	/* Job stayers - wages and hours */{

		cd $created_datadir
		use slim_1997_2016, clear
		* Do NOT drop year=1997, as first-diff for 1998 undefined otherwise 

		xtset, clear
		xtset piden year

		drop poe* w*
		drop if idbrnemp==0

		replace sex = 0 if sex==1
		replace sex = 1 if sex==2

		forvalues i = 2016(-1)1999{
			preserve
				local k = `i' - 1
				keep if (year == `i') | (year == `k')
				keep piden jobid year age tenure idbrnemp log* sjd entref sex colag ft sic
				
				* Keep only employees who are observed in the same job consecutively
				sort piden year
				capture drop f`i'
				quiet gen f`i' = .
				quiet by piden: replace f`i'=1 if L.jobid==jobid & year == `i' & sjd==1 

				capture drop b`k'
				quiet gen b`k' = .
				quiet by piden: replace b`k'=1 if F.jobid==jobid & year == `k' & F.sjd==1
				
				sort jobid year
				capture drop temp
				capture drop temp2
				by jobid year: egen temp 	= count(f`i')
				by jobid year: egen temp2 	= count(b`k')
				
				* Drop if the minimum number of job stayers is not fulfilled - 3 in the baseline sample
				drop if temp<3 & year == `i'
				drop if temp2<3 & year == `k'
				
				*drop temp temp2
				
				sort jobid year
				foreach x of varlist colag sex ft sic{
					by jobid year: egen asd_`x'_`i' = mean(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = mean(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}
				foreach x of varlist age tenure idbrnemp{
					by jobid year: egen asd_`x'_`i' = median(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = median(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}		
				foreach x of varlist logwage_cpi loghours{
					by jobid year: egen asd_`x'_`i' = median(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = median(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				} 		
				drop f`i' b`k'
				
				capture drop tag
				egen tag = tag(jobid)
				drop if tag==0
				drop tag

				* compute the mean age and tenure for normalisation
				egen asd_age = mean(age_`i')
				egen asd_ten = mean(tenure_`i')
				sort jobid
				foreach x of varlist age_`k' age_`i'{
					by jobid: gen sq`x' = (`x'-asd_age)^2
					by jobid: gen cub`x' = (`x'-asd_age)^3
				}	
				foreach x of varlist tenure_`k' tenure_`i'{
					by jobid: gen sq`x' = (`x'-asd_ten)^2
					by jobid: gen cub`x' = (`x'-asd_ten)^3
				}				
				
				keep jobid temp2 sic age_* loghours_* colag_* sex_* ft_* sqtenure_* sqage_* cubtenure_* cubage_* idbrnemp_* logwage_cpi_* entref

				quietly reshape long age_ loghours_ colag_ sex_ ft_ sqtenure_ sqage_ cubtenure_ cubage_ idbrnemp_ logwage_cpi_ , i(jobid) j(year)
				
				rename idbrnemp_ asd
			
				g id = `i'
				
				rename asd idbrnemp_
				
				cd $reg_results_public_dir
				save temp`i'.dta, replace
			restore
		}

		* create empty dataset
		cd $reg_results_public_dir
		use temp2016.dta, clear
		forvalues i = 2015(-1)1999{
			append using temp`i'.dta
			capture erase temp`i'.dta
		}

		rename *_ *

		sort entref
		by entref: egen firm_end=max(year)
		by entref: egen firm_start=min(year)
		g firm_life=firm_end-firm_start+1
		drop entref

		* Keep only jobs which are observed for at least 50% of the years for which the firm exists
		sort jobid
		egen tag = tag(jobid year)
		replace tag=. if tag==0
		by jobid: egen rel_years = sum(tag)
		drop if (rel_years/firm_life)<0.5 & rel_years!=.
		drop rel_years tag firm*

		* temp2 is the number of job stayers in each job per year
		rename temp2 weighting

		egen temp = group(jobid id)
		drop jobid id
		rename temp jobid

		xtset, clear
		xtset jobid year

		quietly tab year, gen(d)

		g ind = 0 
		by jobid: replace ind = 1 if _n==2
		
		foreach k in logwage_cpi loghours{
			quietly areg `k' d2-d19 idbrnemp sqage sqtenure cubage cubtenure colag, absorb(jobid) vce(cluster jobid)
			preserve
				clear
				set obs 18
				gen year = _n + 1998
				gen beta = .
				gen beta_se = .
				forvalue i = 2/19{
					quietly replace beta=_b[d`i'] if year == 1997+`i'
					quietly replace beta_se=_se[d`i'] if year == 1997+`i'
				}
				
				quietly rename beta_se `k'_med_se2
				quietly rename beta `k'_med2
				cd $reg_results_public_dir 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_public_dir
		use beta_logwage_cpi, clear
		quietly merge 1:1 year using beta_loghours, nogen
		save results_2.dta, replace
			
		capture erase temp2016.dta
		capture erase beta_loghours.dta
		capture erase beta_logwage_cpi.dta

	}

	cd $other_data
	use econ, clear
	cd $reg_results_public_dir
	quietly merge 1:1 year using results_1, nogen
	quietly merge 1:1 year using results_2, nogen
	drop if year==1997
	
	save results_97_16.dta, replace
	capture erase results_1.dta
	capture erase results_2.dta
	
	/* Second step regression */{
	
		tsset year

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				forvalue i =1/2{
					preserve
						quietly newey `p'_med`i' `k' year, lag(1)
						clear
						set obs 1
						gen b_`k' = _b[`k']
						gen se_`k' = _se[`k']
						gen spec= `i'
						cd $reg_results_public_dir
						save `p'`k'`i'.dta, replace
					restore
				}
			}
		}

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				cd $reg_results_public_dir
				use `p'`k'1, clear
				quietly append using `p'`k'2
				erase `p'`k'2.dta
				save `p'`k'.dta, replace
				erase `p'`k'1.dta
			}
		}

		foreach p in logwage_cpi loghours{
			cd $reg_results_public_dir
			use `p'unemp, clear
			save `p'.dta, replace
			erase `p'unemp.dta
		}

		
	}

}

	if $rpi==1{
	/* Define regression programme */{
		capture program drop reg_wages
		program define reg_wages

		* Keep only private enterprises
		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		sort jobid year
		
		*** COVARIATES
		foreach k in age idbrnemp{
			by jobid year: egen `k'_j = median(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		replace sex = 0 if sex==2
		foreach k in colag sex{
			by jobid year: egen `k'_j = mean(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		foreach p in logwage_rpi{
			by jobid year: egen `p'_med = median(`p')
			drop `p'
			}

		* Keep one obs per job and year
		egen tag = tag(jobid year)
		keep if tag==1
		drop tag

		* Compute the average age over all new hires in all years for normalisation
		egen asd_age = mean(age)
		* Create covariates
		g agesq 		= (age-asd_age)^2
		g agecub 		= (age-asd_age)^3
		g idbrnempsq 	= idbrnemp^2

		* Set panel and time series variables
		xtset, clear
		xtset jobid year

		* Year dummies
		quietly tab year, gen(d)
		
		foreach k in logwage_rpi_med{
			preserve
				quietly areg `k' d2-d19 age agesq agecub idbrnemp idbrnempsq sex colag, absorb(jobid) vce(cluster jobid)
				matrix b = e(b)
				clear
				svmat b
				forvalue i=1/18 {
				rename b`i' c`i'
				}
				drop b*
				xpose, clear
				capture drop year
				gen year=_n + 1998
				gen se=.
				forvalue i = 2/19{
					quietly replace se=_se[d`i'] if year==1997+`i'
				}	
				quietly rename se `k'_se`1'
				quietly rename v1 `k'`1'
				cd $reg_results_deflators 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_deflators 
		use beta_logwage_rpi_med, clear
		save results_`1'.dta, replace
		
		capture erase beta_logwage_rpi_med.dta
		
		end

		* end areg programme
	}
	/* New hires - wages and hours */{

		cd $created_datadir
		use slim_1997_2016, clear

		* define sample to be analysed
		drop if poe!=1

		* Run the regression program
		reg_wages 1
		
	}
	/* Job stayers - wages and hours */{

		cd $created_datadir
		use slim_1997_2016, clear

		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		xtset, clear
		xtset piden year

		drop poe* w*
		drop if idbrnemp==0

		replace sex = 0 if sex==1
		replace sex = 1 if sex==2

		forvalues i = 2016(-1)1999{
			preserve
				local k = `i' - 1
				keep if (year == `i') | (year == `k')
				keep piden jobid year age tenure idbrnemp log* sjd entref sex colag ft sic
				
				* Keep only employees who are observed in the same job consecutively
				sort piden year
				capture drop f`i'
				quiet gen f`i' = .
				quiet by piden: replace f`i'=1 if L.jobid==jobid & year == `i' & sjd==1 

				capture drop b`k'
				quiet gen b`k' = .
				quiet by piden: replace b`k'=1 if F.jobid==jobid & year == `k' & F.sjd==1
				
				sort jobid year
				capture drop temp
				capture drop temp2
				by jobid year: egen temp 	= count(f`i')
				by jobid year: egen temp2 	= count(b`k')
				
				* Drop if the minimum number of job stayers is not fulfilled - 3 in the baseline sample
				drop if temp<3 & year == `i'
				drop if temp2<3 & year == `k'
				
				*drop temp temp2
				
				sort jobid year
				foreach x of varlist colag sex ft sic{
					by jobid year: egen asd_`x'_`i' = mean(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = mean(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}
				foreach x of varlist age tenure idbrnemp{
					by jobid year: egen asd_`x'_`i' = median(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = median(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}		
				foreach x of varlist logwage_rpi{
					by jobid year: egen asd_`x'_`i' = median(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = median(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				} 		
				drop f`i' b`k'
				
				capture drop tag
				egen tag = tag(jobid)
				drop if tag==0
				drop tag

				* compute the mean age and tenure for normalisation
				egen asd_age = mean(age_`i')
				egen asd_ten = mean(tenure_`i')
				sort jobid
				foreach x of varlist age_`k' age_`i'{
					by jobid: gen sq`x' = (`x'-asd_age)^2
					by jobid: gen cub`x' = (`x'-asd_age)^3
				}	
				foreach x of varlist tenure_`k' tenure_`i'{
					by jobid: gen sq`x' = (`x'-asd_ten)^2
					by jobid: gen cub`x' = (`x'-asd_ten)^3
				}				
				
				keep jobid temp2 sic age_* colag_* sex_* ft_* sqtenure_* sqage_* cubtenure_* cubage_* idbrnemp_* logwage_rpi_* entref

				quietly reshape long age_ colag_ sex_ ft_ sqtenure_ sqage_ cubtenure_ cubage_ idbrnemp_ logwage_rpi_ , i(jobid) j(year)
				
				rename idbrnemp_ asd
			
				g id = `i'
				
				rename asd idbrnemp_
				
				cd $reg_results_deflators
				save temp`i'.dta, replace
			restore
		}

		* create empty dataset
		cd $reg_results_deflators
		use temp2016.dta, clear
		forvalues i = 2015(-1)1999{
			append using temp`i'.dta
			capture erase temp`i'.dta
		}

		rename *_ *

		sort entref
		by entref: egen firm_end=max(year)
		by entref: egen firm_start=min(year)
		g firm_life=firm_end-firm_start+1
		drop entref

		* Keep only jobs which are observed for at least 50% of the years for which the firm exists
		sort jobid
		egen tag = tag(jobid year)
		replace tag=. if tag==0
		by jobid: egen rel_years = sum(tag)
		drop if (rel_years/firm_life)<0.5 & rel_years!=.
		drop rel_years tag firm*

		* temp2 is the number of job stayers in each job per year
		rename temp2 weighting

		egen temp = group(jobid id)
		drop jobid id
		rename temp jobid

		xtset, clear
		xtset jobid year

		quietly tab year, gen(d)

		g ind = 0 
		by jobid: replace ind = 1 if _n==2
		
		foreach k in logwage_rpi{
			quietly areg `k' d2-d19 idbrnemp sqage sqtenure cubage cubtenure colag, absorb(jobid) vce(cluster jobid)
			preserve
				clear
				set obs 18
				gen year = _n + 1998
				gen beta = .
				gen beta_se = .
				forvalue i = 2/19{
					quietly replace beta=_b[d`i'] if year == 1997+`i'
					quietly replace beta_se=_se[d`i'] if year == 1997+`i'
				}
				
				quietly rename beta_se `k'_med_se2
				quietly rename beta `k'_med2
				cd $reg_results_deflators 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_deflators
		use beta_logwage_rpi, clear
		save results_2.dta, replace
			
		capture erase temp2016.dta
		capture erase beta_logwage_rpi.dta

	}

	cd $other_data
	use econ, clear
	cd $reg_results_deflators
	quietly merge 1:1 year using results_1, nogen
	quietly merge 1:1 year using results_2, nogen
	drop if year==1997
	
	save results_97_16.dta, replace
	capture erase results_1.dta
	capture erase results_2.dta

	/* Second step regression */{
	
		tsset year

		foreach p in logwage_rpi{
			foreach k in unemp{
				forvalue i =1/2{
					preserve
						quietly newey `p'_med`i' `k' year, lag(1)
						clear
						set obs 1
						gen b_`k' = _b[`k']
						gen se_`k' = _se[`k']
						gen spec= `i'
						cd $reg_results_deflators
						save `p'`k'`i'.dta, replace
					restore
				}
			}
		}

		foreach p in logwage_rpi{
			foreach k in unemp{
				cd $reg_results_deflators
				use `p'`k'1, clear
				quietly append using `p'`k'2
				erase `p'`k'2.dta
				save `p'`k'.dta, replace
				erase `p'`k'1.dta
			}
		}

		foreach p in logwage_rpi{
			cd $reg_results_deflators
			use `p'unemp, clear
			save `p'.dta, replace
			erase `p'unemp.dta
		}

		
	}

}

}

/* TABLE B2 */{

	* Set globals, i.e. which results are generated
	global min_hires2	= 1 // 2 hires minimum
	global min_hires4	= 1 // 4 hires minimum
	global min_hires5	= 1 // 5 hires minimum
	global min_hires6	= 1 // 6 hires minimum
	global min_hires7	= 1 // 7 hires minimum
	global min_hires8	= 1 // 8 hires minimum
	global min_hires9	= 1 // 9 hires minimum
	global min_hires10	= 1 // 10 hires minimum

	if $min_hires2==1{
	/* Define regression programme */{
		capture program drop reg_wages
		program define reg_wages

		* Keep only private enterprises
		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		sort jobid year
		
		*** COVARIATES
		foreach k in age idbrnemp{
			by jobid year: egen `k'_j = median(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		replace sex = 0 if sex==2
		foreach k in colag sex{
			by jobid year: egen `k'_j = mean(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		foreach p in logwage_cpi loghours{
			by jobid year: egen `p'_med = mean(`p')
			drop `p'
			}

		* Keep one obs per job and year
		egen tag = tag(jobid year)
		keep if tag==1
		drop tag

		* Compute the average age over all new hires in all years for normalisation
		egen asd_age = mean(age)
		* Create covariates
		g agesq 		= (age-asd_age)^2
		g agecub 		= (age-asd_age)^3
		g idbrnempsq 	= idbrnemp^2

		* Set panel and time series variables
		xtset, clear
		xtset jobid year

		* Year dummies
		quietly tab year, gen(d)
		
		foreach k in logwage_cpi_med loghours_med{
			preserve
				quietly areg `k' d2-d19 age agesq agecub idbrnemp idbrnempsq sex colag, absorb(jobid) vce(cluster jobid)
				matrix b = e(b)
				clear
				svmat b
				forvalue i=1/18 {
				rename b`i' c`i'
				}
				drop b*
				xpose, clear
				capture drop year
				gen year=_n + 1998
				gen se=.
				forvalue i = 2/19{
					quietly replace se=_se[d`i'] if year==1997+`i'
				}	
				quietly rename se `k'_se`1'
				quietly rename v1 `k'`1'
				cd $reg_results_poe_criteria 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_poe_criteria 
		use beta_logwage_cpi_med, clear
		quietly merge 1:1 year using beta_loghours_med, nogen
		save results_`1'.dta, replace
		
		capture erase beta_logwage_cpi_med.dta
		capture erase beta_loghours_med.dta
		
		end

		* end areg programme
	}
	/* New hires - wages and hours */{

		cd $reg_results_poe_criteria
		use slim_1997_2016_3, clear

		* define sample to be analysed
		drop if poe!=1

		* Run the regression program
		reg_wages 1
		
	}
	/* Job stayers - wages and hours */{

		cd $reg_results_poe_criteria
		use slim_1997_2016_3, clear

		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		xtset, clear
		xtset piden year

		drop poe* w*
		drop if idbrnemp==0

		replace sex = 0 if sex==1
		replace sex = 1 if sex==2

		forvalues i = 2016(-1)1999{
			preserve
				local k = `i' - 1
				keep if (year == `i') | (year == `k')
				keep piden jobid year age tenure idbrnemp log* sjd entref sex colag ft sic
				
				* Keep only employees who are observed in the same job consecutively
				sort piden year
				capture drop f`i'
				quiet gen f`i' = .
				quiet by piden: replace f`i'=1 if L.jobid==jobid & year == `i' & sjd==1 

				capture drop b`k'
				quiet gen b`k' = .
				quiet by piden: replace b`k'=1 if F.jobid==jobid & year == `k' & F.sjd==1
				
				sort jobid year
				capture drop temp
				capture drop temp2
				by jobid year: egen temp 	= count(f`i')
				by jobid year: egen temp2 	= count(b`k')
				
				* Drop if the minimum number of job stayers is not fulfilled
				drop if temp<2 & year == `i'
				drop if temp2<2 & year == `k'
				
				*drop temp temp2
				
				sort jobid year
				foreach x of varlist colag sex ft sic{
					by jobid year: egen asd_`x'_`i' = mean(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = mean(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}
				foreach x of varlist age tenure idbrnemp{
					by jobid year: egen asd_`x'_`i' = median(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = median(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}		
				foreach x of varlist logwage_cpi loghours{
					by jobid year: egen asd_`x'_`i' = mean(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = mean(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				} 		
				drop f`i' b`k'
				
				capture drop tag
				egen tag = tag(jobid)
				drop if tag==0
				drop tag

				* compute the mean age and tenure for normalisation
				egen asd_age = mean(age_`i')
				egen asd_ten = mean(tenure_`i')
				sort jobid
				foreach x of varlist age_`k' age_`i'{
					by jobid: gen sq`x' = (`x'-asd_age)^2
					by jobid: gen cub`x' = (`x'-asd_age)^3
				}	
				foreach x of varlist tenure_`k' tenure_`i'{
					by jobid: gen sq`x' = (`x'-asd_ten)^2
					by jobid: gen cub`x' = (`x'-asd_ten)^3
				}				
				
				keep jobid temp2 sic age_* loghours_* colag_* sex_* ft_* sqtenure_* sqage_* cubtenure_* cubage_* idbrnemp_* logwage_cpi_* entref

				quietly reshape long age_ loghours_ colag_ sex_ ft_ sqtenure_ sqage_ cubtenure_ cubage_ idbrnemp_ logwage_cpi_ , i(jobid) j(year)
				
				rename idbrnemp_ asd
			
				g id = `i'
				
				rename asd idbrnemp_
				
				cd $reg_results_poe_criteria
				save temp`i'.dta, replace
			restore
		}

		* create empty dataset
		cd $reg_results_poe_criteria
		use temp2016.dta, clear
		forvalues i = 2015(-1)1999{
			append using temp`i'.dta
			capture erase temp`i'.dta
		}

		rename *_ *

		sort entref
		by entref: egen firm_end=max(year)
		by entref: egen firm_start=min(year)
		g firm_life=firm_end-firm_start+1
		drop entref

		* Keep only jobs which are observed for at least 50% of the years for which the firm exists
		sort jobid
		egen tag = tag(jobid year)
		replace tag=. if tag==0
		by jobid: egen rel_years = sum(tag)
		drop if (rel_years/firm_life)<0.5 & rel_years!=.
		drop rel_years tag firm*

		* temp2 is the number of job stayers in each job per year
		rename temp2 weighting

		egen temp = group(jobid id)
		drop jobid id
		rename temp jobid

		xtset, clear
		xtset jobid year

		quietly tab year, gen(d)

		g ind = 0 
		by jobid: replace ind = 1 if _n==2
		
		foreach k in logwage_cpi loghours{
			quietly areg `k' d2-d19 idbrnemp sqage sqtenure cubage cubtenure colag, absorb(jobid) vce(cluster jobid)
			preserve
				clear
				set obs 18
				gen year = _n + 1998
				gen beta = .
				gen beta_se = .
				forvalue i = 2/19{
					quietly replace beta=_b[d`i'] if year == 1997+`i'
					quietly replace beta_se=_se[d`i'] if year == 1997+`i'
				}
				
				quietly rename beta_se `k'_med_se2
				quietly rename beta `k'_med2
				cd $reg_results_poe_criteria 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_poe_criteria
		use beta_logwage_cpi, clear
		quietly merge 1:1 year using beta_loghours, nogen
		save results_2.dta, replace
			
		capture erase temp2016.dta
		capture erase beta_loghours.dta
		capture erase beta_logwage_cpi.dta

	}

	cd $other_data
	use econ, clear
	cd $reg_results_poe_criteria
	quietly merge 1:1 year using results_1, nogen
	quietly merge 1:1 year using results_2, nogen
	drop if year==1997
	
	save results_97_16_poe3.dta, replace
	capture erase results_1.dta
	capture erase results_2.dta
	
	/* Second step regression */{
	
		tsset year

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				forvalue i =1/2{
					preserve
						quietly newey `p'_med`i' `k' year, lag(1)
						clear
						set obs 1
						gen b_`k' = _b[`k']
						gen se_`k' = _se[`k']
						gen spec= `i'
						cd $reg_results_poe_criteria
						save `p'`k'`i'.dta, replace
					restore
				}
			}
		}

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				cd $reg_results_poe_criteria
				use `p'`k'1, clear
				quietly append using `p'`k'2
				erase `p'`k'2.dta
				save `p'`k'.dta, replace
				erase `p'`k'1.dta
			}
		}

		foreach p in logwage_cpi loghours{
			cd $reg_results_poe_criteria
			use `p'unemp, clear
			save `p'3.dta, replace
			erase `p'unemp.dta
		}

		
	}

}

	if $min_hires4==1{
	/* Define regression programme */{
		capture program drop reg_wages
		program define reg_wages

		* Keep only private enterprises
		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		sort jobid year
		
		*** COVARIATES
		foreach k in age idbrnemp{
			by jobid year: egen `k'_j = median(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		replace sex = 0 if sex==2
		foreach k in colag sex{
			by jobid year: egen `k'_j = mean(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		foreach p in logwage_cpi loghours{
			by jobid year: egen `p'_med = mean(`p')
			drop `p'
			}

		* Keep one obs per job and year
		egen tag = tag(jobid year)
		keep if tag==1
		drop tag

		* Compute the average age over all new hires in all years for normalisation
		egen asd_age = mean(age)
		* Create covariates
		g agesq 		= (age-asd_age)^2
		g agecub 		= (age-asd_age)^3
		g idbrnempsq 	= idbrnemp^2

		* Set panel and time series variables
		xtset, clear
		xtset jobid year

		* Year dummies
		quietly tab year, gen(d)
		
		foreach k in logwage_cpi_med loghours_med{
			preserve
				quietly areg `k' d2-d19 age agesq agecub idbrnemp idbrnempsq sex colag, absorb(jobid) vce(cluster jobid)
				matrix b = e(b)
				clear
				svmat b
				forvalue i=1/18 {
				rename b`i' c`i'
				}
				drop b*
				xpose, clear
				capture drop year
				gen year=_n + 1998
				gen se=.
				forvalue i = 2/19{
					quietly replace se=_se[d`i'] if year==1997+`i'
				}	
				quietly rename se `k'_se`1'
				quietly rename v1 `k'`1'
				cd $reg_results_poe_criteria 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_poe_criteria 
		use beta_logwage_cpi_med, clear
		quietly merge 1:1 year using beta_loghours_med, nogen
		save results_`1'.dta, replace
		
		capture erase beta_logwage_cpi_med.dta
		capture erase beta_loghours_med.dta
		
		end

		* end areg programme
	}
	/* New hires - wages and hours */{

		cd $reg_results_poe_criteria
		use slim_1997_2016_4, clear

		* define sample to be analysed
		drop if poe!=1

		* Run the regression program
		reg_wages 1
		
	}
	/* Job stayers - wages and hours */{

		cd $reg_results_poe_criteria
		use slim_1997_2016_4, clear
		* Do NOT drop year=1997, as first-diff for 1998 undefined otherwise 

		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		xtset, clear
		xtset piden year

		drop poe* w*
		drop if idbrnemp==0

		replace sex = 0 if sex==1
		replace sex = 1 if sex==2

		forvalues i = 2016(-1)1999{
			preserve
				local k = `i' - 1
				keep if (year == `i') | (year == `k')
				keep piden jobid year age tenure idbrnemp log* sjd entref sex colag ft sic
				
				* Keep only employees who are observed in the same job consecutively
				sort piden year
				capture drop f`i'
				quiet gen f`i' = .
				quiet by piden: replace f`i'=1 if L.jobid==jobid & year == `i' & sjd==1 

				capture drop b`k'
				quiet gen b`k' = .
				quiet by piden: replace b`k'=1 if F.jobid==jobid & year == `k' & F.sjd==1
				
				sort jobid year
				capture drop temp
				capture drop temp2
				by jobid year: egen temp 	= count(f`i')
				by jobid year: egen temp2 	= count(b`k')
				
				* Drop if the minimum number of job stayers is not fulfilled
				drop if temp<4 & year == `i'
				drop if temp2<4 & year == `k'
				
				*drop temp temp2
				
				sort jobid year
				foreach x of varlist colag sex ft sic{
					by jobid year: egen asd_`x'_`i' = mean(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = mean(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}
				foreach x of varlist age tenure idbrnemp{
					by jobid year: egen asd_`x'_`i' = median(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = median(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}		
				foreach x of varlist logwage_cpi loghours{
					by jobid year: egen asd_`x'_`i' = mean(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = mean(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				} 		
				drop f`i' b`k'
				
				capture drop tag
				egen tag = tag(jobid)
				drop if tag==0
				drop tag

				* compute the mean age and tenure for normalisation
				egen asd_age = mean(age_`i')
				egen asd_ten = mean(tenure_`i')
				sort jobid
				foreach x of varlist age_`k' age_`i'{
					by jobid: gen sq`x' = (`x'-asd_age)^2
					by jobid: gen cub`x' = (`x'-asd_age)^3
				}	
				foreach x of varlist tenure_`k' tenure_`i'{
					by jobid: gen sq`x' = (`x'-asd_ten)^2
					by jobid: gen cub`x' = (`x'-asd_ten)^3
				}
				
				keep jobid temp2 sic age_* loghours_* colag_* sex_* ft_* sqtenure_* sqage_* cubtenure_* cubage_* idbrnemp_* logwage_cpi_* entref

				quietly reshape long age_ loghours_ colag_ sex_ ft_ sqtenure_ sqage_ cubtenure_ cubage_ idbrnemp_ logwage_cpi_ , i(jobid) j(year)
				
				rename idbrnemp_ asd
			
				g id = `i'
				
				rename asd idbrnemp_
				
				cd $reg_results_poe_criteria
				save temp`i'.dta, replace
			restore
		}

		* create empty dataset
		cd $reg_results_poe_criteria
		use temp2016.dta, clear
		forvalues i = 2015(-1)1999{
			append using temp`i'.dta
			capture erase temp`i'.dta
		}

		rename *_ *

		sort entref
		by entref: egen firm_end=max(year)
		by entref: egen firm_start=min(year)
		g firm_life=firm_end-firm_start+1
		drop entref

		* Keep only jobs which are observed for at least 50% of the years for which the firm exists
		sort jobid
		egen tag = tag(jobid year)
		replace tag=. if tag==0
		by jobid: egen rel_years = sum(tag)
		drop if (rel_years/firm_life)<0.5 & rel_years!=.
		drop rel_years tag firm*

		* temp2 is the number of job stayers in each job per year
		rename temp2 weighting

		egen temp = group(jobid id)
		drop jobid id
		rename temp jobid

		xtset, clear
		xtset jobid year

		quietly tab year, gen(d)

		g ind = 0 
		by jobid: replace ind = 1 if _n==2
		
		foreach k in logwage_cpi loghours{
			quietly areg `k' d2-d19 idbrnemp sqage sqtenure cubage cubtenure colag, absorb(jobid) vce(cluster jobid)
			preserve
				clear
				set obs 18
				gen year = _n + 1998
				gen beta = .
				gen beta_se = .
				forvalue i = 2/19{
					quietly replace beta=_b[d`i'] if year == 1997+`i'
					quietly replace beta_se=_se[d`i'] if year == 1997+`i'
				}
				
				quietly rename beta_se `k'_med_se2
				quietly rename beta `k'_med2
				cd $reg_results_poe_criteria 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_poe_criteria
		use beta_logwage_cpi, clear
		quietly merge 1:1 year using beta_loghours, nogen
		save results_2.dta, replace
			
		capture erase temp2016.dta
		capture erase beta_loghours.dta
		capture erase beta_logwage_cpi.dta

	}

	cd $other_data
	use econ, clear
	cd $reg_results_poe_criteria
	quietly merge 1:1 year using results_1, nogen
	quietly merge 1:1 year using results_2, nogen
	drop if year==1997
	
	save results_97_16_poe4.dta, replace
	capture erase results_1.dta
	capture erase results_2.dta

	/* Second step regression */{
	
		tsset year

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				forvalue i =1/2{
					preserve
						quietly newey `p'_med`i' `k' year, lag(1)
						clear
						set obs 1
						gen b_`k' = _b[`k']
						gen se_`k' = _se[`k']
						gen spec= `i'
						cd $reg_results_poe_criteria
						save `p'`k'`i'.dta, replace
					restore
				}
			}
		}

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				cd $reg_results_poe_criteria
				use `p'`k'1, clear
				quietly append using `p'`k'2
				erase `p'`k'2.dta
				save `p'`k'.dta, replace
				erase `p'`k'1.dta
			}
		}

		foreach p in logwage_cpi loghours{
			cd $reg_results_poe_criteria
			use `p'unemp, clear
			save `p'4.dta, replace
			erase `p'unemp.dta
		}

		
	}

}

	if $min_hires5==1{
	/* Define regression programme */{
		capture program drop reg_wages
		program define reg_wages

		* Keep only private enterprises
		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		sort jobid year
		
		*** COVARIATES
		foreach k in age idbrnemp{
			by jobid year: egen `k'_j = median(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		replace sex = 0 if sex==2
		foreach k in colag sex{
			by jobid year: egen `k'_j = mean(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		foreach p in logwage_cpi loghours{
			by jobid year: egen `p'_med = mean(`p')
			drop `p'
			}

		* Keep one obs per job and year
		egen tag = tag(jobid year)
		keep if tag==1
		drop tag

		* Compute the average age over all new hires in all years for normalisation
		egen asd_age = mean(age)
		* Create covariates
		g agesq 		= (age-asd_age)^2
		g agecub 		= (age-asd_age)^3
		g idbrnempsq 	= idbrnemp^2

		* Set panel and time series variables
		xtset, clear
		xtset jobid year

		* Year dummies
		quietly tab year, gen(d)
		
		foreach k in logwage_cpi_med loghours_med{
			preserve
				quietly areg `k' d2-d19 age agesq agecub idbrnemp idbrnempsq sex colag, absorb(jobid) vce(cluster jobid)
				matrix b = e(b)
				clear
				svmat b
				forvalue i=1/18 {
				rename b`i' c`i'
				}
				drop b*
				xpose, clear
				capture drop year
				gen year=_n + 1998
				gen se=.
				forvalue i = 2/19{
					quietly replace se=_se[d`i'] if year==1997+`i'
				}	
				quietly rename se `k'_se`1'
				quietly rename v1 `k'`1'
				cd $reg_results_poe_criteria 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_poe_criteria 
		use beta_logwage_cpi_med, clear
		quietly merge 1:1 year using beta_loghours_med, nogen
		save results_`1'.dta, replace
		
		capture erase beta_logwage_cpi_med.dta
		capture erase beta_loghours_med.dta
		
		end

		* end areg programme
	}
	/* New hires - wages and hours */{

		cd $reg_results_poe_criteria
		use slim_1997_2016_5, clear

		* define sample to be analysed
		drop if poe!=1

		* Run the regression program
		reg_wages 1
		
	}
	/* Job stayers - wages and hours */{

		cd $reg_results_poe_criteria
		use slim_1997_2016_5, clear
		* Do NOT drop year=1997, as first-diff for 1998 undefined otherwise 

		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		xtset, clear
		xtset piden year

		drop poe* w*
		drop if idbrnemp==0

		replace sex = 0 if sex==1
		replace sex = 1 if sex==2

		forvalues i = 2016(-1)1999{
			preserve
				local k = `i' - 1
				keep if (year == `i') | (year == `k')
				keep piden jobid year age tenure idbrnemp log* sjd entref sex colag ft sic
				
				* Keep only employees who are observed in the same job consecutively
				sort piden year
				capture drop f`i'
				quiet gen f`i' = .
				quiet by piden: replace f`i'=1 if L.jobid==jobid & year == `i' & sjd==1 

				capture drop b`k'
				quiet gen b`k' = .
				quiet by piden: replace b`k'=1 if F.jobid==jobid & year == `k' & F.sjd==1
				
				sort jobid year
				capture drop temp
				capture drop temp2
				by jobid year: egen temp 	= count(f`i')
				by jobid year: egen temp2 	= count(b`k')
				
				* Drop if the minimum number of job stayers is not fulfilled
				drop if temp<5 & year == `i'
				drop if temp2<5 & year == `k'
				
				*drop temp temp2
				
				sort jobid year
				foreach x of varlist colag sex ft sic{
					by jobid year: egen asd_`x'_`i' = mean(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = mean(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}
				foreach x of varlist age tenure idbrnemp{
					by jobid year: egen asd_`x'_`i' = median(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = median(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}		
				foreach x of varlist logwage_cpi loghours{
					by jobid year: egen asd_`x'_`i' = mean(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = mean(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				} 		
				drop f`i' b`k'
				
				capture drop tag
				egen tag = tag(jobid)
				drop if tag==0
				drop tag

				* compute the mean age and tenure for normalisation
				egen asd_age = mean(age_`i')
				egen asd_ten = mean(tenure_`i')
				sort jobid
				foreach x of varlist age_`k' age_`i'{
					by jobid: gen sq`x' = (`x'-asd_age)^2
					by jobid: gen cub`x' = (`x'-asd_age)^3
				}	
				foreach x of varlist tenure_`k' tenure_`i'{
					by jobid: gen sq`x' = (`x'-asd_ten)^2
					by jobid: gen cub`x' = (`x'-asd_ten)^3
				}				
				
				keep jobid temp2 sic age_* loghours_* colag_* sex_* ft_* sqtenure_* sqage_* cubtenure_* cubage_* idbrnemp_* logwage_cpi_* entref

				quietly reshape long age_ loghours_ colag_ sex_ ft_ sqtenure_ sqage_ cubtenure_ cubage_ idbrnemp_ logwage_cpi_ , i(jobid) j(year)
				
				rename idbrnemp_ asd
			
				g id = `i'
				
				rename asd idbrnemp_
				
				cd $reg_results_poe_criteria
				save temp`i'.dta, replace
			restore
		}

		* create empty dataset
		cd $reg_results_poe_criteria
		use temp2016.dta, clear
		forvalues i = 2015(-1)1999{
			append using temp`i'.dta
			capture erase temp`i'.dta
		}

		rename *_ *

		sort entref
		by entref: egen firm_end=max(year)
		by entref: egen firm_start=min(year)
		g firm_life=firm_end-firm_start+1
		drop entref

		* Keep only jobs which are observed for at least 50% of the years for which the firm exists
		sort jobid
		egen tag = tag(jobid year)
		replace tag=. if tag==0
		by jobid: egen rel_years = sum(tag)
		drop if (rel_years/firm_life)<0.5 & rel_years!=.
		drop rel_years tag firm*

		* temp2 is the number of job stayers in each job per year
		rename temp2 weighting

		egen temp = group(jobid id)
		drop jobid id
		rename temp jobid

		xtset, clear
		xtset jobid year

		quietly tab year, gen(d)

		g ind = 0 
		by jobid: replace ind = 1 if _n==2
		
		foreach k in logwage_cpi loghours{
			quietly areg `k' d2-d19 idbrnemp sqage sqtenure cubage cubtenure colag, absorb(jobid) vce(cluster jobid)
			preserve
				clear
				set obs 18
				gen year = _n + 1998
				gen beta = .
				gen beta_se = .
				forvalue i = 2/19{
					quietly replace beta=_b[d`i'] if year == 1997+`i'
					quietly replace beta_se=_se[d`i'] if year == 1997+`i'
				}
				
				quietly rename beta_se `k'_med_se2
				quietly rename beta `k'_med2
				cd $reg_results_poe_criteria 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_poe_criteria
		use beta_logwage_cpi, clear
		quietly merge 1:1 year using beta_loghours, nogen
		save results_2.dta, replace
			
		capture erase temp2016.dta
		capture erase beta_loghours.dta
		capture erase beta_logwage_cpi.dta

	}

	cd $other_data
	use econ, clear
	cd $reg_results_poe_criteria
	quietly merge 1:1 year using results_1, nogen
	quietly merge 1:1 year using results_2, nogen
	drop if year==1997
	
	save results_97_16_poe5.dta, replace
	capture erase results_1.dta
	capture erase results_2.dta

	/* Second step regression */{
	
		tsset year

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				forvalue i =1/2{
					preserve
						quietly newey `p'_med`i' `k' year, lag(1)
						clear
						set obs 1
						gen b_`k' = _b[`k']
						gen se_`k' = _se[`k']
						gen spec= `i'
						cd $reg_results_poe_criteria
						save `p'`k'`i'.dta, replace
					restore
				}
			}
		}

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				cd $reg_results_poe_criteria
				use `p'`k'1, clear
				quietly append using `p'`k'2
				erase `p'`k'2.dta
				save `p'`k'.dta, replace
				erase `p'`k'1.dta
			}
		}

		foreach p in logwage_cpi loghours{
			cd $reg_results_poe_criteria
			use `p'unemp, clear
			save `p'5.dta, replace
			erase `p'unemp.dta
		}

		
	}

}

	if $min_hires6==1{
	/* Define regression programme */{
		capture program drop reg_wages
		program define reg_wages

		* Keep only private enterprises
		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		sort jobid year
		
		*** COVARIATES
		foreach k in age idbrnemp{
			by jobid year: egen `k'_j = median(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		replace sex = 0 if sex==2
		foreach k in colag sex{
			by jobid year: egen `k'_j = mean(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		foreach p in logwage_cpi loghours{
			by jobid year: egen `p'_med = mean(`p')
			drop `p'
			}

		* Keep one obs per job and year
		egen tag = tag(jobid year)
		keep if tag==1
		drop tag

		* Compute the average age over all new hires in all years for normalisation
		egen asd_age = mean(age)
		* Create covariates
		g agesq 		= (age-asd_age)^2
		g agecub 		= (age-asd_age)^3
		g idbrnempsq 	= idbrnemp^2

		* Set panel and time series variables
		xtset, clear
		xtset jobid year

		* Year dummies
		quietly tab year, gen(d)
		
		foreach k in logwage_cpi_med loghours_med{
			preserve
				quietly areg `k' d2-d19 age agesq agecub idbrnemp idbrnempsq sex colag, absorb(jobid) vce(cluster jobid)
				matrix b = e(b)
				clear
				svmat b
				forvalue i=1/18 {
				rename b`i' c`i'
				}
				drop b*
				xpose, clear
				capture drop year
				gen year=_n + 1998
				gen se=.
				forvalue i = 2/19{
					quietly replace se=_se[d`i'] if year==1997+`i'
				}	
				quietly rename se `k'_se`1'
				quietly rename v1 `k'`1'
				cd $reg_results_poe_criteria 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_poe_criteria 
		use beta_logwage_cpi_med, clear
		quietly merge 1:1 year using beta_loghours_med, nogen
		save results_`1'.dta, replace
		
		capture erase beta_logwage_cpi_med.dta
		capture erase beta_loghours_med.dta
		
		end

		* end areg programme
	}
	/* New hires - wages and hours */{

		cd $reg_results_poe_criteria
		use slim_1997_2016_6, clear

		* define sample to be analysed
		drop if poe!=1

		* Run the regression program
		reg_wages 1
		
	}
	/* Job stayers - wages and hours */{

		cd $reg_results_poe_criteria
		use slim_1997_2016_6, clear
		* Do NOT drop year=1997, as first-diff for 1998 undefined otherwise 

		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		xtset, clear
		xtset piden year

		drop poe* w*
		drop if idbrnemp==0

		replace sex = 0 if sex==1
		replace sex = 1 if sex==2

		forvalues i = 2016(-1)1999{
			preserve
				local k = `i' - 1
				keep if (year == `i') | (year == `k')
				keep piden jobid year age tenure idbrnemp log* sjd entref sex colag ft sic
				
				* Keep only employees who are observed in the same job consecutively
				sort piden year
				capture drop f`i'
				quiet gen f`i' = .
				quiet by piden: replace f`i'=1 if L.jobid==jobid & year == `i' & sjd==1 

				capture drop b`k'
				quiet gen b`k' = .
				quiet by piden: replace b`k'=1 if F.jobid==jobid & year == `k' & F.sjd==1
				
				sort jobid year
				capture drop temp
				capture drop temp2
				by jobid year: egen temp 	= count(f`i')
				by jobid year: egen temp2 	= count(b`k')
				
				* Drop if the minimum number of job stayers is not fulfilled
				drop if temp<6 & year == `i'
				drop if temp2<6 & year == `k'
				
				*drop temp temp2
				
				sort jobid year
				foreach x of varlist colag sex ft sic{
					by jobid year: egen asd_`x'_`i' = mean(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = mean(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}
				foreach x of varlist age tenure idbrnemp{
					by jobid year: egen asd_`x'_`i' = median(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = median(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}		
				foreach x of varlist logwage_cpi loghours{
					by jobid year: egen asd_`x'_`i' = mean(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = mean(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				} 		
				drop f`i' b`k'
				
				capture drop tag
				egen tag = tag(jobid)
				drop if tag==0
				drop tag

				* compute the mean age and tenure for normalisation
				egen asd_age = mean(age_`i')
				egen asd_ten = mean(tenure_`i')
				sort jobid
				foreach x of varlist age_`k' age_`i'{
					by jobid: gen sq`x' = (`x'-asd_age)^2
					by jobid: gen cub`x' = (`x'-asd_age)^3
				}	
				foreach x of varlist tenure_`k' tenure_`i'{
					by jobid: gen sq`x' = (`x'-asd_ten)^2
					by jobid: gen cub`x' = (`x'-asd_ten)^3
				}				
				
				keep jobid temp2 sic age_* loghours_* colag_* sex_* ft_* sqtenure_* sqage_* cubtenure_* cubage_* idbrnemp_* logwage_cpi_* entref

				quietly reshape long age_ loghours_ colag_ sex_ ft_ sqtenure_ sqage_ cubtenure_ cubage_ idbrnemp_ logwage_cpi_ , i(jobid) j(year)
				
				rename idbrnemp_ asd
			
				g id = `i'
				
				rename asd idbrnemp_
				
				cd $reg_results_poe_criteria
				save temp`i'.dta, replace
			restore
		}

		* create empty dataset
		cd $reg_results_poe_criteria
		use temp2016.dta, clear
		forvalues i = 2015(-1)1999{
			append using temp`i'.dta
			capture erase temp`i'.dta
		}

		rename *_ *

		sort entref
		by entref: egen firm_end=max(year)
		by entref: egen firm_start=min(year)
		g firm_life=firm_end-firm_start+1
		drop entref

		* Keep only jobs which are observed for at least 50% of the years for which the firm exists
		sort jobid
		egen tag = tag(jobid year)
		replace tag=. if tag==0
		by jobid: egen rel_years = sum(tag)
		drop if (rel_years/firm_life)<0.5 & rel_years!=.
		drop rel_years tag firm*

		* temp2 is the number of job stayers in each job per year
		rename temp2 weighting

		egen temp = group(jobid id)
		drop jobid id
		rename temp jobid

		xtset, clear
		xtset jobid year

		quietly tab year, gen(d)

		g ind = 0 
		by jobid: replace ind = 1 if _n==2
		
		foreach k in logwage_cpi loghours{
			quietly areg `k' d2-d19 idbrnemp sqage sqtenure cubage cubtenure colag, absorb(jobid) vce(cluster jobid)
			preserve
				clear
				set obs 18
				gen year = _n + 1998
				gen beta = .
				gen beta_se = .
				forvalue i = 2/19{
					quietly replace beta=_b[d`i'] if year == 1997+`i'
					quietly replace beta_se=_se[d`i'] if year == 1997+`i'
				}
				
				quietly rename beta_se `k'_med_se2
				quietly rename beta `k'_med2
				cd $reg_results_poe_criteria 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_poe_criteria
		use beta_logwage_cpi, clear
		quietly merge 1:1 year using beta_loghours, nogen
		save results_2.dta, replace
			
		capture erase temp2016.dta
		capture erase beta_loghours.dta
		capture erase beta_logwage_cpi.dta

	}

	cd $other_data
	use econ, clear
	cd $reg_results_poe_criteria
	quietly merge 1:1 year using results_1, nogen
	quietly merge 1:1 year using results_2, nogen
	drop if year==1997
	
	save results_97_16_poe6.dta, replace
	capture erase results_1.dta
	capture erase results_2.dta
	
	/* Second step regression */{
	
		tsset year

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				forvalue i =1/2{
					preserve
						quietly newey `p'_med`i' `k' year, lag(1)
						clear
						set obs 1
						gen b_`k' = _b[`k']
						gen se_`k' = _se[`k']
						gen spec= `i'
						cd $reg_results_poe_criteria
						save `p'`k'`i'.dta, replace
					restore
				}
			}
		}

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				cd $reg_results_poe_criteria
				use `p'`k'1, clear
				quietly append using `p'`k'2
				erase `p'`k'2.dta
				save `p'`k'.dta, replace
				erase `p'`k'1.dta
			}
		}

		foreach p in logwage_cpi loghours{
			cd $reg_results_poe_criteria
			use `p'unemp, clear
			save `p'6.dta, replace
			erase `p'unemp.dta
		}

		
	}

}

	if $min_hires7==1{
	/* Define regression programme */{
		capture program drop reg_wages
		program define reg_wages

		* Keep only private enterprises
		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		sort jobid year
		
		*** COVARIATES
		foreach k in age idbrnemp{
			by jobid year: egen `k'_j = median(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		replace sex = 0 if sex==2
		foreach k in colag sex{
			by jobid year: egen `k'_j = mean(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		foreach p in logwage_cpi loghours{
			by jobid year: egen `p'_med = mean(`p')
			drop `p'
			}

		* Keep one obs per job and year
		egen tag = tag(jobid year)
		keep if tag==1
		drop tag

		* Compute the average age over all new hires in all years for normalisation
		egen asd_age = mean(age)
		* Create covariates
		g agesq 		= (age-asd_age)^2
		g agecub 		= (age-asd_age)^3
		g idbrnempsq 	= idbrnemp^2

		* Set panel and time series variables
		xtset, clear
		xtset jobid year

		* Year dummies
		quietly tab year, gen(d)
		
		foreach k in logwage_cpi_med loghours_med{
			preserve
				quietly areg `k' d2-d19 age agesq agecub idbrnemp idbrnempsq sex colag, absorb(jobid) vce(cluster jobid)
				matrix b = e(b)
				clear
				svmat b
				forvalue i=1/18 {
				rename b`i' c`i'
				}
				drop b*
				xpose, clear
				capture drop year
				gen year=_n + 1998
				gen se=.
				forvalue i = 2/19{
					quietly replace se=_se[d`i'] if year==1997+`i'
				}	
				quietly rename se `k'_se`1'
				quietly rename v1 `k'`1'
				cd $reg_results_poe_criteria 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_poe_criteria 
		use beta_logwage_cpi_med, clear
		quietly merge 1:1 year using beta_loghours_med, nogen
		save results_`1'.dta, replace
		
		capture erase beta_logwage_cpi_med.dta
		capture erase beta_loghours_med.dta
		
		end

		* end areg programme
	}
	/* New hires - wages and hours */{

		cd $reg_results_poe_criteria
		use slim_1997_2016_7, clear

		* define sample to be analysed
		drop if poe!=1

		* Run the regression program
		reg_wages 1
		
	}
	/* Job stayers - wages and hours */{

		cd $reg_results_poe_criteria
		use slim_1997_2016_7, clear
		* Do NOT drop year=1997, as first-diff for 1998 undefined otherwise 

		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		xtset, clear
		xtset piden year

		drop poe* w*
		drop if idbrnemp==0

		replace sex = 0 if sex==1
		replace sex = 1 if sex==2

		forvalues i = 2016(-1)1999{
			preserve
				local k = `i' - 1
				keep if (year == `i') | (year == `k')
				keep piden jobid year age tenure idbrnemp log* sjd entref sex colag ft sic
				
				* Keep only employees who are observed in the same job consecutively
				sort piden year
				capture drop f`i'
				quiet gen f`i' = .
				quiet by piden: replace f`i'=1 if L.jobid==jobid & year == `i' & sjd==1 

				capture drop b`k'
				quiet gen b`k' = .
				quiet by piden: replace b`k'=1 if F.jobid==jobid & year == `k' & F.sjd==1
				
				sort jobid year
				capture drop temp
				capture drop temp2
				by jobid year: egen temp 	= count(f`i')
				by jobid year: egen temp2 	= count(b`k')
				
				* Drop if the minimum number of job stayers is not fulfilled
				drop if temp<7 & year == `i'
				drop if temp2<7 & year == `k'
				
				*drop temp temp2
				
				sort jobid year
				foreach x of varlist colag sex ft sic{
					by jobid year: egen asd_`x'_`i' = mean(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = mean(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}
				foreach x of varlist age tenure idbrnemp{
					by jobid year: egen asd_`x'_`i' = median(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = median(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}		
				foreach x of varlist logwage_cpi loghours{
					by jobid year: egen asd_`x'_`i' = mean(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = mean(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				} 		
				drop f`i' b`k'
				
				capture drop tag
				egen tag = tag(jobid)
				drop if tag==0
				drop tag

				* compute the mean age and tenure for normalisation
				egen asd_age = mean(age_`i')
				egen asd_ten = mean(tenure_`i')
				sort jobid
				foreach x of varlist age_`k' age_`i'{
					by jobid: gen sq`x' = (`x'-asd_age)^2
					by jobid: gen cub`x' = (`x'-asd_age)^3
				}	
				foreach x of varlist tenure_`k' tenure_`i'{
					by jobid: gen sq`x' = (`x'-asd_ten)^2
					by jobid: gen cub`x' = (`x'-asd_ten)^3
				}				
				
				keep jobid temp2 sic age_* loghours_* colag_* sex_* ft_* sqtenure_* sqage_* cubtenure_* cubage_* idbrnemp_* logwage_cpi_* entref

				quietly reshape long age_ loghours_ colag_ sex_ ft_ sqtenure_ sqage_ cubtenure_ cubage_ idbrnemp_ logwage_cpi_ , i(jobid) j(year)
				
				rename idbrnemp_ asd
			
				g id = `i'
				
				rename asd idbrnemp_
				
				cd $reg_results_poe_criteria
				save temp`i'.dta, replace
			restore
		}

		* create empty dataset
		cd $reg_results_poe_criteria
		use temp2016.dta, clear
		forvalues i = 2015(-1)1999{
			append using temp`i'.dta
			capture erase temp`i'.dta
		}

		rename *_ *

		sort entref
		by entref: egen firm_end=max(year)
		by entref: egen firm_start=min(year)
		g firm_life=firm_end-firm_start+1
		drop entref

		* Keep only jobs which are observed for at least 50% of the years for which the firm exists
		sort jobid
		egen tag = tag(jobid year)
		replace tag=. if tag==0
		by jobid: egen rel_years = sum(tag)
		drop if (rel_years/firm_life)<0.5 & rel_years!=.
		drop rel_years tag firm*

		* temp2 is the number of job stayers in each job per year
		rename temp2 weighting

		egen temp = group(jobid id)
		drop jobid id
		rename temp jobid

		xtset, clear
		xtset jobid year

		quietly tab year, gen(d)

		g ind = 0 
		by jobid: replace ind = 1 if _n==2
		
		foreach k in logwage_cpi loghours{
			quietly areg `k' d2-d19 idbrnemp sqage sqtenure cubage cubtenure colag, absorb(jobid) vce(cluster jobid)
			preserve
				clear
				set obs 18
				gen year = _n + 1998
				gen beta = .
				gen beta_se = .
				forvalue i = 2/19{
					quietly replace beta=_b[d`i'] if year == 1997+`i'
					quietly replace beta_se=_se[d`i'] if year == 1997+`i'
				}
				
				quietly rename beta_se `k'_med_se2
				quietly rename beta `k'_med2
				cd $reg_results_poe_criteria 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_poe_criteria
		use beta_logwage_cpi, clear
		quietly merge 1:1 year using beta_loghours, nogen
		save results_2.dta, replace
			
		capture erase temp2016.dta
		capture erase beta_loghours.dta
		capture erase beta_logwage_cpi.dta

	}

	cd $other_data
	use econ, clear
	cd $reg_results_poe_criteria
	quietly merge 1:1 year using results_1, nogen
	quietly merge 1:1 year using results_2, nogen
	drop if year==1997
	
	save results_97_16_poe7.dta, replace
	capture erase results_1.dta
	capture erase results_2.dta
	
	/* Second step regression */{
	
		tsset year

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				forvalue i =1/2{
					preserve
						quietly newey `p'_med`i' `k' year, lag(1)
						clear
						set obs 1
						gen b_`k' = _b[`k']
						gen se_`k' = _se[`k']
						gen spec= `i'
						cd $reg_results_poe_criteria
						save `p'`k'`i'.dta, replace
					restore
				}
			}
		}

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				cd $reg_results_poe_criteria
				use `p'`k'1, clear
				quietly append using `p'`k'2
				erase `p'`k'2.dta
				save `p'`k'.dta, replace
				erase `p'`k'1.dta
			}
		}

		foreach p in logwage_cpi loghours{
			cd $reg_results_poe_criteria
			use `p'unemp, clear
			save `p'7.dta, replace
			erase `p'unemp.dta
		}

		
	}

}

	if $min_hires8==1{
	/* Define regression programme */{
		capture program drop reg_wages
		program define reg_wages

		* Keep only private enterprises
		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		sort jobid year
		
		*** COVARIATES
		foreach k in age idbrnemp{
			by jobid year: egen `k'_j = median(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		replace sex = 0 if sex==2
		foreach k in colag sex{
			by jobid year: egen `k'_j = mean(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		foreach p in logwage_cpi loghours{
			by jobid year: egen `p'_med = mean(`p')
			drop `p'
			}

		* Keep one obs per job and year
		egen tag = tag(jobid year)
		keep if tag==1
		drop tag

		* Compute the average age over all new hires in all years for normalisation
		egen asd_age = mean(age)
		* Create covariates
		g agesq 		= (age-asd_age)^2
		g agecub 		= (age-asd_age)^3
		g idbrnempsq 	= idbrnemp^2

		* Set panel and time series variables
		xtset, clear
		xtset jobid year

		* Year dummies
		quietly tab year, gen(d)
		
		foreach k in logwage_cpi_med loghours_med{
			preserve
				quietly areg `k' d2-d19 age agesq agecub idbrnemp idbrnempsq sex colag, absorb(jobid) vce(cluster jobid)
				matrix b = e(b)
				clear
				svmat b
				forvalue i=1/18 {
				rename b`i' c`i'
				}
				drop b*
				xpose, clear
				capture drop year
				gen year=_n + 1998
				gen se=.
				forvalue i = 2/19{
					quietly replace se=_se[d`i'] if year==1997+`i'
				}	
				quietly rename se `k'_se`1'
				quietly rename v1 `k'`1'
				cd $reg_results_poe_criteria 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_poe_criteria 
		use beta_logwage_cpi_med, clear
		quietly merge 1:1 year using beta_loghours_med, nogen
		save results_`1'.dta, replace
		
		capture erase beta_logwage_cpi_med.dta
		capture erase beta_loghours_med.dta
		
		end

		* end areg programme
	}
	/* New hires - wages and hours */{

		cd $reg_results_poe_criteria
		use slim_1997_2016_8, clear

		* define sample to be analysed
		drop if poe!=1

		* Run the regression program
		reg_wages 1
		
	}
	/* Job stayers - wages and hours */{

		cd $reg_results_poe_criteria
		use slim_1997_2016_8, clear
		* Do NOT drop year=1997, as first-diff for 1998 undefined otherwise 

		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		xtset, clear
		xtset piden year

		drop poe* w*
		drop if idbrnemp==0

		replace sex = 0 if sex==1
		replace sex = 1 if sex==2

		forvalues i = 2016(-1)1999{
			preserve
				local k = `i' - 1
				keep if (year == `i') | (year == `k')
				keep piden jobid year age tenure idbrnemp log* sjd entref sex colag ft sic
				
				* Keep only employees who are observed in the same job consecutively
				sort piden year
				capture drop f`i'
				quiet gen f`i' = .
				quiet by piden: replace f`i'=1 if L.jobid==jobid & year == `i' & sjd==1 

				capture drop b`k'
				quiet gen b`k' = .
				quiet by piden: replace b`k'=1 if F.jobid==jobid & year == `k' & F.sjd==1
				
				sort jobid year
				capture drop temp
				capture drop temp2
				by jobid year: egen temp 	= count(f`i')
				by jobid year: egen temp2 	= count(b`k')
				
				* Drop if the minimum number of job stayers is not fulfilled
				drop if temp<8 & year == `i'
				drop if temp2<8 & year == `k'
				
				*drop temp temp2
				
				sort jobid year
				foreach x of varlist colag sex ft sic{
					by jobid year: egen asd_`x'_`i' = mean(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = mean(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}
				foreach x of varlist age tenure idbrnemp{
					by jobid year: egen asd_`x'_`i' = median(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = median(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}		
				foreach x of varlist logwage_cpi loghours{
					by jobid year: egen asd_`x'_`i' = mean(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = mean(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				} 		
				drop f`i' b`k'
				
				capture drop tag
				egen tag = tag(jobid)
				drop if tag==0
				drop tag

				* compute the mean age and tenure for normalisation
				egen asd_age = mean(age_`i')
				egen asd_ten = mean(tenure_`i')
				sort jobid
				foreach x of varlist age_`k' age_`i'{
					by jobid: gen sq`x' = (`x'-asd_age)^2
					by jobid: gen cub`x' = (`x'-asd_age)^3
				}	
				foreach x of varlist tenure_`k' tenure_`i'{
					by jobid: gen sq`x' = (`x'-asd_ten)^2
					by jobid: gen cub`x' = (`x'-asd_ten)^3
				}				
				
				keep jobid temp2 sic age_* loghours_* colag_* sex_* ft_* sqtenure_* sqage_* cubtenure_* cubage_* idbrnemp_* logwage_cpi_* entref

				quietly reshape long age_ loghours_ colag_ sex_ ft_ sqtenure_ sqage_ cubtenure_ cubage_ idbrnemp_ logwage_cpi_ , i(jobid) j(year)
				
				rename idbrnemp_ asd
			
				g id = `i'
				
				rename asd idbrnemp_
				
				cd $reg_results_poe_criteria
				save temp`i'.dta, replace
			restore
		}

		* create empty dataset
		cd $reg_results_poe_criteria
		use temp2016.dta, clear
		forvalues i = 2015(-1)1999{
			append using temp`i'.dta
			capture erase temp`i'.dta
		}

		rename *_ *

		sort entref
		by entref: egen firm_end=max(year)
		by entref: egen firm_start=min(year)
		g firm_life=firm_end-firm_start+1
		drop entref

		* Keep only jobs which are observed for at least 50% of the years for which the firm exists
		sort jobid
		egen tag = tag(jobid year)
		replace tag=. if tag==0
		by jobid: egen rel_years = sum(tag)
		drop if (rel_years/firm_life)<0.5 & rel_years!=.
		drop rel_years tag firm*

		* temp2 is the number of job stayers in each job per year
		rename temp2 weighting

		egen temp = group(jobid id)
		drop jobid id
		rename temp jobid

		xtset, clear
		xtset jobid year

		quietly tab year, gen(d)

		g ind = 0 
		by jobid: replace ind = 1 if _n==2
		
		foreach k in logwage_cpi loghours{
			quietly areg `k' d2-d19 idbrnemp sqage sqtenure cubage cubtenure colag, absorb(jobid) vce(cluster jobid)
			preserve
				clear
				set obs 18
				gen year = _n + 1998
				gen beta = .
				gen beta_se = .
				forvalue i = 2/19{
					quietly replace beta=_b[d`i'] if year == 1997+`i'
					quietly replace beta_se=_se[d`i'] if year == 1997+`i'
				}
				
				quietly rename beta_se `k'_med_se2
				quietly rename beta `k'_med2
				cd $reg_results_poe_criteria 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_poe_criteria
		use beta_logwage_cpi, clear
		quietly merge 1:1 year using beta_loghours, nogen
		save results_2.dta, replace
			
		capture erase temp2016.dta
		capture erase beta_loghours.dta
		capture erase beta_logwage_cpi.dta

	}

	cd $other_data
	use econ, clear
	cd $reg_results_poe_criteria
	quietly merge 1:1 year using results_1, nogen
	quietly merge 1:1 year using results_2, nogen
	drop if year==1997
	
	save results_97_16_poe8.dta, replace
	capture erase results_1.dta
	capture erase results_2.dta
	
	/* Second step regression */{
	
		tsset year

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				forvalue i =1/2{
					preserve
						quietly newey `p'_med`i' `k' year, lag(1)
						clear
						set obs 1
						gen b_`k' = _b[`k']
						gen se_`k' = _se[`k']
						gen spec= `i'
						cd $reg_results_poe_criteria
						save `p'`k'`i'.dta, replace
					restore
				}
			}
		}

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				cd $reg_results_poe_criteria
				use `p'`k'1, clear
				quietly append using `p'`k'2
				erase `p'`k'2.dta
				save `p'`k'.dta, replace
				erase `p'`k'1.dta
			}
		}

		foreach p in logwage_cpi loghours{
			cd $reg_results_poe_criteria
			use `p'unemp, clear
			save `p'8.dta, replace
			erase `p'unemp.dta
		}

		
	}

}

	if $min_hires9==1{
	/* Define regression programme */{
		capture program drop reg_wages
		program define reg_wages

		* Keep only private enterprises
		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		sort jobid year
		
		*** COVARIATES
		foreach k in age idbrnemp{
			by jobid year: egen `k'_j = median(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		replace sex = 0 if sex==2
		foreach k in colag sex{
			by jobid year: egen `k'_j = mean(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		foreach p in logwage_cpi loghours{
			by jobid year: egen `p'_med = mean(`p')
			drop `p'
			}

		* Keep one obs per job and year
		egen tag = tag(jobid year)
		keep if tag==1
		drop tag

		* Compute the average age over all new hires in all years for normalisation
		egen asd_age = mean(age)
		* Create covariates
		g agesq 		= (age-asd_age)^2
		g agecub 		= (age-asd_age)^3
		g idbrnempsq 	= idbrnemp^2

		* Set panel and time series variables
		xtset, clear
		xtset jobid year

		* Year dummies
		quietly tab year, gen(d)
		
		foreach k in logwage_cpi_med loghours_med{
			preserve
				quietly areg `k' d2-d19 age agesq agecub idbrnemp idbrnempsq sex colag, absorb(jobid) vce(cluster jobid)
				matrix b = e(b)
				clear
				svmat b
				forvalue i=1/18 {
				rename b`i' c`i'
				}
				drop b*
				xpose, clear
				capture drop year
				gen year=_n + 1998
				gen se=.
				forvalue i = 2/19{
					quietly replace se=_se[d`i'] if year==1997+`i'
				}	
				quietly rename se `k'_se`1'
				quietly rename v1 `k'`1'
				cd $reg_results_poe_criteria 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_poe_criteria 
		use beta_logwage_cpi_med, clear
		quietly merge 1:1 year using beta_loghours_med, nogen
		save results_`1'.dta, replace
		
		capture erase beta_logwage_cpi_med.dta
		capture erase beta_loghours_med.dta
		
		end

		* end areg programme
	}
	/* New hires - wages and hours */{

		cd $reg_results_poe_criteria
		use slim_1997_2016_9, clear

		* define sample to be analysed
		drop if poe!=1

		* Run the regression program
		reg_wages 1
		
	}
	/* Job stayers - wages and hours */{

		cd $reg_results_poe_criteria
		use slim_1997_2016_9, clear
		* Do NOT drop year=1997, as first-diff for 1998 undefined otherwise 

		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		xtset, clear
		xtset piden year

		drop poe* w*
		drop if idbrnemp==0

		replace sex = 0 if sex==1
		replace sex = 1 if sex==2

		forvalues i = 2016(-1)1999{
			preserve
				local k = `i' - 1
				keep if (year == `i') | (year == `k')
				keep piden jobid year age tenure idbrnemp log* sjd entref sex colag ft sic
				
				* Keep only employees who are observed in the same job consecutively
				sort piden year
				capture drop f`i'
				quiet gen f`i' = .
				quiet by piden: replace f`i'=1 if L.jobid==jobid & year == `i' & sjd==1 

				capture drop b`k'
				quiet gen b`k' = .
				quiet by piden: replace b`k'=1 if F.jobid==jobid & year == `k' & F.sjd==1
				
				sort jobid year
				capture drop temp
				capture drop temp2
				by jobid year: egen temp 	= count(f`i')
				by jobid year: egen temp2 	= count(b`k')
				
				* Drop if the minimum number of job stayers is not fulfilled
				drop if temp<9 & year == `i'
				drop if temp2<9 & year == `k'
				
				*drop temp temp2
				
				sort jobid year
				foreach x of varlist colag sex ft sic{
					by jobid year: egen asd_`x'_`i' = mean(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = mean(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}
				foreach x of varlist age tenure idbrnemp{
					by jobid year: egen asd_`x'_`i' = median(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = median(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}		
				foreach x of varlist logwage_cpi loghours{
					by jobid year: egen asd_`x'_`i' = mean(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = mean(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				} 		
				drop f`i' b`k'
				
				capture drop tag
				egen tag = tag(jobid)
				drop if tag==0
				drop tag

				* compute the mean age and tenure for normalisation
				egen asd_age = mean(age_`i')
				egen asd_ten = mean(tenure_`i')
				sort jobid
				foreach x of varlist age_`k' age_`i'{
					by jobid: gen sq`x' = (`x'-asd_age)^2
					by jobid: gen cub`x' = (`x'-asd_age)^3
				}	
				foreach x of varlist tenure_`k' tenure_`i'{
					by jobid: gen sq`x' = (`x'-asd_ten)^2
					by jobid: gen cub`x' = (`x'-asd_ten)^3
				}				
				
				keep jobid temp2 sic age_* loghours_* colag_* sex_* ft_* sqtenure_* sqage_* cubtenure_* cubage_* idbrnemp_* logwage_cpi_* entref

				quietly reshape long age_ loghours_ colag_ sex_ ft_ sqtenure_ sqage_ cubtenure_ cubage_ idbrnemp_ logwage_cpi_ , i(jobid) j(year)
				
				rename idbrnemp_ asd
			
				g id = `i'
				
				rename asd idbrnemp_
				
				cd $reg_results_poe_criteria
				save temp`i'.dta, replace
			restore
		}

		* create empty dataset
		cd $reg_results_poe_criteria
		use temp2016.dta, clear
		forvalues i = 2015(-1)1999{
			append using temp`i'.dta
			capture erase temp`i'.dta
		}

		rename *_ *

		sort entref
		by entref: egen firm_end=max(year)
		by entref: egen firm_start=min(year)
		g firm_life=firm_end-firm_start+1
		drop entref

		* Keep only jobs which are observed for at least 50% of the years for which the firm exists
		sort jobid
		egen tag = tag(jobid year)
		replace tag=. if tag==0
		by jobid: egen rel_years = sum(tag)
		drop if (rel_years/firm_life)<0.5 & rel_years!=.
		drop rel_years tag firm*

		* temp2 is the number of job stayers in each job per year
		rename temp2 weighting

		egen temp = group(jobid id)
		drop jobid id
		rename temp jobid

		xtset, clear
		xtset jobid year

		quietly tab year, gen(d)

		g ind = 0 
		by jobid: replace ind = 1 if _n==2
		
		foreach k in logwage_cpi loghours{
			quietly areg `k' d2-d19 idbrnemp sqage sqtenure cubage cubtenure colag, absorb(jobid) vce(cluster jobid)
			preserve
				clear
				set obs 18
				gen year = _n + 1998
				gen beta = .
				gen beta_se = .
				forvalue i = 2/19{
					quietly replace beta=_b[d`i'] if year == 1997+`i'
					quietly replace beta_se=_se[d`i'] if year == 1997+`i'
				}
				
				quietly rename beta_se `k'_med_se2
				quietly rename beta `k'_med2
				cd $reg_results_poe_criteria 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_poe_criteria
		use beta_logwage_cpi, clear
		quietly merge 1:1 year using beta_loghours, nogen
		save results_2.dta, replace
			
		capture erase temp2016.dta
		capture erase beta_loghours.dta
		capture erase beta_logwage_cpi.dta

	}

	cd $other_data
	use econ, clear
	cd $reg_results_poe_criteria
	quietly merge 1:1 year using results_1, nogen
	quietly merge 1:1 year using results_2, nogen
	drop if year==1997
	
	save results_97_16_poe9.dta, replace
	capture erase results_1.dta
	capture erase results_2.dta
	
	/* Second step regression */{
	
		tsset year

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				forvalue i =1/2{
					preserve
						quietly newey `p'_med`i' `k' year, lag(1)
						clear
						set obs 1
						gen b_`k' = _b[`k']
						gen se_`k' = _se[`k']
						gen spec= `i'
						cd $reg_results_poe_criteria
						save `p'`k'`i'.dta, replace
					restore
				}
			}
		}

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				cd $reg_results_poe_criteria
				use `p'`k'1, clear
				quietly append using `p'`k'2
				erase `p'`k'2.dta
				save `p'`k'.dta, replace
				erase `p'`k'1.dta
			}
		}

		foreach p in logwage_cpi loghours{
			cd $reg_results_poe_criteria
			use `p'unemp, clear
			save `p'9.dta, replace
			erase `p'unemp.dta
		}

		
	}

}

	if $min_hires10==1{
	/* Define regression programme */{
		capture program drop reg_wages
		program define reg_wages

		* Keep only private enterprises
		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		sort jobid year
		
		*** COVARIATES
		foreach k in age idbrnemp{
			by jobid year: egen `k'_j = median(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		replace sex = 0 if sex==2
		foreach k in colag sex{
			by jobid year: egen `k'_j = mean(`k')
			quietly replace `k' = `k'_j
			drop `k'_j
			}

		foreach p in logwage_cpi loghours{
			by jobid year: egen `p'_med = mean(`p')
			drop `p'
			}

		* Keep one obs per job and year
		egen tag = tag(jobid year)
		keep if tag==1
		drop tag

		* Compute the average age over all new hires in all years for normalisation
		egen asd_age = mean(age)
		* Create covariates
		g agesq 		= (age-asd_age)^2
		g agecub 		= (age-asd_age)^3
		g idbrnempsq 	= idbrnemp^2

		* Set panel and time series variables
		xtset, clear
		xtset jobid year

		* Year dummies
		quietly tab year, gen(d)
		
		foreach k in logwage_cpi_med loghours_med{
			preserve
				quietly areg `k' d2-d19 age agesq agecub idbrnemp idbrnempsq sex colag, absorb(jobid) vce(cluster jobid)
				matrix b = e(b)
				clear
				svmat b
				forvalue i=1/18 {
				rename b`i' c`i'
				}
				drop b*
				xpose, clear
				capture drop year
				gen year=_n + 1998
				gen se=.
				forvalue i = 2/19{
					quietly replace se=_se[d`i'] if year==1997+`i'
				}	
				quietly rename se `k'_se`1'
				quietly rename v1 `k'`1'
				cd $reg_results_poe_criteria 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_poe_criteria 
		use beta_logwage_cpi_med, clear
		quietly merge 1:1 year using beta_loghours_med, nogen
		save results_`1'.dta, replace
		
		capture erase beta_logwage_cpi_med.dta
		capture erase beta_loghours_med.dta
		
		end

		* end areg programme
	}
	/* New hires - wages and hours */{

		cd $reg_results_poe_criteria
		use slim_1997_2016_10, clear

		* define sample to be analysed
		drop if poe!=1

		* Run the regression program
		reg_wages 1
		
	}
	/* Job stayers - wages and hours */{

		cd $reg_results_poe_criteria
		use slim_1997_2016_10, clear
		* Do NOT drop year=1997, as first-diff for 1998 undefined otherwise 

		keep if idbrsta==1 | idbrsta==2 | idbrsta==3

		xtset, clear
		xtset piden year

		drop poe* w*
		drop if idbrnemp==0

		replace sex = 0 if sex==1
		replace sex = 1 if sex==2

		forvalues i = 2016(-1)1999{
			preserve
				local k = `i' - 1
				keep if (year == `i') | (year == `k')
				keep piden jobid year age tenure idbrnemp log* sjd entref sex colag ft sic
				
				* Keep only employees who are observed in the same job consecutively
				sort piden year
				capture drop f`i'
				quiet gen f`i' = .
				quiet by piden: replace f`i'=1 if L.jobid==jobid & year == `i' & sjd==1 

				capture drop b`k'
				quiet gen b`k' = .
				quiet by piden: replace b`k'=1 if F.jobid==jobid & year == `k' & F.sjd==1
				
				sort jobid year
				capture drop temp
				capture drop temp2
				by jobid year: egen temp 	= count(f`i')
				by jobid year: egen temp2 	= count(b`k')
				
				* Drop if the minimum number of job stayers is not fulfilled
				drop if temp<10 & year == `i'
				drop if temp2<10 & year == `k'
				
				*drop temp temp2
				
				sort jobid year
				foreach x of varlist colag sex ft sic{
					by jobid year: egen asd_`x'_`i' = mean(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = mean(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}
				foreach x of varlist age tenure idbrnemp{
					by jobid year: egen asd_`x'_`i' = median(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = median(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				}		
				foreach x of varlist logwage_cpi loghours{
					by jobid year: egen asd_`x'_`i' = mean(`x') if f`i'==1
					by jobid year: egen asd_`x'_`k' = mean(`x') if b`k'==1
					by jobid: egen `x'_`i' = mean(asd_`x'_`i')
					by jobid: egen `x'_`k' = mean(asd_`x'_`k')
					drop asd_`x'_`i' asd_`x'_`k'
				} 		
				drop f`i' b`k'
				
				capture drop tag
				egen tag = tag(jobid)
				drop if tag==0
				drop tag

				* compute the mean age and tenure for normalisation
				egen asd_age = mean(age_`i')
				egen asd_ten = mean(tenure_`i')
				sort jobid
				foreach x of varlist age_`k' age_`i'{
					by jobid: gen sq`x' = (`x'-asd_age)^2
					by jobid: gen cub`x' = (`x'-asd_age)^3
				}	
				foreach x of varlist tenure_`k' tenure_`i'{
					by jobid: gen sq`x' = (`x'-asd_ten)^2
					by jobid: gen cub`x' = (`x'-asd_ten)^3
				}				
				
				keep jobid temp2 sic age_* loghours_* colag_* sex_* ft_* sqtenure_* sqage_* cubtenure_* cubage_* idbrnemp_* logwage_cpi_* entref

				quietly reshape long age_ loghours_ colag_ sex_ ft_ sqtenure_ sqage_ cubtenure_ cubage_ idbrnemp_ logwage_cpi_ , i(jobid) j(year)
				
				rename idbrnemp_ asd
			
				g id = `i'
				
				rename asd idbrnemp_
				
				cd $reg_results_poe_criteria
				save temp`i'.dta, replace
			restore
		}

		* create empty dataset
		cd $reg_results_poe_criteria
		use temp2016.dta, clear
		forvalues i = 2015(-1)1999{
			append using temp`i'.dta
			capture erase temp`i'.dta
		}

		rename *_ *

		sort entref
		by entref: egen firm_end=max(year)
		by entref: egen firm_start=min(year)
		g firm_life=firm_end-firm_start+1
		drop entref

		* Keep only jobs which are observed for at least 50% of the years for which the firm exists
		sort jobid
		egen tag = tag(jobid year)
		replace tag=. if tag==0
		by jobid: egen rel_years = sum(tag)
		drop if (rel_years/firm_life)<0.5 & rel_years!=.
		drop rel_years tag firm*

		* temp2 is the number of job stayers in each job per year
		rename temp2 weighting

		egen temp = group(jobid id)
		drop jobid id
		rename temp jobid

		xtset, clear
		xtset jobid year

		quietly tab year, gen(d)

		g ind = 0 
		by jobid: replace ind = 1 if _n==2
		
		foreach k in logwage_cpi loghours{
			quietly areg `k' d2-d19 idbrnemp sqage sqtenure cubage cubtenure colag, absorb(jobid) vce(cluster jobid)
			preserve
				clear
				set obs 18
				gen year = _n + 1998
				gen beta = .
				gen beta_se = .
				forvalue i = 2/19{
					quietly replace beta=_b[d`i'] if year == 1997+`i'
					quietly replace beta_se=_se[d`i'] if year == 1997+`i'
				}
				
				quietly rename beta_se `k'_med_se2
				quietly rename beta `k'_med2
				cd $reg_results_poe_criteria 
				save beta_`k'.dta, replace
			restore
		}

		cd $reg_results_poe_criteria
		use beta_logwage_cpi, clear
		quietly merge 1:1 year using beta_loghours, nogen
		save results_2.dta, replace
			
		capture erase temp2016.dta
		capture erase beta_loghours.dta
		capture erase beta_logwage_cpi.dta

	}

	cd $other_data
	use econ, clear
	cd $reg_results_poe_criteria
	quietly merge 1:1 year using results_1, nogen
	quietly merge 1:1 year using results_2, nogen
	drop if year==1997
	
	save results_97_16_poe10.dta, replace
	capture erase results_1.dta
	capture erase results_2.dta
	
	/* Second step regression */{
	
		tsset year

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				forvalue i =1/2{
					preserve
						quietly newey `p'_med`i' `k' year, lag(1)
						clear
						set obs 1
						gen b_`k' = _b[`k']
						gen se_`k' = _se[`k']
						gen spec= `i'
						cd $reg_results_poe_criteria
						save `p'`k'`i'.dta, replace
					restore
				}
			}
		}

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				cd $reg_results_poe_criteria
				use `p'`k'1, clear
				quietly append using `p'`k'2
				erase `p'`k'2.dta
				save `p'`k'.dta, replace
				erase `p'`k'1.dta
			}
		}

		foreach p in logwage_cpi loghours{
			cd $reg_results_poe_criteria
			use `p'unemp, clear
			save `p'10.dta, replace
			erase `p'unemp.dta
		}

		
	}

}

}

/* TABLE 5 */{

	* Set globals, i.e. which results are generated
	global trend2			= 1 // quadratic trend
	global first_diff		= 1 // first differences
	global wls_2nd_stage	= 1 // WLS in second stage (weighted by jobs per year)

	if $trend2==1{
	/* Second step regression */{
	
		cd $reg_resultsdir_97_16
		use results_97_16, clear
		tsset year
		
		g year2 = year^2

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				forvalue i =1/2{
					preserve
						quietly newey `p'_med`i' `k' year year2, lag(1)
						clear
						set obs 1
						gen b_`k' = _b[`k']
						gen se_`k' = _se[`k']
						gen spec= `i'
						cd $reg_results_2nd_stage
						save `p'`k'`i'.dta, replace
					restore
				}
			}
		}

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				cd $reg_results_2nd_stage
				use `p'`k'1, clear
				quietly append using `p'`k'2
				erase `p'`k'2.dta
				save `p'`k'.dta, replace
				erase `p'`k'1.dta
			}
		}

		foreach p in logwage_cpi loghours{
			cd $reg_results_2nd_stage
			use `p'unemp, clear
			save `p'_quad.dta, replace
			erase `p'unemp.dta
		}

		
	}

}
	
	if $first_diff==1{
	/* Second step regression */{
	
		cd $reg_resultsdir_97_16
		use results_97_16, clear
		tsset year

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				forvalue i =1/2{
					preserve
						quietly newey D.`p'_med`i' D.unemp, lag(1)
						clear
						set obs 1
						gen b_`k' = _b[D.`k']
						gen se_`k' = _se[D.`k']
						gen spec= `i'
						cd $reg_first_diff
						save `p'`k'`i'.dta, replace
					restore
				}
			}
		}

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				cd $reg_first_diff
				use `p'`k'1, clear
				quietly append using `p'`k'2
				erase `p'`k'2.dta
				save `p'`k'.dta, replace
				erase `p'`k'1.dta
			}
		}

		foreach p in logwage_cpi loghours{
			cd $reg_first_diff
			use `p'unemp, clear
			save `p'.dta, replace
			erase `p'unemp.dta
		}

		
	}

}

	if $wls_2nd_stage==1{
	/* Second step regression */{
	
		cd $reg_resultsdir_97_16
		use results_97_16, clear
		tsset year
		
		* Merge in weights - number of poe jobs per year
		cd $created_datadir
		quietly merge 1:1 year using poe_year_weights.dta, nogen
		quietly merge 1:1 year using stayer_year_weights.dta, nogen

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				forvalue i =1/1{
					preserve
						quietly reg `p'_med`i' `k' year [aweight=weight]
						clear
						set obs 1
						gen b_`k' = _b[`k']
						gen se_`k' = _se[`k']
						gen spec= `i'
						cd $reg_results_wls
						save `p'`k'`i'.dta, replace
					restore
				}
			}
		}
		
		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				forvalue i =2/2{
					preserve
						quietly reg `p'_med`i' `k' year [aweight=stayer_weights]
						clear
						set obs 1
						gen b_`k' = _b[`k']
						gen se_`k' = _se[`k']
						gen spec= `i'
						cd $reg_results_wls
						save `p'`k'`i'.dta, replace
					restore
				}
			}
		}

		foreach p in logwage_cpi loghours{
			foreach k in unemp{
				cd $reg_results_wls
				use `p'`k'1, clear
				quietly append using `p'`k'2
				erase `p'`k'2.dta
				save `p'`k'.dta, replace
				erase `p'`k'1.dta
			}
		}

		foreach p in logwage_cpi loghours{
			cd $reg_results_wls
			use `p'unemp, clear
			save `p'.dta, replace
			erase `p'unemp.dta
		}

		
	}

}

}

}

*** CREATE TABLES ***
if $tables==1{

***************
*** TABLE 1 ***
***************
{

	cd $created_datadir
	use idbrsta poe entref year jobid piden using slim_1997_2016.dta, clear
	
	* Keep only private enterprises
	keep if idbrsta==1 | idbrsta==2 | idbrsta==3
	
	egen tag_firm 	= tag(entref year)
	egen tag_job 	= tag(jobid year) if poe==1
	replace tag_firm=. if tag_firm==0
	replace tag_job=. if tag_job==0
	
	cd $other_data
	quiet merge m:1 year using econ, nogen keepusing(unemp)
	replace unemp = unemp*100
	
	drop if year<=1997
	ren (poe tag_job tag_firm) (new_hires entry_level_jobs firms)
	table year, c(count new_hires count entry_level_jobs count firms mean unemp) format(%9.2f) row
	
	*** The number of unique observations is computed below
	
	* Unique firms, unique firm==1
	egen unique_firms = tag(entref)
	tab unique_firms if unique_firms==1
	
	* Unique jobs, unique job==1
	egen unique_jobs = tag(jobid new_hires)
	tab unique_jobs if unique_jobs==1
	
	* Unique employees, unique employee==1
	egen unique_workers = tag(piden new_hires)
	tab unique_workers if unique_workers==1

}

***************
*** TABLE 2 ***
***************
{
	
*** Note: this table requires that the regressions for job-stayers have been run previously *** 
	
***************************
*** Stats for new hires ***
***************************
{
	cd $created_datadir
	use slim_1997_2016, clear
	drop if poe!=1
	keep if idbrsta==1 | idbrsta==2 | idbrsta==3

	replace sex = 0 if sex==1
	replace sex = 1 if sex==2

	g wage 		= exp(logwage_cpi)
	g earnings 	= exp(logearnings_cpi)
	g hours 	= exp(loghours)

	cd $table_dir
	preserve
		quiet table year, c(m age m sex m ft med idbrnemp) row format(%9.2f) replace
		rename (table1 table2 table3 table4) (age sex ft idbrnemp)
		replace year = 0 if year == .
		save hires_1.dta, replace
	restore

	preserve
		quiet table year, c(med wage med earnings med hours m hours) row format(%9.2f) replace
		rename (table1 table2 table3 table4) (wage earnings hours mhours)
		replace year = 0 if year == .
		save hires_2.dta, replace
	restore

}

*****************************
*** Stats for job stayers ***
*****************************
{
	cd $reg_resultsdir_97_16
	use stayer_data_baseline.dta, clear

	sort entref
	by entref: egen firm_end=max(year)
	by entref: egen firm_start=min(year)
	gen firm_life=firm_end-firm_start+1
	drop entref

	sort jobid
	egen tag = tag(jobid year)
	replace tag=. if tag==0
	by jobid: egen rel_years = sum(tag)
	drop if (rel_years/firm_life)<0.5 & rel_years!=.
	drop rel_years tag firm*

	g marker=1 if id==year
	drop if marker==.
	drop marker

	g wage 		= exp(logwage_cpi)
	g hours 	= exp(loghours)

	cd $table_dir
	preserve
		quiet table year, c(m age m sex m ft med idbrnemp) row format(%9.2f) replace
		rename (table1 table2 table3 table4) (age_s sex_s ft_s idbrnemp_s)
		replace year = 0 if year == .
		save stayers_1.dta, replace
	restore

	preserve	
		quiet table year, c(med wage med hours m hours) row format(%9.2f) replace
		rename (table1 table2 table3) (wage_s hours_s mhours_s)
		replace year = 0 if year == .
		save stayers_2.dta, replace
	restore

}

*****************************
*** Stats for ASHE stayer ***
*****************************
{
	
	cd $created_datadir
	use slim_1997_2016_all, clear
	keep if sjd==1
	keep if idbrsta==1 | idbrsta==2 | idbrsta==3

	replace sex = 0 if sex==1
	replace sex = 1 if sex==2

	g wage 		= exp(logwage_cpi)
	g hours 	= exp(loghours)

	cd $table_dir
	preserve
		quiet table year, c(m age m sex m ft med idbrnemp) row format(%9.2f) replace
		rename (table1 table2 table3 table4) (age_a sex_a ft_a idbrnemp_a)
		replace year = 0 if year == .
		save ashe_1.dta, replace
	restore

	preserve
		quiet table year, c(med wage med hours m hours) row format(%9.2f) replace
		rename (table1 table2 table3) (wage_a hours_a mhours_a)
		replace year = 0 if year == .
		save ashe_2.dta, replace
	restore

}

********************************
*** Stats for ASHE new hires ***
********************************
{
	
	cd $created_datadir
	use slim_1997_2016_all, clear
	drop if entry!=1
	keep if idbrsta==1 | idbrsta==2 | idbrsta==3

	replace sex = 0 if sex==1
	replace sex = 1 if sex==2

	g wage 		= exp(logwage_cpi)
	g earnings 	= exp(logearnings_cpi)
	g hours 	= exp(loghours)

	cd $table_dir
	preserve
		quiet table year, c(m age m sex m ft med idbrnemp) row format(%9.2f) replace
		rename (table1 table2 table3 table4) (age_an sex_an ft_an idbrnemp_an)
		replace year = 0 if year == .
		save ashe_hires_1.dta, replace
	restore

	preserve
		quiet table year, c(med wage med hours m hours) row format(%9.2f) replace
		rename (table1 table2 table3) (wage_an hours_an mhours_an)
		replace year = 0 if year == .
		save ashe_hires_2.dta, replace
	restore
	
}
	
}

***************
*** TABLE 3 ***
***************
{
	
	* BASELINE & ALL JOBS WITH 2 OBS
	cd $reg_results_2nd_stage
	use logwage_cpi, clear
	g var1 = .
	g var2 = .
	g var3 = .
	replace var1 = 1
	replace var2 = 1 if (spec==1 | spec==3)
	replace var2 = 2 if (spec==2 | spec==4)
	replace var3 = 1 if (spec==1 | spec==2)
	replace var3 = 4 if (spec==3 | spec==4)
	append using loghours
	replace var1 = 2 if var1==.
	replace var2 = 1 if var2==. & (spec==1 | spec==3)
	replace var2 = 2 if var2==. & (spec==2 | spec==4)
	replace var3 = 1 if var3==. & (spec==1 | spec==2)
	replace var3 = 4 if var3==. & (spec==3 | spec==4)
	
	* NO CONTROLS
	cd $reg_results_ft
	append using logwage_cpi
	replace var1 = 1 if var1==.
	replace var2 = 1 if var2==. & spec==1
	replace var2 = 2 if var2==. & spec==2
	replace var3 = 2 if var3==.
	append using loghours
	replace var1 = 2 if var1==.
	replace var2 = 1 if var2==. & spec==1
	replace var2 = 2 if var2==. & spec==2
	replace var3 = 2 if var3==.
	
	* 25% HIRING
	cd $reg_results_poe_criteria
	append using logwage_cpi2
	replace var1 = 1 if var1==.
	replace var2 = 1 if var2==. & spec==1
	replace var2 = 2 if var2==. & spec==2
	replace var3 = 3 if var3==.
	append using loghours2
	replace var1 = 2 if var1==.
	replace var2 = 1 if var2==. & spec==1
	replace var2 = 2 if var2==. & spec==2
	replace var3 = 3 if var3==.
	
	* MAX HIRING
	cd $reg_results_poe_criteria
	append using logwage_cpimax
	replace var1 = 1 if var1==.
	replace var2 = 1 if var2==. & spec==1
	replace var2 = 2 if var2==. & spec==2
	replace var3 = 4 if var3==.
	append using loghoursmax
	replace var1 = 2 if var1==.
	replace var2 = 1 if var2==. & spec==1
	replace var2 = 2 if var2==. & spec==2
	replace var3 = 4 if var3==.
	
	* WLS IN FIRST STAGE (EMPLOYEES)
	cd $reg_results_wls
	append using logwage_cpi
	replace var1 = 1 if var1==.
	replace var2 = 1 if var2==. & spec==1
	replace var2 = 2 if var2==. & spec==2
	replace var3 = 5 if var3==.
	append using loghours
	replace var1 = 2 if var1==.
	replace var2 = 1 if var2==. & spec==1
	replace var2 = 2 if var2==. & spec==2
	replace var3 = 5 if var3==.
	
	* INCLUDING OTHER PAY
	cd $reg_results_overtime
	append using logpayrate_cpi
	replace var1 = 1 if var1==.
	replace var2 = 1 if var2==. & spec==1
	replace var2 = 2 if var2==. & spec==2
	replace var3 = 6 if var3==.
	append using logthrs
	replace var1 = 2 if var1==.
	replace var2 = 1 if var2==. & spec==1
	replace var2 = 2 if var2==. & spec==2
	replace var3 = 6 if var3==.
	
	* 3D OCCUPATIONS
	cd $reg_results_3d
	append using logwage_cpi_3d
	replace var1 = 1 if var1==.
	replace var2 = 1 if var2==. & spec==1
	replace var2 = 2 if var2==. & spec==2
	replace var3 = 7 if var3==.
	append using loghours_3d
	replace var1 = 2 if var1==.
	replace var2 = 1 if var2==. & spec==1
	replace var2 = 2 if var2==. & spec==2
	replace var3 = 7 if var3==.
	
	keep var* b_unemp se_unemp
	label define var3label 1 "Baseline" 2 "FT controls" 3 "25percent" 4 "2obs" 5 "WLS" 6 "other pay" 7 "3d"
	label define var2label 1 "New Hire" 2 "Job Stayer"
	label define var1label 1 "Wages" 2 "Hours"
	
	label values var3 var3label
	label values var2 var2label
	label values var1 var1label
	
	table var3 var2 var1, c(mean b_unemp mean se_unemp) format(%9.2f)
	
}	

***************
*** TABLE 5 ***
***************
{
	
	* BASELINE
	cd $reg_results_2nd_stage
	use logwage_cpi, clear
	g var1 = .
	g var2 = .
	g var3 = .
	replace var1 = 1
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	replace var3 = 1
	append using loghours
	replace var1 = 2 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	replace var3 = 1
	drop if spec>2
	
	* QUADRATIC TREND
	cd $reg_results_2nd_stage
	append using logwage_cpi_quad
	replace var1 = 1 if var1==.
	replace var2 = 1 if var2==. & spec==1
	replace var2 = 2 if var2==. & spec==2
	replace var3 = 2 if var3==.
	append using loghours_quad
	replace var1 = 2 if var1==.
	replace var2 = 1 if var2==. & spec==1
	replace var2 = 2 if var2==. & spec==2
	replace var3 = 2 if var3==.
	
	* FIRST DIFFERENCES
	cd $reg_first_diff
	append using logwage_cpi
	replace var1 = 1 if var1==.
	replace var2 = 1 if var2==. & spec==1
	replace var2 = 2 if var2==. & spec==2
	replace var3 = 3 if var3==.
	append using loghours
	replace var1 = 2 if var1==.
	replace var2 = 1 if var2==. & spec==1
	replace var2 = 2 if var2==. & spec==2
	replace var3 = 3 if var3==.
	
	* WLS IN 2ND STAGE
	cd $reg_results_wls
	append using logwage_cpi
	replace var1 = 1 if var1==.
	replace var2 = 1 if var2==. & spec==1
	replace var2 = 2 if var2==. & spec==2
	replace var3 = 4 if var3==.
	append using loghours
	replace var1 = 2 if var1==.
	replace var2 = 1 if var2==. & spec==1
	replace var2 = 2 if var2==. & spec==2
	replace var3 = 4 if var3==.
	
	
	keep var* b_unemp se_unemp
	
	label define var1label 1 "Wages" 2 "Hours"
	label define var2label 1 "New Hire" 2 "Job Stayer"
	label define var3label 1 "Baseline" 2 "Quad trend" 3 "FD" 4 "WLS jobs"
	
	label values var3 var3label
	label values var2 var2label
	label values var1 var1label
	
	table var3 var2 var1, c(mean b_unemp mean se_unemp) format(%9.2f)
	
}	

***************
*** TABLE 6 ***
***************
{

	* BASELINE
	cd $reg_results_2nd_stage
	use logwage_cpi, clear
	g var1 = .
	g var2 = .
	g var3 = .
	replace var1 = 1
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	append using loghours
	replace var1 = 2 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	replace var3 = 1
	
	append using logwage_cpi
	replace var1 = 1 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	append using loghours
	replace var1 = 2 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	replace var3 = 2 if var3==.
	drop if spec>2
	
	g b_gamma 		= b_log_prod_gdp if var3==1
	replace b_gamma	= b_log_prod_ser if var3==2
	g se_gamma 		= se_log_prod_gdp if var3==1
	replace se_gamma= se_log_prod_ser if var3==2
	keep var* b_gamma se_gamma
	
	label define var3label 1 "GDP" 2 "Services"
	label define var2label 1 "New Hire" 2 "Job Stayer"
	label define var1label 1 "Wages" 2 "Hours"
	
	label values var3 var3label
	label values var2 var2label
	label values var1 var1label
	
	table var3 var2 var1, c(mean b_gamma mean se_gamma) format(%9.2f)

}

****************
*** TABLE B1 ***
****************
{

	* BASELINE
	cd $reg_results_2nd_stage
	use logwage_cpi, clear
	g var1 = .
	g var2 = .
	g var3 = .
	replace var1 = 1
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	replace var3 = 1
	append using loghours
	replace var1 = 2 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	replace var3 = 1
	drop if spec>2
	
	* MEANS
	cd $reg_results_mean
	append using logwage_cpi
	replace var1 = 1 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	append using loghours
	replace var1 = 2 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	replace var3 = 2 if var3==.
	
	* 25p
	cd $reg_results_p25
	append using logwage_cpi
	replace var1 = 1 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	append using loghours
	replace var1 = 2 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	replace var3 = 3 if var3==.
	
	* 75p
	cd $reg_results_p75
	append using logwage_cpi
	replace var1 = 1 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	append using loghours
	replace var1 = 2 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	replace var3 = 4 if var3==.
	
	* NO CONTROLS
	cd $reg_results_no_controls
	append using logwage_cpi
	replace var1 = 1 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	append using loghours
	replace var1 = 2 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	replace var3 = 5 if var3==.
	
	* PUBLIC SECTOR
	cd $reg_results_public_dir
	append using logwage_cpi
	replace var1 = 1 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	append using loghours
	replace var1 = 2 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	replace var3 = 6 if var3==.
	
	* RPI
	cd $reg_results_deflators
	append using logwage_rpi
	replace var1 = 1 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	replace var3 = 7 if var3==.
	
	keep var* b_unemp se_unemp
	
	label define var1label 1 "Wages" 2 "Hours"
	label define var2label 1 "New Hire" 2 "Job Stayer"
	label define var3label 1 "Baseline" 2 "Means" 3 "25p" 4 "75p" 5 "No controls" 6 "Public sec" 7 "RPI"
	
	label values var3 var3label
	label values var2 var2label
	label values var1 var1label
	
	table var3 var2 var1, c(mean b_unemp mean se_unemp) format(%9.2f)

}

****************
*** TABLE B2 ***
****************
{

	* BASELINE (3)
	cd $reg_results_2nd_stage
	use logwage_cpi, clear
	g var1 = .
	g var2 = .
	g var3 = .
	replace var1 = 1 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	append using loghours
	replace var1 = 2 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	replace var3 = 2
	drop if spec>2
	
	* EMPLOYEES 2
	cd $reg_results_poe_criteria
	append using logwage_cpi3
	replace var1 = 1 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	append using loghours3
	replace var1 = 2 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	replace var3 = 1 if var3==.
	
	* EMPLOYEES 4
	cd $reg_results_poe_criteria
	append using logwage_cpi4
	replace var1 = 1 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	append using loghours4
	replace var1 = 2 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	replace var3 = 3 if var3==.
	
	* EMPLOYEES 5
	cd $reg_results_poe_criteria
	append using logwage_cpi5
	replace var1 = 1 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	append using loghours5
	replace var1 = 2 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	replace var3 = 4 if var3==.
	
	* EMPLOYEES 6
	cd $reg_results_poe_criteria
	append using logwage_cpi6
	replace var1 = 1 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	append using loghours6
	replace var1 = 2 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	replace var3 = 5 if var3==.
	
	* EMPLOYEES 7
	cd $reg_results_poe_criteria
	append using logwage_cpi7
	replace var1 = 1 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	append using loghours7
	replace var1 = 2 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	replace var3 = 6 if var3==.
	
	* EMPLOYEES 8
	cd $reg_results_poe_criteria
	append using logwage_cpi8
	replace var1 = 1 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	append using loghours8
	replace var1 = 2 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	replace var3 = 7 if var3==.
	
	* EMPLOYEES 9
	cd $reg_results_poe_criteria
	append using logwage_cpi9
	replace var1 = 1 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	append using loghours9
	replace var1 = 2 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	replace var3 = 8 if var3==.
	
	* EMPLOYEES 10
	cd $reg_results_poe_criteria
	append using logwage_cpi10
	replace var1 = 1 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	append using loghours10
	replace var1 = 2 if var1==.
	replace var2 = 1 if spec==1
	replace var2 = 2 if spec==2
	replace var3 = 9 if var3==.
	
	keep var* b_unemp se_unemp
	
	label define var1label 1 "Wages" 2 "Hours"
	label define var2label 1 "New Hire" 2 "Job Stayer"
	label define var3label 1 "2 Workers" 2 "Baseline (3)" 3 "4" 4 "5" 5 "6" 6 "7" 7 "8" 8 "9" 9 "10"
	
	label values var3 var3label
	label values var2 var2label
	label values var1 var1label
	
	table var3 var2 var1, c(mean b_unemp mean se_unemp) format(%9.2f)

}

****************
*** TABLE B3 ***
****************
{
	***********************************
	*** ROW 1 & 8 & 9 & 11 & 12 ***
	***********************************
	{
	cd $reg_resultsdir_97_16
	use results_97_16, clear
	tsset year
	g year2 = year^2
	
	* ROW 1
	preserve
		g diff = logwage_cpi_med1 - logwage_cpi_med2
		quietly newey diff unemp year, lag(1)
		clear
		set obs 1
		g b_unemp 	= _b[unemp]
		g se_unemp 	= _se[unemp]
		g var1 		= 1
		g var2		= 1
		cd $codedir
		save temp.dta, replace
	restore
	preserve
		g diff = loghours_med1 - loghours_med2
		quietly newey diff unemp year, lag(1)
		clear
		set obs 1
		g b_unemp 	= _b[unemp]
		g se_unemp 	= _se[unemp]
		g var1 		= 2
		g var2		= 1
		cd $codedir
		append using temp
		save row1.dta, replace
		erase temp.dta
	restore
	
	* ROW 8
	preserve
		g diff = logwage_cpi_med1 - logwage_cpi_med2
		quietly newey diff unemp year year2, lag(1)
		clear
		set obs 1
		g b_unemp 	= _b[unemp]
		g se_unemp 	= _se[unemp]
		g var1 		= 1
		g var2		= 8
		cd $codedir
		save temp.dta, replace
	restore
	preserve
		g diff = loghours_med1 - loghours_med2
		quietly newey diff unemp year year2, lag(1)
		clear
		set obs 1
		g b_unemp 	= _b[unemp]
		g se_unemp 	= _se[unemp]
		g var1 		= 2
		g var2		= 8
		cd $codedir
		append using temp
		save row8.dta, replace
		erase temp.dta
	restore
	
	* ROW 9
	preserve
		g diff = D.logwage_cpi_med1 - D.logwage_cpi_med2
		quietly newey diff D.unemp, lag(1)
		clear
		set obs 1
		g b_unemp 	= _b[D1.unemp]
		g se_unemp 	= _se[D1.unemp]
		g var1 		= 1
		g var2		= 9
		cd $codedir
		save temp.dta, replace
	restore
	preserve
		g diff = D.loghours_med1 - D.loghours_med2
		quietly newey diff D.unemp, lag(1)
		clear
		set obs 1
		g b_unemp 	= _b[D1.unemp]
		g se_unemp 	= _se[D1.unemp]
		g var1 		= 2
		g var2		= 9
		cd $codedir
		append using temp
		save row9.dta, replace
		erase temp.dta
	restore
	
	* ROW 11
	preserve
		g diff = logwage_cpi_med1 - logwage_cpi_med2
		quietly newey diff log_prod_gdp year, lag(1)
		clear
		set obs 1
		g b_unemp 	= _b[log_prod_gdp]
		g se_unemp 	= _se[log_prod_gdp]
		g var1 		= 1
		g var2		= 11
		cd $codedir
		save temp.dta, replace
	restore
	preserve
		g diff = loghours_med1 - loghours_med2
		quietly newey diff log_prod_gdp year, lag(1)
		clear
		set obs 1
		g b_unemp 	= _b[log_prod_gdp]
		g se_unemp 	= _se[log_prod_gdp]
		g var1 		= 2
		g var2		= 11
		cd $codedir
		append using temp
		save row11.dta, replace
		erase temp.dta
	restore
	
	* ROW 12
	preserve
		g diff = logwage_cpi_med1 - logwage_cpi_med2
		quietly newey diff log_prod_ser year, lag(1)
		clear
		set obs 1
		g b_unemp 	= _b[log_prod_ser]
		g se_unemp 	= _se[log_prod_ser]
		g var1 		= 1
		g var2		= 12
		cd $codedir
		save temp.dta, replace
	restore
	preserve
		g diff = loghours_med1 - loghours_med2
		quietly newey diff log_prod_ser year, lag(1)
		clear
		set obs 1
		g b_unemp 	= _b[log_prod_ser]
		g se_unemp 	= _se[log_prod_ser]
		g var1 		= 2
		g var2		= 12
		cd $codedir
		append using temp
		save row12.dta, replace
		erase temp.dta
	restore
	}
	
	*************
	*** ROW 2 ***
	*************
	{
	cd $reg_results_ft
	use results_97_16, clear
	tsset year	
	
	preserve
		g diff = logwage_cpi_med1 - logwage_cpi_med2
		quietly newey diff unemp year, lag(1)
		clear
		set obs 1
		g b_unemp 	= _b[unemp]
		g se_unemp 	= _se[unemp]
		g var1 		= 1
		g var2		= 2
		cd $codedir
		save temp.dta, replace
	restore
	preserve
		g diff = loghours_med1 - loghours_med2
		quietly newey diff unemp year, lag(1)
		clear
		set obs 1
		g b_unemp 	= _b[unemp]
		g se_unemp 	= _se[unemp]
		g var1 		= 2
		g var2		= 2
		cd $codedir
		append using temp
		save row2.dta, replace
		erase temp.dta
	restore	
	}
	
	*************
	*** ROW 3 ***
	*************
	{
	cd $reg_results_poe_criteria
	use results_97_16_2, clear
	tsset year
	
	preserve
		g diff = logwage_cpi_med1 - logwage_cpi_med2
		quietly newey diff unemp year, lag(1)
		clear
		set obs 1
		g b_unemp 	= _b[unemp]
		g se_unemp 	= _se[unemp]
		g var1 		= 1
		g var2		= 3
		cd $codedir
		save temp.dta, replace
	restore
	preserve
		g diff = loghours_med1 - loghours_med2
		quietly newey diff unemp year, lag(1)
		clear
		set obs 1
		g b_unemp 	= _b[unemp]
		g se_unemp 	= _se[unemp]
		g var1 		= 2
		g var2		= 3
		cd $codedir
		append using temp
		save row3.dta, replace
		erase temp.dta
	restore
	}

	*************
	*** ROW 4 ***
	*************
	{
	cd $reg_results_poe_criteria
	use results_97_16_2, clear
	tsset year
	
	* ROW 4
	preserve
		g diff = logwage_cpi_med1 - logwage_cpi_med2
		quietly newey diff unemp year, lag(1)
		clear
		set obs 1
		g b_unemp 	= _b[unemp]
		g se_unemp 	= _se[unemp]
		g var1 		= 1
		g var2		= 4
		cd $codedir
		save temp.dta, replace
	restore
	preserve
		g diff = loghours_med1 - loghours_med2
		quietly newey diff unemp year, lag(1)
		clear
		set obs 1
		g b_unemp 	= _b[unemp]
		g se_unemp 	= _se[unemp]
		g var1 		= 2
		g var2		= 4
		cd $codedir
		append using temp
		save row4.dta, replace
		erase temp.dta
	restore
	}
	
	*************
	*** ROW 5 ***
	*************
	{
	cd $reg_results_wls
	use results_97_16, clear
	tsset year
	
	preserve
		g diff = logwage_cpi_med1 - logwage_cpi_med2
		quietly newey diff unemp year, lag(1)
		clear
		set obs 1
		g b_unemp 	= _b[unemp]
		g se_unemp 	= _se[unemp]
		g var1 		= 1
		g var2		= 5
		cd $codedir
		save temp.dta, replace
	restore
	preserve
		g diff = loghours_med1 - loghours_med2
		quietly newey diff unemp year, lag(1)
		clear
		set obs 1
		g b_unemp 	= _b[unemp]
		g se_unemp 	= _se[unemp]
		g var1 		= 2
		g var2		= 5
		cd $codedir
		append using temp
		save row5.dta, replace
		erase temp.dta
	restore
	}

	*************
	*** ROW 6 ***
	*************
	{
	cd $reg_results_overtime
	use results_97_16, clear
	tsset year	
	
	preserve
		g diff = logpayrate_cpi_med1 - logpayrate_cpi_med2
		quietly newey diff unemp year, lag(1)
		clear
		set obs 1
		g b_unemp 	= _b[unemp]
		g se_unemp 	= _se[unemp]
		g var1 		= 1
		g var2		= 6
		cd $codedir
		save temp.dta, replace
	restore
	preserve
		g diff = logthrs_med1 - logthrs_med2
		quietly newey diff unemp year, lag(1)
		clear
		set obs 1
		g b_unemp 	= _b[unemp]
		g se_unemp 	= _se[unemp]
		g var1 		= 2
		g var2		= 6
		cd $codedir
		append using temp
		save row6.dta, replace
		erase temp.dta
	restore
	}
	
	*************
	*** ROW 7 ***
	*************
	{
	cd $reg_results_3d
	use results_97_16, clear
	tsset year
	
	preserve
		g diff = logwage_cpi_med1 - logwage_cpi_med2
		quietly newey diff unemp year, lag(1)
		clear
		set obs 1
		g b_unemp 	= _b[unemp]
		g se_unemp 	= _se[unemp]
		g var1 		= 1
		g var2		= 7
		cd $codedir
		save temp.dta, replace
	restore
	preserve
		g diff = loghours_med1 - loghours_med2
		quietly newey diff unemp year, lag(1)
		clear
		set obs 1
		g b_unemp 	= _b[unemp]
		g se_unemp 	= _se[unemp]
		g var1 		= 2
		g var2		= 7
		cd $codedir
		append using temp
		save row7.dta, replace
		erase temp.dta
	restore
	}

	**************
	*** ROW 10 ***
	**************
	{
	cd $reg_results_wls
	use results_97_16, clear
	
	cd $created_datadir
	quietly merge 1:1 year using poe_year_weights.dta, nogen
	
	tsset year
	
	preserve
		g diff = logwage_cpi_med1 - logwage_cpi_med2
		quietly reg diff unemp year [aweight=weight]
		clear
		set obs 1
		g b_unemp 	= _b[unemp]
		g se_unemp 	= _se[unemp]
		g var1 		= 1
		g var2		= 10
		cd $codedir
		save temp.dta, replace
	restore
	preserve
		g diff = loghours_med1 - loghours_med2
		quietly reg diff unemp year [aweight=weight]
		clear
		set obs 1
		g b_unemp 	= _b[unemp]
		g se_unemp 	= _se[unemp]
		g var1 		= 2
		g var2		= 10
		cd $codedir
		append using temp
		save row10.dta, replace
		erase temp.dta
	restore
	}

	cd $codedir
	use row1, clear
	forvalue i = 2/12{
		append using row`i'
		erase row`i'.dta
	}

	label define var1label 1 "Wages" 2 "Hours"
	label values var1 var1label
	
	label define var2label 1 "Baseline" 2 "FT controls" 3 "25%" 4 "2 obs" 5 "WLS 1st stage" 6 "Other pay" 7 "3d occ" 8 "Quad trend" 9 "FD" 10 "WLS 2nd stage" 11 "Prod 1" 12 "Prod 2"
	label values var2 var2label
	
	table var2 var1, c(mean b_unemp mean se_unemp) format(%9.2f)
	
	}

****************
*** TABLE C1 ***
****************
{

	cd $created_datadir
	use slim_1997_2016, clear
	drop if poe!=1
	keep if idbrsta==1 | idbrsta==2 | idbrsta==3

	g dig2 		= floor(sic/1000)
	g dig1 		= floor(sic/10000)

	sort year
	by year: egen obs = count(piden)
	
	g var1 = 1
	
	preserve
		forvalue i=50/93{
			egen obs`i' = count(piden) if dig2==`i'
		}

		rename (obs52 obs55 obs65 obs74) (Retail HotelRest Finance CleaningRecruitment)

		quiet table var1, c(m Retail m HotelRest m Finance m CleaningRecruitment) format(%9.0f) replace
		rename (table1 table2 table3 table4) (retail hotel fin cleaning)
		
		cd $table_dir
		save table_C1_counts.dta, replace
	restore

	preserve
		forvalue i=50/93{
			by year: egen obs`i' = count(piden) if dig2==`i'
			gen share`i' = obs`i'/obs
			by year: egen max`i'=max(share`i')
			replace share`i' = max`i'
			drop obs`i' max`i'
		}

		rename (share52 share55 share65 share74) (Retail HotelRest Finance CleaningRecruitment)

		quiet table year, c(m Retail m HotelRest m Finance m CleaningRecruitment) row format(%9.2f)	replace
		rename (table1 table2 table3 table4) (retail hotel fin cleaning)
		keep if year==.
		drop year
		
		cd $table_dir
		save table_C1_shares.dta, replace
	restore

}

****************
*** TABLE C2 ***
****************
{

	cd $created_datadir
	use slim_1997_2016, clear
	drop if poe!=1
	keep if idbrsta==1 | idbrsta==2 | idbrsta==3

	g dig2 		= floor(isco88_4d/100)
	g dig1 		= floor(isco88_4d/1000)

	sort year
	by year: egen obs = count(piden)

	g var1 = 1
	
	preserve
		forvalue i=40/93{
			egen obs`i' = count(piden) if dig2==`i'
		}

		quiet table var1, c(m obs42 m obs51 m obs52 m obs91 m obs93) format(%9.0f) replace
		rename (table1 table2 table3 table4 table5) (Cashier HotelRest SalesPers Cleaners Other)
		
		cd $table_dir
		save table_C2_counts.dta, replace
	restore

	preserve
		forvalue i=40/93{
			by year: egen obs`i' = count(piden) if dig2==`i'
			gen share`i' = obs`i'/obs
			by year: egen max`i'=max(share`i')
			replace share`i' = max`i'
			drop obs`i' max`i'
		}

		quiet table year, c(m share42 m share51 m share52 m share91 m share93) row format(%9.2f) replace
		rename (table1 table2 table3 table4 table5) (Cashier HotelRest SalesPers Cleaners Other)
		keep if year==.
		drop year
		
		cd $table_dir
		save table_C2_shares.dta, replace
	restore

}

****************
*** TABLE C3 ***
****************
{
	cd $reg_resultsdir_97_16
	use results_97_16, clear
	keep year logwage*
	
	*** HOURLY WAGES ***
	forvalue i = 1/2{
		quiet reg logwage_cpi_med`i' year
		predict temp`i', residuals
		replace logwage_cpi_med`i' = temp`i' - temp`i'[6]
		drop temp`i'
	}
	
	preserve
		keep year logwage_cpi_med1 logwage_cpi_med_se1
		g var1 = 1
		g var2 = 1
		ren (logwage_cpi_med1 logwage_cpi_med_se1) (wage se)
		cd $codedir
		save temp1, replace
	restore
		
	preserve
		keep year logwage_cpi_med2 logwage_cpi_med_se2
		g var1 = 2
		g var2 = 1
		ren (logwage_cpi_med2 logwage_cpi_med_se2) (wage se)
		cd $codedir
		save temp2, replace
	restore
	
	cd $reg_results_poe_criteria
	use results_97_16_max, clear
	keep year logwage*
	
	*** HOURLY WAGES ***
	forvalue i = 1/2{
		quiet reg logwage_cpi_med`i' year
		predict temp`i', residuals
		replace logwage_cpi_med`i' = temp`i' - temp`i'[6]
		drop temp`i'
	}
	
	preserve
		keep year logwage_cpi_med1 logwage_cpi_med_se1
		g var1 = 1
		g var2 = 2
		ren (logwage_cpi_med1 logwage_cpi_med_se1) (wage se)
		cd $codedir
		save temp3, replace
	restore
		
	preserve
		keep year logwage_cpi_med2 logwage_cpi_med_se2
		g var1 = 2
		g var2 = 2
		ren (logwage_cpi_med2 logwage_cpi_med_se2) (wage se)
		cd $codedir
		save temp4, replace
	restore
	
	cd $codedir
	use temp1, clear
	append using temp2
	append using temp3
	append using temp4
	drop if year==1998
	
	label define var1label 1 "New Hire" 2 "Job Stayer"
	label define var2label 1 "Baseline" 2 "ASHE"
	label values var1 var1label
	label values var2 var2label
	
	table year var1 var2, c(m wage m se) format(%9.3f)
	
	erase temp1.dta
	erase temp2.dta
	erase temp3.dta
	erase temp4.dta

}

****************
*** TABLE C4 ***
****************
{
	cd $reg_resultsdir_97_16
	use results_97_16, clear
	keep year loghours*
	
	*** HOURLS ***
	forvalue i = 1/1{
		g temp`i' = loghours_med`i'
		replace loghours_med`i' = temp`i' - temp`i'[6]
		drop temp`i'
	}
	
	forvalue i = 2/2{
		quiet reg loghours_med`i' year
		predict temp`i', residuals
		replace loghours_med`i' = temp`i' - temp`i'[6]
		drop temp`i'
	}
	
	preserve
		keep year loghours_med1 loghours_med_se1
		g var1 = 1
		g var2 = 1
		ren (loghours_med1 loghours_med_se1) (hours se)
		cd $codedir
		save temp1, replace
	restore
		
	preserve
		keep year loghours_med2 loghours_med_se2
		g var1 = 2
		g var2 = 1
		ren (loghours_med2 loghours_med_se2) (hours se)
		cd $codedir
		save temp2, replace
	restore
	
	cd $reg_results_poe_criteria
	use results_97_16_max, clear
	keep year loghours*
	
	*** HOURLS ***
	forvalue i = 1/1{
		g temp`i' = loghours_med`i'
		replace loghours_med`i' = temp`i' - temp`i'[6]
		drop temp`i'
	}
	
	forvalue i = 2/2{
		quiet reg loghours_med`i' year
		predict temp`i', residuals
		replace loghours_med`i' = temp`i' - temp`i'[6]
		drop temp`i'
	}
	
	preserve
		keep year loghours_med1 loghours_med_se1
		g var1 = 1
		g var2 = 2
		ren (loghours_med1 loghours_med_se1) (hours se)
		cd $codedir
		save temp3, replace
	restore
		
	preserve
		keep year loghours_med2 loghours_med_se2
		g var1 = 2
		g var2 = 2
		ren (loghours_med2 loghours_med_se2) (hours se)
		cd $codedir
		save temp4, replace
	restore
	
	cd $codedir
	use temp1, clear
	append using temp2
	append using temp3
	append using temp4
	drop if year==1998
	
	label define var1label 1 "New Hire" 2 "Job Stayer"
	label define var2label 1 "Baseline" 2 "ASHE"
	label values var1 var1label
	label values var2 var2label
	
	table year var1 var2, c(m hours m se) format(%9.3f)
	
	erase temp1.dta
	erase temp2.dta
	erase temp3.dta
	erase temp4.dta

}

****************
*** TABLE C6 ***
****************
{

	cd $tenure_dir
	use table_C6_wages.dta, clear
	quiet append using table_C6_hours
		
	table start tenure type, c(mean b mean se)

}

************************
*** TABLE C7, C8, C9 ***
************************
{
	
	cd $tenure_dir
	use figure2_data.dta, clear
	
	xtset, clear
	egen matchid = group(jobid piden)
	xtset matchid year
	
	* CLEAN UP THE DATASET
	drop ts sts
	
	egen id = group(entref)
	replace entref = id
	drop id
	
	* Normalise tenure variable
	drop tenure
	rename temp tenure
	
	g hours = exp(loghours)
	
	* CREATE INDICATOR OF STATUS CHANGE AND HOURS CHANGES
	g ft_pt 	  = 0
	g pt_ft 	  = 0
	g dhours	  = .
	g pt_ft_hours = .
	g ft_pt_hours = .
	g ft_ft_hours = .
	g pt_pt_hours = .
	bysort matchid (year): replace pt_ft  = 1 if ft==1 & l.ft==0 & tenure>0
	bysort matchid (year): replace ft_pt  = 1 if ft==0 & l.ft==1 & tenure>0
	bysort matchid (year): replace dhours = hours - l.hours
	bysort matchid (year): replace pt_ft_hours = hours - l.hours if pt_ft==1
	bysort matchid (year): replace ft_pt_hours = hours - l.hours if ft_pt==1
	bysort matchid (year): replace ft_ft_hours = hours - l.hours if ft==1 & l.ft==1 & tenure>0
	bysort matchid (year): replace pt_pt_hours = hours - l.hours if ft==0 & l.ft==0 & tenure>0
	
	*** GROSS TRANSITON RATES FT-PT ***
	
	* TABLE C7
	preserve
		drop if tenure==0 | tenure>3
		drop if cohort<=2001 | cohort>=2014
		quiet table cohort tenure, c(mean pt_ft mean pt_ft_hours mean ft_pt mean ft_pt_hours) replace
		ren (table1 table2 table3 table4) (pt_ft pt_ft_hours ft_pt ft_pt_hours)
		replace pt_ft = pt_ft*100
		replace ft_pt = ft_pt*100
		format pt_ft %4.2f
		format ft_pt %4.2f
		format pt_ft_hours %4.2f
		format ft_pt_hours %4.2f
		
		list
	restore
	
	* TABLE C8 and C9
	preserve
		drop if tenure==0 | tenure>3
		keep if cohort<=2007
		quiet table tenure, c(mean pt_ft mean pt_ft_hours mean ft_pt mean ft_pt_hours mean dhours) replace
		ren (table1 table2 table3 table4 table5) (pt_ft pt_ft_hours ft_pt ft_pt_hours dhours)
		g cohort = 2008
		cd $tenure_dir
		save temp1.dta, replace
	restore
	preserve
		drop if tenure==0 | tenure>3
		keep if cohort>=2008
		quiet table tenure, c(mean pt_ft mean pt_ft_hours mean ft_pt mean ft_pt_hours mean dhours) replace
		ren (table1 table2 table3 table4 table5) (pt_ft pt_ft_hours ft_pt ft_pt_hours dhours)
		g cohort = 2009
		
		cd $tenure_dir
		append using temp1
		erase temp1.dta
		sort cohort tenure
		
		g gamma = 100 * ((pt_ft/100) * pt_ft_hours + (ft_pt/100) * ft_pt_hours)/dhours
		
		replace pt_ft = pt_ft*100
		replace ft_pt = ft_pt*100
		format pt_ft %4.2f
		format ft_pt %4.2f
		format pt_ft_hours %4.2f
		format ft_pt_hours %4.2f
		format dhours %4.2f
		format gamma %4.2f
		
		label define varlabel 2008 "2002-07" 2009 "2008-13"
		label values cohort varlabel
		
		list
	restore
	
	* TABLE C7-C9 CELL COUNTS
// 	preserve
// 		drop if tenure==0 | tenure>3
// 		drop if cohort<=2001 | cohort>=2014
// 		quiet table cohort tenure, c(count pt_ft_hours count ft_pt_hours) replace
// 		ren (table1 table2) ( pt_ft_hours  ft_pt_hours)
// 		format pt_ft_hours %4.2f
// 		format ft_pt_hours %4.2f
//		
// 		list
// 	restore
	
}

****************
*** TABLE E1 ***
****************
{

	cd $created_datadir
	use slim_1997_2016.dta, clear
	keep if idbrsta==1 | idbrsta==2 | idbrsta==3
	drop poe* start now firm_start entry idbrsta w* gp* colag ft

	xtset, clear
	xtset piden year

	capture drop logw
	gen logw = ln(hexo)

	sort piden year
	capture drop dlogw
	gen dlogw = .
	by piden: replace dlogw = logw - L.logw if sjd==1 & jobid==L.jobid
	label var dlogw "Log nominal wage (per hour) change"

	cd $other_data
	sort piden year
	quietly merge m:1 year using CPI.dta, nogen

	sort piden year
	gen dlnCPI = ln(cpi) - ln(L.cpi)

		g dlogw_obs  		= dlogw~=. 							if dlogw~=.
		g dlogw_zero 		= dlogw==0 							if dlogw~=.
		g dlogw_cut  		= dlogw<0  							if dlogw~=.
		g dlogw_zeroplus	= dlogw>0      & dlogw<=0.01 		if dlogw~=.
		g dlogw_zerominus	= dlogw>=-0.01 & dlogw<0 			if dlogw~=.
		g dlogw_realcut_cpi = dlogw<dlnCPI	 			 		if dlogw~=.
		
		sort year
		by year: egen obs  			= sum(dlogw_obs)
		by year: egen zero 			= sum(dlogw_zero)
		by year: egen cut  			= sum(dlogw_cut)
		by year: egen zeroplus 		= sum(dlogw_zeroplus)
		by year: egen zerominus		= sum(dlogw_zerominus)
		by year: egen realcut_cpi	= sum(dlogw_realcut_cpi)

		g spike 				= zero/obs 	*100		if dlogw==0
		g plus 					= zeroplus/obs *100
		g minus 				= zerominus/obs *100
		g cut_fraction 			= cut/obs *100
		g realcut_fraction_cpi 	= realcut_cpi/obs *100
		
		* Table 6
		format spike %4.1f
		format plus %4.1f
		format minus %4.1f
		format cut_fraction %4.1f
		format realcut_fraction_cpi %4.1f
		format dlnCPI %4.1f
		
		drop if year==1997
		
		preserve
			table year, c(mean minus mean spike mean plus mean cut_fraction mean realcut_fraction_cpi)
		restore

}


}

*** CREATE TABLES ***
if $figures==1{

	*** Generate Figures - requires that the regressions have been run previously ***

****************
*** FIGURE 1 ***
****************
{
	*****************
	*** 1998-2016 ***
	*****************
	cd $reg_resultsdir_97_16
	use results_97_16, clear
	tsset year
	cd $figure_dir
	
	*** HOURLY WAGES ***
	forvalue i = 1/2{
		capture drop upper`i'
		capture drop lower`i'
		
		quiet reg logwage_cpi_med`i' year
		predict temp`i', residuals
		replace logwage_cpi_med`i' = temp`i' - temp`i'[6]
		
		g upper`i' = logwage_cpi_med`i' + 1.96*logwage_cpi_med_se`i'
		g lower`i' = logwage_cpi_med`i' - 1.96*logwage_cpi_med_se`i'
	}		
	
	twoway 	(tsline logwage_cpi_med1, 	lp(solid) 		lc(gs5) lw(*1.0)) ///
			(tsline upper1, 			lp(shortdash) 	lc(gs5) lw(*0.8)) ///
			(tsline lower1, 			lp(shortdash) 	lc(gs5) lw(*0.8)) ///
			(tsline logwage_cpi_med2, 	lp(longdash) 	lc(gs5) lw(*1.0)), ///
			title("Median hourly wages") xtitle("Year") ytitle("Log change relative to 2003") ///
			legend(order(1 4) label(1 "New hires") label(4 "Job stayers in sample firms")) ///
			ylabel(-0.15(0.05)0.1, format(%9.2fc) nogrid angle(0)) ymlabel(,nolabels) ysc(titlegap(*2.5) r(-0.15 0.1)) ///
			xsc(titlegap(*1.5) r(1998 2016)) xlabel(1998(2)2016) ///
			ttext(.095 1998.5 "95% confidence interval, new hires",placement(e)) ///
			tline(2008.5, 	lwidth(vvthick) 	lcolor(gs14)) ///
			tline(2009, 	lwidth(vvvthick) 	lcolor(gs14)) ///
			tline(2009.5, 	lwidth(vvthick) 	lcolor(gs14)) ///
			graphregion(fcolor(white)) name(fig_1A_wages, replace)
	graph export "fig_1A_wages.png", as(png) name(fig_1A_wages) replace width(2800) height(2000)
	graph close
		
	*** HOURS WORKED ***
	forvalue i = 1/1{
		capture drop upper`i'
		capture drop lower`i'
		capture drop temp`i'
		
		g temp`i' = loghours_med`i'
		replace loghours_med`i' = temp`i' - temp`i'[6]
		
		gen upper`i' = loghours_med`i' + 1.96*loghours_med_se`i'
		gen lower`i' = loghours_med`i' - 1.96*loghours_med_se`i'
	}
	
	forvalue i = 2/2{
		capture drop upper`i'
		capture drop lower`i'
		capture drop temp`i'
		
		quiet reg loghours_med`i' year
		predict temp`i', residuals
		replace loghours_med`i' = temp`i' - temp`i'[6]
		
		gen upper`i' = loghours_med`i' + 1.96*loghours_med_se`i'
		gen lower`i' = loghours_med`i' - 1.96*loghours_med_se`i'
	}	
	
	twoway 	(tsline loghours_med1, 	lp(solid) 		lc(gs5) lw(*1.0)) ///
			(tsline upper1, 		lp(shortdash) 	lc(gs5) lw(*0.8)) ///
			(tsline lower1, 		lp(shortdash) 	lc(gs5) lw(*0.8)) ///
			(tsline loghours_med2, 	lp(longdash)	lc(gs5) lw(*1.0)), ///
			title("Median hours worked") xtitle("Year") ytitle("Log change relative to 2003") ///
			legend(order(1 4) label(1 "New hires") label(4 "Job stayers in sample firms")) ///
			ylabel(-0.20(0.10)0.20, format(%9.2fc) nogrid angle(0)) ymlabel(,nolabels) ysc(titlegap(*2.5) r(-0.20 0.20)) ///
			xsc(titlegap(*1.5) r(1998 2016)) xlabel(1998(2)2016) ///
			ttext(-.15 2000.3 "95% confidence interval, new hires",placement(e)) ///
			tline(2008.5, lwidth(vvthick) lcolor(gs14)) ///
			tline(2009, lwidth(vvvthick) lcolor(gs14)) ///
			tline(2009.5, lwidth(vvthick) lcolor(gs14)) ///
			graphregion(fcolor(white)) name(fig_1B_hours, replace)
	graph export "fig_1B_hours.png", as(png) name(fig_1B_hours) replace width(2800) height(2000)
	graph close

}

****************
*** FIGURE 2 ***
****************
{

	cd $tenure_dir
	use figure2_data, clear
	
	replace logwage_cpi = exp(logwage_cpi)
	replace loghours 	= exp(loghours)
	
	collapse (mean) logwage_cpi loghours (median) logwage_cpi_med=logwage_cpi loghours_med=loghours, by(cohort temp)
	g year = cohort+temp
	
	drop temp
	reshape wide logwage_cpi loghours logwage_cpi_med loghours_med, i(year) j(cohort)
	tsset year
	* Create hiring series
	foreach j in logwage_cpi loghours logwage_cpi_med loghours_med{
		gen hiring_`j'=.
		forvalues i = 1998/2016{
			replace hiring_`j'=`j'`i' if year==`i'
		}
	}

	cd $figure_dir
	twoway  (tsline hiring_logwage_cpi, lp(solid) 	lc(black) lw(*1.5)) ///
			(tsline logwage_cpi1998, lp(solid) 		lc(gs5)   lw(*0.8)) ///
			(tsline logwage_cpi1999, lp(shortdash) 	lc(gs5)   lw(*1.0)) ///
			(tsline logwage_cpi2000, lp(longdash) 	lc(gs5)   lw(*1.0)) ///
			(tsline logwage_cpi2001, lp(solid) 		lc(gs5)   lw(*0.8)) ///
			(tsline logwage_cpi2002, lp(shortdash) 	lc(gs5)   lw(*1.0)) ///
			(tsline logwage_cpi2003, lp(longdash) 	lc(gs5)   lw(*1.0)) ///
			(tsline logwage_cpi2004, lp(solid) 		lc(gs5)   lw(*0.8)) ///
			(tsline logwage_cpi2005, lp(shortdash) 	lc(gs5)   lw(*1.0)) ///
			(tsline logwage_cpi2006, lp(longdash) 	lc(gs5)   lw(*1.0)) ///
			(tsline logwage_cpi2007, lp(solid) 		lc(gs5)   lw(*0.8)) ///
			(tsline logwage_cpi2008, lp(shortdash) 	lc(gs5)   lw(*1.0)) ///
			(tsline logwage_cpi2009, lp(longdash) 	lc(gs5)   lw(*1.0)) ///
			(tsline logwage_cpi2010, lp(solid) 		lc(gs5)   lw(*0.8)) ///
			(tsline logwage_cpi2011, lp(shortdash) 	lc(gs5)   lw(*1.0)) ///
			(tsline logwage_cpi2012, lp(longdash) 	lc(gs5)   lw(*1.0)) ///
			(tsline logwage_cpi2013, lp(solid) 		lc(gs5)   lw(*0.8)) ///
			(tsline logwage_cpi2014, lp(shortdash) 	lc(gs5)   lw(*1.0)) ///
			(tsline logwage_cpi2015, lp(longdash) 	lc(gs5)   lw(*1.0)) ///
			(tsline logwage_cpi2016, lp(solid) 		lc(gs5)   lw(*0.8)) ///
			(pcarrowi 7.7 2013 6.7 2013.8 "Mean wage 2014, cohort 2009" , color(black) mlabc(black) mlabs(3.5) mlabp(12) barbsize(1.5) mangle(30)), ///
			title("Mean hourly wages") xtitle("Year") ytitle("Average hourly wage ({c L-} 1998)") ///
			legend(off) ///
			ylabel(5(1)10, format(%9.0fc) nogrid angle(0)) ymlabel(,nolabels) ysc(titlegap(*2.5) r(5 10)) ///
			xsc(titlegap(*1.5) r(1998 2016)) xlabel(1998(2)2016) ///
			ttext(5.6 2000.5 "Mean hiring wage of cohorts", placement(e)) ///
			tline(2008.5, lwidth(vvthick) lcolor(gs14)) ///
			tline(2009, lwidth(vvvthick) lcolor(gs14)) ///
			tline(2009.5, lwidth(vvthick) lcolor(gs14)) ///
			graphregion(fcolor(white)) name(fig_2A_wages, replace) 
	graph export "fig_2A_wages.png", as(png) name(fig_2A_wages) replace width(2800) height(2000)
	graph close
	
	twoway  (tsline hiring_loghours,  	lp(solid) 		lc(black) lw(*1.5)) ///
			(tsline loghours1998, 		lp(solid) 		lc(gs5)   lw(*0.8)) ///
			(tsline loghours1999, 		lp(shortdash) 	lc(gs5)   lw(*1.0)) ///
			(tsline loghours2000, 		lp(longdash) 	lc(gs5)   lw(*1.0)) ///
			(tsline loghours2001, 		lp(solid) 		lc(gs5)   lw(*0.8)) ///
			(tsline loghours2002, 		lp(shortdash) 	lc(gs5)   lw(*1.0)) ///
			(tsline loghours2003, 		lp(longdash) 	lc(gs5)   lw(*1.0)) ///
			(tsline loghours2004, 		lp(solid) 		lc(gs5)   lw(*0.8)) ///
			(tsline loghours2005, 		lp(shortdash) 	lc(gs5)   lw(*1.0)) ///
			(tsline loghours2006, 		lp(longdash) 	lc(gs5)   lw(*1.0)) ///
			(tsline loghours2007, 		lp(solid) 		lc(gs5)   lw(*0.8)) ///
			(tsline loghours2008, 		lp(shortdash) 	lc(gs5)   lw(*1.0)) ///
			(tsline loghours2009, 		lp(longdash) 	lc(gs5)   lw(*1.0)) ///
			(tsline loghours2010, 		lp(solid) 		lc(gs5)   lw(*0.8)) ///
			(tsline loghours2011, 		lp(shortdash) 	lc(gs5)   lw(*1.0)) ///
			(tsline loghours2012, 		lp(longdash) 	lc(gs5)   lw(*1.0)) ///
			(tsline loghours2013, 		lp(solid) 		lc(gs5)   lw(*0.8)) ///
			(tsline loghours2014,		lp(shortdash) 	lc(gs5)   lw(*1.0)) ///
			(tsline loghours2015, 		lp(longdash) 	lc(gs5)   lw(*1.0)) ///
			(tsline loghours2016, 		lp(solid) 		lc(gs5)   lw(*0.8)) ///
			(pcarrowi 32 2006.7 32 2007.7 "Mean hours worked 2008, cohort 2003" , color(black) mlabc(black) mlabs(3.5) mlabp(9) barbsize(1.5) mangle(30)), ///
			title("Mean hours worked") xtitle("Year") ytitle("Average hours worked") ///
			legend(off) ///
			ylabel(21(2)31, format(%9.0fc) nogrid angle(0)) ymlabel(,nolabels) ysc(titlegap(*2.5) r(21 32)) ///
			xsc(titlegap(*1.5) r(1998 2016)) xlabel(1998(2)2016) ///
			ttext(24.2 1998.2 "Mean hiring hours of cohorts", placement(e)) ///
			tline(2008.5, lwidth(vvthick) lcolor(gs14)) ///
			tline(2009, lwidth(vvvthick) lcolor(gs14)) ///
			tline(2009.5, lwidth(vvthick) lcolor(gs14)) ///
			graphregion(fcolor(white)) name(fig_2B_hours, replace) 
	graph export "fig_2B_hours.png", as(png) name(fig_2B_hours) replace width(2800) height(2000)
	graph close

}

****************
*** FIGURE 3 ***
****************
{

	cd $tenure_dir
	use poe_tenure_wage.dta, clear
	tsset tenure
	drop if tenure==0
	drop se*

	quietly reshape long b, i(tenure) j(start)

	sort start tenure
	g id = _n + start + start - 4000
	drop if start <= 2004

	cd $figure_dir
	twoway 	(bar b id if (id>=23 & id<=25), barw(0.75) fc(gs12) lw(0) lc(b) ) ///
			(bar b id if (id>=28 & id<=30), barw(0.75) fc(gs12) lw(0) lc(b) ) ///
			(bar b id if (id>=33 & id<=35), barw(0.75) fc(gs12) lw(0) lc(b) ) ///
			(bar b id if (id>=38 & id<=40), barw(0.75) fc(gs12) lw(0) lc(b) ) ///
			(bar b id if (id>=43 & id<=45), barw(0.75) fc(gs12) lw(0) lc(b) ) ///
			(bar b id if (id>=48 & id<=50), barw(0.75) fc(gs12) lw(0) lc(b) ) ///
			(bar b id if (id>=53 & id<=55), barw(0.75) fc(gs12) lw(0) lc(b) ) ///
			(bar b id if (id>=58 & id<=60), barw(0.75) fc(gs12) lw(0) lc(b) ) ///
			(bar b id if (id>=63 & id<=65), barw(0.75) fc(gs12) lw(0) lc(b) ) /// 
			(pcarrowi .076 42 .050 38.5 "Ln wage change after one year" 	, color(black) mlabc(black) mlabs(3.5) mlabp(3) barbsize(1.5) mangle(30)) ///
			(pcarrowi .064 42 .046 39.5 "... two years"				, color(black) mlabc(black) mlabs(3.5) mlabp(3) barbsize(1.5) mangle(30)) ///		
			(pcarrowi .053 42 .042 40.5 "... three years" 			, color(black) mlabc(black) mlabs(3.5) mlabp(3) barbsize(1.5) mangle(30)), ///
			title("New hire wages and employee tenure") legend(off) ///
			ytitle("Log change relative to hiring wage") ylabel(-0.00(0.04)0.16, format(%9.2fc) angle(0)) ymlabel(,nolabels) ysc(titlegap(*2.5) r(-0.00 0.16)) ///
			xtitle("Cohort") xlabel(24 "2005" 29 "2006" 34 "2007" 39 "2008" 44 "2009" 49 "2010" 54 "2011" 59 "2012" 64 "2013", noticks) xmlabel(,nolabels) xsc(titlegap(*2.5) r(23 65)) ///
			graphregion(fcolor(white)) name(fig_3A_wages, replace)
		graph export "fig_3A_wages.png", as(png) name(fig_3A_wages) replace width(2800) height(2000)
		graph close

		
	cd $tenure_dir
	use poe_tenure_hours.dta, clear
	tsset tenure
	drop if tenure==0
	drop se*

	quietly reshape long b, i(tenure) j(start)

	sort start tenure
	g id = _n + start + start - 4000
	drop if start <= 2004

	cd $figure_dir
	twoway 	(bar b id if (id>=23 & id<=25), barw(0.75) fc(gs12) lw(0) lc(b) ) ///
			(bar b id if (id>=28 & id<=30), barw(0.75) fc(gs12) lw(0) lc(b) ) ///
			(bar b id if (id>=33 & id<=35), barw(0.75) fc(gs12) lw(0) lc(b) ) ///
			(bar b id if (id>=38 & id<=40), barw(0.75) fc(gs12) lw(0) lc(b) ) ///
			(bar b id if (id>=43 & id<=45), barw(0.75) fc(gs12) lw(0) lc(b) ) ///
			(bar b id if (id>=48 & id<=50), barw(0.75) fc(gs12) lw(0) lc(b) ) ///
			(bar b id if (id>=53 & id<=55), barw(0.75) fc(gs12) lw(0) lc(b) ) ///
			(bar b id if (id>=58 & id<=60), barw(0.75) fc(gs12) lw(0) lc(b) ) ///
			(bar b id if (id>=63 & id<=65), barw(0.75) fc(gs12) lw(0) lc(b) ) /// 
			(pcarrowi .040 40 .016 42.5 "... one year" 							, color(black) mlabc(black) mlabs(3.5) mlabp(10) barbsize(1.5) mangle(30)) ///
			(pcarrowi .058 40 .038 43.5 "... two years"							, color(black) mlabc(black) mlabs(3.5) mlabp(10) barbsize(1.5) mangle(30)) ///		
			(pcarrowi .074 40 .049 44.5 "Ln hours change after three years" 	, color(black) mlabc(black) mlabs(3.5) mlabp(10) barbsize(1.5) mangle(30)), ///
			title("New hire wages and employee tenure") legend(off) ///
			ytitle("Log change relative to hiring hours") ylabel(-0.00(0.05)0.20, format(%9.2fc) angle(0)) ymlabel(,nolabels) ysc(titlegap(*2.5) r(-0.00 0.20)) ///
			xtitle("Cohort") xlabel(24 "2005" 29 "2006" 34 "2007" 39 "2008" 44 "2009" 49 "2010" 54 "2011" 59 "2012" 64 "2013", noticks) xmlabel(,nolabels) xsc(titlegap(*2.5) r(23 65)) ///
			graphregion(fcolor(white)) name(fig_3B_hours, replace)
		graph export "fig_3B_hours.png", as(png) name(fig_3B_hours) replace width(2800) height(2000)
		graph close

}

*****************
*** FIGURE D1 ***
*****************
{

	cd $table_dir
	use ashe_1, clear
	qui merge 1:1 year using ashe_2, nogen
	qui merge 1:1 year using ashe_hires_1, nogen
	qui merge 1:1 year using ashe_hires_2, nogen
	qui merge 1:1 year using hires_1, nogen
	qui merge 1:1 year using hires_2, nogen
	qui merge 1:1 year using stayers_1, nogen
	qui merge 1:1 year using stayers_2, nogen
	
	* Age
	preserve
		keep age* year
		drop if year == 0
		tsset year
		drop if year==1997
		
		cd $figure_dir
		twoway 	(tsline age, 	lp(shortdash) 	lc(gs5) recast(connected) msymbol(i) mc(gs5)) ///
				(tsline age_s, 	lp(solid) 		lc(gs5) recast(connected) msymbol(i) mc(gs5)) ///
				(tsline age_an, lp("_...") 		lc(gs5) recast(connected) msymbol(i) mc(gs5)) ///
				(tsline age_a, 	lp(longdash) 	lc(gs5) recast(connected) msymbol(i) mc(gs5)), ///
				title("Average age of employees") xtitle("Year") ytitle("Average age of employees") ysc(r(25 45)) ///
				legend(label(1 "Hires in sample jobs") label(2 "Job stayers in sample firms") label(3 "All hires") label(4 "All job stayers")) ///
				ysc(titlegap(*2.5)) ylabel(25(5)45, format(%9.0fc) angle(0) nogrid) ymlabel(,nolabels) xsc(r(1998 2016)) xlabel(1998(2)2016) name(fig_D1A_age, replace) ///
				tline(2008.5, lwidth(vvthick) lcolor(gs14)) ///
				tline(2009, lwidth(vvvthick) lcolor(gs14)) ///
				tline(2009.5, lwidth(vvthick) lcolor(gs14)) /// 
				graphregion(fcolor(white))
		graph export "fig_D1A_age.png", as(png) name(fig_D1A_age) replace width(2800) height(2000)
		graph close	
	restore

	* Sex
	preserve
		keep sex* year
		drop if year == 0
		tsset year
		drop if year==1997

		cd $figure_dir
		twoway 	(tsline sex, 	lp(shortdash) 	lc(gs5) recast(connected) msymbol(i) mc(gs5)) ///
				(tsline sex_s, 	lp(solid) 		lc(gs5) recast(connected) msymbol(i) mc(gs5)) ///
				(tsline sex_an, lp("_...")		lc(gs5) recast(connected) msymbol(i) mc(gs5)) ///
				(tsline sex_a, 	lp(longdash) 	lc(gs5) recast(connected) msymbol(i) mc(gs5)), ///
				title("Share of female workers") xtitle("Year") ytitle("Share of female employees") ysc(r(0.35 0.65)) ///
				legend(label(1 "Hires in sample jobs") label(2 "Job stayers in sample firms") label(3 "All hires") label(4 "All job stayers")) ///
				ysc(titlegap(*2.5)) ylabel(0.35(.1)0.65, format(%9.2fc) angle(0) nogrid) ymlabel(,nolabels) xsc(r(1998 2016)) xlabel(1998(2)2016) name(fig_D1C_sex, replace) ///
				tline(2008.5, lwidth(vvthick) lcolor(gs14)) ///
				tline(2009, lwidth(vvvthick) lcolor(gs14)) ///
				tline(2009.5, lwidth(vvthick) lcolor(gs14)) /// 
				graphregion(fcolor(white))
		graph export "fig_D1C_sex.png", as(png) name(fig_D1C_sex) replace width(2800) height(2000)
		graph close	
	restore

	* FT/PT
	preserve
		keep ft* year
		drop if year == 0
		tsset year
		drop if year==1997
		
		cd $figure_dir
		twoway 	(tsline ft, 	lp(shortdash) 	lc(gs5) recast(connected) msymbol(i) mc(gs5)) ///
				(tsline ft_s, 	lp(solid) 		lc(gs5) recast(connected) msymbol(i) mc(gs5)) ///
				(tsline ft_an, 	lp("_...")		lc(gs5) recast(connected) msymbol(i) mc(gs5)) ///
				(tsline ft_a, 	lp(longdash) 	lc(gs5) recast(connected) msymbol(i) mc(gs5)), ///
				title("Share of full-time employees") xtitle("Year") ytitle("Share of fulltime employees") ysc(r(0.3 0.9)) ///
				legend(label(1 "Hires in sample jobs") label(2 "Job stayers in sample firms") label(3 "All hires") label(4 "All job stayers")) ///
				ysc(titlegap(*2.5)) ylabel(0.3(0.1)0.9, format(%9.1fc) angle(0) nogrid) ymlabel(,nolabels) xsc(r(1998 2016)) xlabel(1998(2)2016) name(fig_D1E_ft, replace) ///
				tline(2008.5, lwidth(vvthick) lcolor(gs14)) ///
				tline(2009, lwidth(vvvthick) lcolor(gs14)) ///
				tline(2009.5, lwidth(vvthick) lcolor(gs14)) ///
				graphregion(fcolor(white))
		graph export "fig_D1E_ft.png", as(png) name(fig_D1E_ft) replace width(2800) height(2000)
		graph close	
	restore

	* Wages
	preserve
		keep wage* year
		drop if year == 0
		tsset year
		drop if year==1997
		
		cd $figure_dir
		twoway 	(tsline wage, 	lp(shortdash) 	lc(gs5) recast(connected) msymbol(i) mc(gs5)) ///
				(tsline wage_s, lp(solid) 		lc(gs5) recast(connected) msymbol(i) mc(gs5)) ///
				(tsline wage_an, lp("_...")		lc(gs5) recast(connected) msymbol(i) mc(gs5)) ///
				(tsline wage_a, lp(longdash) 	lc(gs5) recast(connected) msymbol(i) mc(gs5)), ///
				title("Median hourly wages") xtitle("Year") ytitle("Median hourly wages ({c L-} 1998)") ysc(r(4.5 9.5)) ///
				legend(label(1 "Hires in sample jobs") label(2 "Job stayers in sample firms") label(3 "All hires") label(4 "All job stayers")) ///
				ysc(titlegap(*2.5)) ylabel(4.5(1)9.5, format(%9.1fc) angle(0) nogrid) ymlabel(,nolabels) xsc(r(1998 2016)) xlabel(1998(2)2016) name(fig_D1D_wages, replace) ///
				tline(2008.5, lwidth(vvthick) lcolor(gs14)) ///
				tline(2009, lwidth(vvvthick) lcolor(gs14)) ///
				tline(2009.5, lwidth(vvthick) lcolor(gs14)) /// 
				graphregion(fcolor(white))
		graph export "fig_D1D_wages.png", as(png) name(fig_D1D_wages) replace width(2800) height(2000)
		graph close	
	restore

	* Earnings
	preserve
		keep earnings* year
		drop if year == 0
		tsset year
		drop if year==1997
		
		cd $figure_dir
		twoway 	(tsline earnings, 	lp(shortdash) 	lc(gs5) recast(connected) msymbol(i) mc(gs5)) ///
				(tsline earnings_s, lp(solid) 		lc(gs5) recast(connected) msymbol(i) mc(gs5)) ///
				(tsline earnings_an, lp("_...")		lc(gs5) recast(connected) msymbol(i) mc(gs5)) ///
				(tsline earnings_a, lp(longdash) 	lc(gs5) recast(connected) msymbol(i) mc(gs5)), ///
				title("Median weekly earnings") xtitle("Year") ytitle("Median weekly earnings ({c L-} 1998)") ysc(r(100 350)) ///
				legend(label(1 "Hires in sample jobs") label(2 "Job stayers in sample firms") label(3 "All hires") label(4 "All job stayers")) ///
				ysc(titlegap(*2.5)) ylabel(100(50)350, format(%9.0fc) angle(0) nogrid) ymlabel(,nolabels) xsc(r(1998 2016)) xlabel(1998(2)2016) name(fig_D1B_earnings, replace) ///
				tline(2008.5, lwidth(vvthick) lcolor(gs14)) ///
				tline(2009, lwidth(vvvthick) lcolor(gs14)) ///
				tline(2009.5, lwidth(vvthick) lcolor(gs14)) /// 
				graphregion(fcolor(white))
		graph export "fig_D1B_earnings.png", as(png) name(fig_D1B_earnings) replace width(2800) height(2000)
		graph close	
	restore

	* Median Hours
	preserve
		keep hours* year
		drop if year == 0
		tsset year
		
		cd $figure_dir
		twoway 	(tsline hours, 		lp(shortdash) 	lc(gs5) recast(connected) msymbol(i) mc(gs5)) ///
				(tsline hours_s, 	lp(solid) 		lc(gs5) recast(connected) msymbol(i) mc(gs5)) ///
				(tsline hours_a, 	lp(longdash) 	lc(gs5) recast(connected) msymbol(i) mc(gs5)), ///
				title("Median weekly hours") xtitle("Year") ytitle("Median weekly hours") ysc(r(20 40)) ///
				legend(label(1 "Hires in sample jobs") label(2 "Job stayers in sample firms") label(3 "All employees")) ///
				ysc(titlegap(*2.5)) ylabel(20(5)40, format(%9.0fc) angle(0) nogrid) ymlabel(,nolabels) xsc(r(1998 2016)) xlabel(1998(2)2016) name(fig_D1F_hours, replace) ///
				tline(2008.5, lwidth(vvthick) lcolor(gs14)) ///
				tline(2009, lwidth(vvvthick) lcolor(gs14)) ///
				tline(2009.5, lwidth(vvthick) lcolor(gs14)) ///
				graphregion(fcolor(white))
		graph export "fig_D1F_hours.png", as(png) name(fig_D1F_hours) replace width(2800) height(2000)
		graph close	
	restore

}

*****************
*** FIGURE D2 ***
*****************
{

	cd $created_datadir
	use slim_1997_2016, clear
	drop if poe!=1
	keep if idbrsta==1 | idbrsta==2 | idbrsta==3
	keep jobid poe year piden hexo

	sort jobid year
	by jobid year: egen wage_med = median(hexo)
	g wage_med_diff = ln(hexo) - ln(wage_med)

	cd $figure_dir
	twoway (hist wage_med_diff if wage_med_diff>=-0.5 & wage_med_diff<=0.51, discrete fraction fcolor(gs12) gap(50) width(0.02) lcolor(black) lwidth(*0) ), ///
			xtitle("Ln difference between worker's hiring wage and median hiring wage within job") ytitle("Share of new hires") ///
			xlabel(-0.5(0.10)0.51, format(%9.1f)) ylabel(0 (0.05) 0.25, nogrid format(%9.2f) angle(0)) legend(off) plotregion(margin(b=0)) ///
			xsc(titlegap(*2.5)) ///
			graphregion(fcolor(white)) name(fig_D2, replace)
		graph export "fig_D2.png", as(png) name(fig_D2) replace width(2800) height(2000)
		graph close


}

*****************
*** FIGURE D3 ***
*****************
{
	
	cd $other_data
	use econ.dta, clear
	tsset year
	cd $figure_dir

	keep year log_prod* unemp
	drop if year == 1997

	g temp = log_prod_gdp[6]
	replace log_prod_gdp = log_prod_gdp - temp
	drop temp

	g temp = log_prod_ser[6]
	replace log_prod_ser = log_prod_ser - temp
	drop temp


	twoway 	(tsline unemp, 	lp(longdash) lc(gs5)) ///
			(tsline log_prod_gdp, yaxis(2) lp(solid) 		lw(*1.0) lc(gs5) ) ///
			(tsline log_prod_ser, yaxis(2) lp(shortdash)  	lw(*1.0) lc(gs5) ), ///
			title("Comparison of business cycle indicators") xtitle("Year") ytitle("Unemployment rate") ytitle("Ln GVA per hour (2003=0)", axis(2)) ///
			legend(cols(1) order(1 2 3) label(1 "Unemployment rate") label(2 "Whole economy GVA per hour (2nd axis)") label(3 "Services sector GVA per hour (2nd axis)")) ///
			ylabel(0.045(0.01)0.085, format(%4.2f) nogrid angle(0)) ymlabel(,nolabels) ysc(titlegap(*2.5) r(0.045 0.085)) ///
			ylabel(-.10(0.05).10, format(%4.2f) axis(2) nogrid angle(0)) ymlabel(,nolabels) ysc(titlegap(*4.5) r(-.12 .12) axis(2)) ///	
			xsc(titlegap(*1.5) r(1998 2016)) xlabel(1998(2)2016) ///
			tline(2008.5, 	lwidth(vvthick) 	lcolor(gs14)) ///
			tline(2009, 	lwidth(vvvthick) 	lcolor(gs14)) ///
			tline(2009.5, 	lwidth(vvthick) 	lcolor(gs14)) ///
			graphregion(fcolor(white)) name(fig_D3, replace) 
		graph export "fig_D3.png", as(png) name(fig_D3) replace width(2800) height(2000)
		graph close


}

*****************
*** FIGURE D4 ***
*****************
{

	*************
	*** 1998-2016
	*************
	cd $reg_resultsdir_97_16
	use results_97_16, clear
	keep year logwage_cpi_med1 logwage_cpi_med2
	ren (logwage_cpi_med1 logwage_cpi_med2) ///
		(logwage_1 logwage_2)
	
	cd $reg_results_poe_criteria
	quiet merge 1:1 year using results_97_16_max, nogen keepusing(logwage_cpi_med1 logwage_cpi_med2)
	
	tsset year
	cd $figure_dir
	
	* Normalise to 0 in 2003
	g temp = logwage_1[6]
	replace logwage_1 		= logwage_1 - temp
	drop temp
	
	g temp = logwage_cpi_med1[6]
	replace logwage_cpi_med1 	= logwage_cpi_med1 - temp
	drop temp
	
	quiet reg logwage_2 year
	predict wage2, resid
	g temp = wage2[6]
	replace wage2 		= wage2 - temp
	drop temp
	
	quiet reg logwage_cpi_med2 year
	predict wage_cpi_med2, resid
	g temp = wage_cpi_med2[6]
	replace wage_cpi_med2 	= wage_cpi_med2 - temp
	drop temp
		
	* Wages hires - POE vs ASHE
	twoway 	(tsline logwage_1, lp(solid) 	recast(connected) msymbol(i) mlc(gs5) lc(gs5)) ///
			(tsline logwage_cpi_med1, lp(shortdash) recast(connected) msymbol(i) mlc(gs5) lc(gs5)), ///
			title("Median hourly wages, new hires") xtitle("Year") ytitle("Log change relative to 2003") ///
			legend(label(1 "Hires in sample jobs") label(2 "All hires") ) ///	
			ylabel(-0.10(0.05)0.05, format(%9.2fc) nogrid angle(0)) ymlabel(,nolabels) ysc(titlegap(*2.5) r(-0.10 0.05)) ///
			tline(2008.5, lwidth(vvthick) lcolor(gs14)) ///
			tline(2009, lwidth(vvvthick) lcolor(gs14)) ///
			tline(2009.5, lwidth(vvthick) lcolor(gs14)) ///
			xsc(titlegap(*1.5) r(1998 2016)) xlabel(1998(2)2016) ///
			graphregion(fcolor(white)) name(fig_D4A_wages, replace)
		graph export "fig_D4A_wages.png", as(png) name(fig_D4A_wages) replace width(2800) height(2000)
	graph close

	* Wages stayers - POE vs ASHE
	twoway 	(tsline wage2, lp(solid) 	recast(connected) msymbol(i) mlc(gs5) lc(gs5)) ///
			(tsline wage_cpi_med2, lp(shortdash) recast(connected) msymbol(i) mlc(gs5) lc(gs5)), ///
			title("Median hourly wages, job stayers") xtitle("Year") ytitle("Log change relative to 2003") ///
			legend( label(1 "Job stayers in sample firms") label(2 "All job stayers")) ///	
			ylabel(-0.10(0.05)0.05, format(%9.2fc) nogrid angle(0)) ymlabel(,nolabels) ysc(titlegap(*2.5) r(-0.10 0.05)) ///
			tline(2008.5, lwidth(vvthick) lcolor(gs14)) ///
			tline(2009, lwidth(vvvthick) lcolor(gs14)) ///
			tline(2009.5, lwidth(vvthick) lcolor(gs14)) ///
			xsc(titlegap(*1.5) r(1998 2016)) xlabel(1998(2)2016) ///
			graphregion(fcolor(white)) name(fig_D4B_wages, replace)
		graph export "fig_D4B_wages.png", as(png) name(fig_D4B_wages) replace width(2800) height(2000)
	graph close

}

*****************
*** FIGURE D5 ***
*****************
{

	*************
	*** 1998-2016
	*************
	cd $reg_resultsdir_97_16
	use results_97_16, clear
	keep year loghours_med1 loghours_med2
	ren (loghours_med1 loghours_med2) ///
		(loghours_1 loghours_2)
	
	cd $reg_results_poe_criteria
	quiet merge 1:1 year using results_97_16_max, nogen keepusing(loghours_med1 loghours_med2)
	
	tsset year
	cd $figure_dir
	
	* Normalise to 0 in 2003
	g temp = loghours_1[6]
	replace loghours_1 		= loghours_1 - temp
	drop temp
	
	g temp = loghours_med1[6]
	replace loghours_med1 	= loghours_med1 - temp
	drop temp
	
	quiet reg loghours_2 year
	predict hours2, resid
	g temp = hours2[6]
	replace hours2 		= hours2 - temp
	drop temp
	
	g temp = loghours_med2[6]
	replace loghours_med2 	= loghours_med2 - temp
	drop temp

	* HOURS WORKED
	twoway  (tsline loghours_1, lp(solid) 	 recast(connected) msymbol(i) mlc(gs5) lc(gs5)) ///
			(tsline loghours_med1, lp(shortdash) recast(connected) msymbol(i) mlc(gs5) lc(gs5)), ///
			title("Median hours worked") xtitle("Year") ytitle("Log change relative to 2003") ///
			legend( label(1 "Hires in sample jobs") label(2 "All hires") ) ///
			ylabel(-0.15(0.05)0.1, format(%9.2fc) nogrid angle(0)) ymlabel(,nolabels) ysc(titlegap(*2.5) r(-0.15 0.1)) ///
			tline(2008.5, lwidth(vvthick) lcolor(gs14)) ///
			tline(2009, lwidth(vvvthick) lcolor(gs14)) ///
			tline(2009.5, lwidth(vvthick) lcolor(gs14)) ///
			xsc(titlegap(*1.5) r(1998 2016)) xlabel(1998(2)2016) ///
			graphregion(fcolor(white)) name(fig_D5A_hours, replace)
	graph export "fig_D5A_hours.png", as(png) name(fig_D5A_hours) replace width(2800) height(2000)
	graph close

	* HOURS WORKED
	twoway  (tsline hours2, lp(solid) 	 recast(connected) msymbol(i) mlc(gs5) lc(gs5)) ///
			(tsline loghours_med2, lp(shortdash) recast(connected) msymbol(i) mlc(gs5) lc(gs5)), ///
			title("Median hours worked") xtitle("Year") ytitle("Log change relative to 2003") ///
			legend( label(1 "Job stayers in sample firms") label(2 "All job stayers") ) ///
			ylabel(-0.15(0.05)0.1, format(%9.2fc) nogrid angle(0)) ymlabel(,nolabels) ysc(titlegap(*2.5) r(-0.15 0.1)) ///
			tline(2008.5, lwidth(vvthick) lcolor(gs14)) ///
			tline(2009, lwidth(vvvthick) lcolor(gs14)) ///
			tline(2009.5, lwidth(vvthick) lcolor(gs14)) ///
			xsc(titlegap(*1.5) r(1998 2016)) xlabel(1998(2)2016) ///
			graphregion(fcolor(white)) name(fig_D5B_hours, replace)
	graph export "fig_D5B_hours.png", as(png) name(fig_D5B_hours) replace width(2800) height(2000)
	graph close


}

*****************
*** FIGURE E1 ***
*****************
{

	cd $created_datadir
	use slim_1997_2016.dta, clear
	keep if idbrsta==1 | idbrsta==2 | idbrsta==3
	drop poe* start now firm_start entry idbrsta w* gp* colag ft

	xtset, clear
	xtset piden year

	/*
	Builds upon code underlying Figure 7 and Table 6 of Elsby, Shin and Solon, 2016, 
	"Wage Adjustment in the Great Recession and Other Downturns.", Journal of Labor Economics
	*/

	capture drop logw
	gen logw = ln(hexo)

	sort piden year
	capture drop dlogw
	gen dlogw = .
	by piden: replace dlogw = logw - L.logw if sjd==1 & jobid==L.jobid
	label var dlogw "Log nominal wage (per hour) change"

	cd $other_data
	sort piden year
	quietly merge m:1 year using CPI.dta, nogen

	sort piden year
	gen dlnCPI = ln(cpi) - ln(L.cpi)

		
	keep if year==2006 | year==2010
	* define limits for histogram
	replace dlogw =  0.35 if dlogw >  0.35 & dlogw~=.
	replace dlogw = -0.20 if dlogw < -0.20 & dlogw~=.

	capture drop dlogw_discrete
	g dlogw_discrete = .

	local l = -0.20
	local d = 0.01
	while `l' < 0 {
		quiet replace dlogw_discrete = `l'+(`d'/2) if dlogw>=`l' & dlogw<`l'+`d'
		local l = `l'+`d'
	}

	local l = 0
	local d = 0.01
	while `l' <= 0.35 {
		quiet replace dlogw_discrete = `l'+(`d'/2) if dlogw>=`l' & dlogw<`l'+`d'
		local l = `l'+`d'
	}
	
	cd $figure_dir
	foreach i in 2006 2010{
		preserve
			keep if year==`i'
			
			quietly sum dlnCPI
			local k = round(`r(mean)', 0.01)
			
			local end 	= `k' + 0.005
			local start = `k' + 0.025
			twoway 	( histogram dlogw_discrete, discrete fraction fcolor(gs12) gap(40) barwidth(0.01) lcolor(black) lwidth(none)) ///
					( pcarrowi 0.17 `start' 0.165 `end' "CPI inflation", mangle(30) color(black) mlabc(black) mlabs(3.5) mlabp(3) barbsize(1.5) ), ///
					xtitle("Change in log nominal wage") ytitle("Share of job stayers") ///
					xlabel(-.2(.05).35, format(%9.2f)) ylabel(0 (.05) .20, nogrid format(%9.2f) angle(0)) legend(off) ///
					xline(0, lwidth(*1.0) lc(b)) xline(`k', lpattern(dash) lwidth(*1.0) lc(b)) ///
					ysc(r(0.01 0.2)) ///
					graphregion(fcolor(white)) plotregion(margin(0)) title(`i') name(fig_E`i', replace) 
				graph export "fig_E`i'.png", as(png) name(fig_E`i') replace width(2800) height(2000)
				graph close
		restore
	}	


}

}

***************************************************
*** Appendix F: DiNardo, Fortin, Lemieux (1996) ***
***************************************************
if $NMW==1{
	
	cd $created_datadir
	use slim_1997_2016, clear

	* define sample to be analysed
	drop if poe!=1
	drop w*

	* Keep only private enterprises
	keep if idbrsta==1 | idbrsta==2 | idbrsta==3

	cd $other_data
	capture drop cpi
	quietly merge m:1 year using nmw.dta, nogen keep(1 3)
	quietly merge m:1 year using CPI.dta, nogen keep(1 3)

	foreach k in nmw_adult nmw_1617 nmw_dev nmw_25{
		replace `k' = ln(`k'*(100/cpi)) if `k'>0
	}

	capture drop nmw
	gen nmw = .
	replace nmw = nmw_1617 		if age>=16 & age<=17 & year>=2004
	replace nmw = nmw_dev 		if age>=18 & age<=21 & year>=1999 & year <=2009
	replace nmw = nmw_dev 		if age>=18 & age<=20 & year>=2010
	replace nmw = nmw_adult 	if age>=22 & year>=1999 & year <=2009
	replace nmw = nmw_adult 	if age>=21 & year>=2010
	replace nmw = nmw_25 		if age>=25 & year>=2016

	rename logwage_cpi logwage

	foreach x in logwage_med nmw_median nmw_mean j_*{
		capture drop `x'
	}
	sort jobid year
	by jobid year: egen logwage_med 	= median(logwage)
	by jobid year: egen nmw_median 		= median(nmw)
	by jobid year: egen nmw_mean 		= mean(nmw)
	by jobid year: egen j_age 			= median(age)
	by jobid year: egen j_sex 			= mean(sex)
	by jobid year: egen j_ft 			= mean(ft)
	by jobid year: egen j_colag 		= mean(colag)

	* Generate hires per job and year for weighting
	sort jobid year
	by jobid year: egen number_hires = count(piden)

	egen tag = tag(jobid year)
	drop if tag==0
	drop tag

	preserve
		collapse (mean) nmw=nmw_adult (p10) w_p10=logwage_med (p25) w_p25=logwage_med (p50) w_p50=logwage_med, by(year)
		tsset year
		
		replace nmw 	= exp(nmw)
		replace w_p50 	= exp(w_p50)
		replace w_p25 	= exp(w_p25)
		replace w_p10 	= exp(w_p10)
		
		cd $figure_dir
		twoway 	(tsline nmw, lp(shortdash) recast(connected) msymbol(X) msize(large) mfc(gs5) mlc(gs5) lc(gs5)) ///
				(tsline w_p50, lp(shortdash) recast(connected) msymbol(i) mlc(gs5) lc(gs5)) ///
				(tsline w_p25, lp(dash) recast(connected) msymbol(i) mlc(gs5) lc(gs5)) ///
				(tsline w_p10, lp(solid) recast(connected) msymbol(i) msize(gs5) mlc(gs5) lc(gs5)), ///
				title("Real hourly hiring wages and NMW rates, age > 21") xtitle("Year") ytitle("Hourly hiring wage ({c L-} 1998)") ///
				legend(off) ///
				ylabel(3.5(.5)5.5, format(%9.1fc) nogrid angle(0)) ymlabel(,nolabels) ysc(titlegap(*2.5) r(3.5 5.5)) ///
				xsc(titlegap(*1.5) r(1998 2016)) xlabel(1998(2)2016) ///
				ttext(5.00 2000 "Median"		,placement(c)) ///
				ttext(4.45 2000 "25th perc."	,placement(c)) ///
				ttext(4.11 2000 "10th perc."	,placement(c)) ///
				ttext(3.60 2001 "NMW adult rate",placement(c)) ///
				tline(2008.5, lwidth(vvthick) lcolor(gs14)) ///
				tline(2009, lwidth(vvvthick) lcolor(gs14)) ///
				tline(2009.5, lwidth(vvthick) lcolor(gs14)) ///
				graphregion(fcolor(white)) name(fig_F1, replace) 
		graph export "fig_F1.png", as(png) name(fig_F1) replace width(2800) height(2000)
		graph close	
	restore


	*DFL_figures
	{
		
		*Density figures
		preserve
			
			cd $figure_dir
			keep if (year>=2002 & year<=2004) | (year>=2012 & year<=2014)

			capture drop marker
			gen marker = 0
			replace marker = 1 if year >=2012 & year<=2014
			
			* make conform with cell counts
			replace logwage_med =	1.300 if logwage_med < 1.30 & marker==0
			replace logwage_med =  	2.235 if logwage_med > 2.235 & marker==0
			replace logwage_med =  	2.050 if logwage_med > 2.05 & marker==1
			drop if logwage_med <  	1.300 & marker==1

			xtset jobid year

			quiet sum logwage_med, detail
			capture drop xstep
			capture drop kwage
			gen xstep = (r(max)-r(min))/r(N)
			gen kwage = r(min)+(_n-1)*xstep if _n<=r(N)

			local mw = ln(4.70)
			
			capture drop fd*
			kdens logwage_med if marker==0, at(kwage) kernel(gauss) bw(0.025) gen(fd02_04) nograph
			kdens logwage_med if marker==1, at(kwage) kernel(gauss) bw(0.020) gen(fd12_14) nograph

			
			local pos1 = `mw' - 0.01
			local pos2 = `pos1' - 0.02
			graph twoway	( scatter fd02_04 kwage if kwage>=1.30 & kwage<=2.0, ms(Oh) msize(1.5) clwidth(medium) ) ///
							( pcarrowi 6.85 `pos2' 6.55 `pos1' "NMW 2013", mangle(30) color(black) mlabc(black) mlabs(3.5) mlabp(9) barbsize(1.5) ), ///
							title("Estimated density of real hiring wages 2002-04") xtitle("Log of real hourly hiring wage") ytitle("Density") ///
							xlabel(1.39 "ln(4.0)" `mw' "ln(4.7)" 1.79 "ln(6.0)" 2.0 "ln(7.4)") xline(`mw', lc(black)) xsc(titlegap(*1.5) r(1.30 2.01)) ///
							ylabel(0.0(2.0)7.0, format(%9.0fc) nogrid angle(0)) ymlabel(,nolabels) ysc(titlegap(*2.5) r(0.0 7.0)) ///
							legend(off) ///
							graphregion(fcolor(white)) plotregion(margin(0)) name(fig_F3A, replace) 		
						graph export "fig_F3A.png", as(png) name(fig_F3A) replace width(2800) height(2000)
						graph close
		
			
			local pos1 = `mw' - 0.01
			local pos2 = `pos1' - 0.02
			graph twoway	( scatter fd12_14 kwage if kwage>=1.30 & kwage<=2.0, ms(Oh) msize(1.5) clwidth(medium) )  ///
							( pcarrowi 6.85 `pos2' 6.55 `pos1' "NMW 2013", color(black) mlabc(black) mlabs(3.5) mlabp(9) barbsize(1.5) mangle(30)), ///
							title("Estimated density of log real hiring wages 2012-14") xtitle("Log of real hourly hiring wage") ytitle("Density") ///
							xlabel(1.39 "ln(4.0)" `mw' "ln(4.7)" 1.79 "ln(6.0)" 2.0 "ln(7.4)") xline(`mw', lc(black)) xsc(titlegap(*1.5) r(1.30 2.01)) ///
							ylabel(0.0(2.0)7.0, format(%9.0fc) nogrid angle(0)) ymlabel(,nolabels) ysc(titlegap(*2.5) r(0.0 7.0)) ///
							legend(off) ///
							graphregion(fcolor(white)) plotregion(margin(0)) name(fig_F3B, replace) 							
						graph export "fig_F3B.png", as(png) name(fig_F3B) replace width(2800) height(2000)
						graph close
			
			capture drop industry
			gen industry = floor(sic / 10000)

			capture drop below_min
			gen 	below_min = 0
			replace below_min = 1 if logwage_med <= `mw'

			capture drop y12_14
			gen y12_14 = 0
			replace y12_14=1 if marker==1
			quiet logit y12_14 i.industry age c.j_age#c.j_age c.j_age#c.j_age#c.j_age j_colag j_ft j_sex idbrnemp c.idbrnemp#c.idbrnemp if (below_min==1)
			capture drop py12_14
			predict py12_14, p 

			quiet sum y12_14
			capture drop pbar
			gen pbar = r(mean)
			capture drop psi_x
			gen psi_x = (py12_14)/(1-py12_14) * (1-pbar)/(pbar)

			gen 	weight = 0
			replace weight = 0 		if marker==1 & below_min == 1
			replace weight = 1 		if marker==1 & below_min == 0
			replace weight = psi_x	if marker==0 & below_min == 1

			capture drop fd12_14x03
			kdens logwage_med [aweight=weight], at(kwage) kernel(gauss) bw(0.018) gen(fd12_14x03) nograph

			
			local pos1 = `mw' - 0.01
			local pos2 = `pos1' - 0.02
			graph twoway	( scatter fd12_14x03 kwage if kwage>=1.30 & kwage<=2.0, ms(Oh) msize(1.5) clwidth(medium) )  ///
							( pcarrowi 6.85 `pos2' 6.55 `pos1' "NMW 2013", color(black) mlabc(black) mlabs(3.5) mlabp(9) barbsize(1.5) mangle(30)), ///
							title("Counterfactual density of log real hiring wages 2012-14") xtitle("Log of real hourly hiring wage") ytitle("Density") ///
							xlabel(1.39 "ln(4.0)" `mw' "ln(4.7)" 1.79 "ln(6.0)" 2.0 "ln(7.4)") xline(`mw', lc(black)) xsc(titlegap(*1.5) r(1.30 2.01)) ///
							ylabel(0.0(2.0)7.0, format(%9.0fc) nogrid angle(0)) ymlabel(,nolabels) ysc(titlegap(*2.5) r(0.0 7.0)) ///
							legend(off) ///
							graphregion(fcolor(white)) plotregion(margin(0)) name(fig_F3C, replace) 			
						graph export "fig_F3C.png", as(png) name(fig_F3C) replace width(2800) height(2000)
						graph close

			local pos1 = `mw' - 0.01
			local pos2 = `pos1' - 0.02
			graph twoway	( scatter fd12_14 	kwage if kwage>=1.30 & kwage<=2.0, ms(Oh) msize(1.5) clwidth(medium) ) ///
							( connected fd12_14x03 	kwage if kwage>=1.33 & kwage<=2.0, msymbol(i) clwidth(medium) lpattern(solid) lc(black)) ///
							( pcarrowi 6.85 `pos2' 6.55 `pos1' "NMW 2013", color(black) mlabc(black) mlabs(3.5) mlabp(9) barbsize(1.5) mangle(30)) ///
							( pcarrowi 1.80  1.45 1.40  1.47 "Adjusted density", color(black) mlabc(black) mlabs(3.5) mlabp(11) barbsize(1.5) mangle(30)) ///
							( pcarrowi 5.40  1.51 5.10  1.53 "Density 2012-14", color(black) mlabc(black) mlabs(3.5) mlabp(9) barbsize(1.5) mangle(30)), ///
							title("Estimated and counterfactual densities, 2012-14") xtitle("Log of real hourly hiring wage") ytitle("Density") ///
							xlabel(1.39 "ln(4.0)" `mw' "ln(4.7)" 1.79 "ln(6.0)" 2.0 "ln(7.4)") xline(`mw', lc(black)) xsc(titlegap(*1.5) r(1.30 2.01)) ///
							ylabel(0.0(2.0)7.0, format(%9.0fc) nogrid angle(0)) ymlabel(,nolabels) ysc(titlegap(*2.5) r(0.0 7.0)) ///
							legend(off) ///
							graphregion(fcolor(white)) plotregion(margin(0)) name(fig_F4A, replace) 	
						graph export "fig_F4A.png", as(png) name(fig_F4A) replace width(2800) height(2000)
						graph close	
			
			
			capture drop temp
			gen temp = fd12_14x03 - fd12_14
			local pos1 = `mw' - 0.01
			local pos2 = `pos1' - 0.02
			graph twoway	( connected temp 	kwage if kwage>=1.30 & kwage<=2.0, ms(i) lpattern(solid) msize(1.5) clwidth(medium) ) ///
							( pcarrowi 1.75 `pos2' 1.55 `pos1' "NMW 2013", color(black) mlabc(black) mlabs(3.5) mlabp(9) barbsize(1.5) mangle(30)), ///
							title("Difference between estimated and counterfactual densities") xtitle("Log of real hourly hiring wage") ytitle("Density") ///
							xlabel(1.39 "ln(4.0)" `mw' "ln(4.7)" 1.79 "ln(6.0)" 2.0 "ln(7.4)") xline(`mw', lc(black)) xsc(titlegap(*1.5) r(1.30 2.01)) ///
							yline(0, lc(gs12) lw(*0.7)) ///
							ylabel(-2.0(1.0)2.0, format(%9.0fc) nogrid angle(0)) ymlabel(,nolabels) ysc(titlegap(*2.5) r(-2.2 2.0)) ///
							legend(off) ///
							graphregion(fcolor(white)) plotregion(margin(0)) name(fig_F4B, replace) 	
						graph export "fig_F4B.png", as(png) name(fig_F4B) replace width(2800) height(2000)
						graph close							
					
		restore
	}

	* Generate counterfactual hiring wages	
	forvalue i = 2004/2016{
		forvalue spillover = 0(1)100{
			preserve	
				
				keep if year==2003 | year==`i'
				xtset jobid year
				
				quiet sum logwage_med, detail
				capture drop xstep
				capture drop kwage
				gen xstep = (r(max)-r(min))/r(N)
				gen kwage = r(min)+(_n-1)*xstep if _n<=r(N)
				
				capture drop fd*
				kdens logwage_med if year==2003, at(kwage) kernel(gauss) bw(sj) gen(fd2003) nograph
				kdens logwage_med if year==`i',  at(kwage) kernel(gauss) bw(sj) gen(fd`i') nograph
				local kwidth = r(width)
				
				quiet sum nmw_adult if year==`i'
				local mw = r(mean) + `spillover'/1000
				local nom= round(exp(`mw'), .01)
				
				capture drop industry
				gen industry = floor(sic / 10000)
				
				capture drop below_min
				gen 	below_min = 0
				replace below_min = 1 if logwage_med <= `mw'

				capture drop y`i'
				gen y`i' = 0
				replace y`i'=1 if year==`i'
				quiet logit y`i' i.industry age c.j_age#c.j_age c.j_age#c.j_age#c.j_age j_colag j_ft j_sex idbrnemp c.idbrnemp#c.idbrnemp if (below_min==1)
				capture drop py`i'
				predict py`i', p 

				quiet sum y`i'
				capture drop pbar
				gen pbar = r(mean)
				capture drop psi_x
				gen psi_x = (py`i')/(1-py`i') * (1-pbar)/(pbar)
				
				gen 	weight = 0
				replace weight = 0 		if year==`i' & below_min == 1
				replace weight = 1 		if year==`i' & below_min == 0
				replace weight = psi_x	if year==2003 & below_min== 1
				
				keep logwage_med jobid year weight
				
				capture drop cdf_old
				cumul logwage_med if year==`i' , gen(cdf_old) freq

				quiet sum cdf_old, d
				local k 	= 100/r(N)
				local p 	= r(N) - 1
				local start = 0 + `k'
				local end 	= 100 - `k'
				_pctile logwage_med [aweight = weight], p(`start'(`k')`end')
				
				sort cdf_old
				capture drop clogwage
				gen clogwage = .
				forvalue j = 1/`p'{
					quiet replace clogwage = r(r`j') if cdf_old == `j'+1
					}
				quiet sum logwage_med [aweight = weight], d
				replace clogwage = r(min) if cdf_old == 1

				keep year jobid clogwage
				rename clogwage clogwage`spillover'
				drop if year == 2003
				cd $nmw
				save counterfactual`spillover'_`i', replace
			restore
		}		
	}


	cd $created_datadir
	use slim_1997_2016, clear
	drop if poe!=1
	keep if idbrsta==1 | idbrsta==2 | idbrsta==3

	foreach k in age idbrnemp{
		capture drop `k'_j
		sort jobid year
		by jobid year: egen `k'_j = median(`k')
		quietly replace `k' = `k'_j
		drop `k'_j
		}
		
	foreach k in colag sex{
		capture drop `k'_j
		sort jobid year
		by jobid year: egen `k'_j = mean(`k')
		quietly replace `k' = `k'_j
		drop `k'_j
		}

	capture drop tag
	egen tag = tag(jobid year)
	keep if tag==1
	drop tag

	* concatenate the data
	cd $nmw
	forvalue i = 2004/2016{
		forvalue spillover = 0(1)100{
			quiet merge 1:1 year jobid using counterfactual`spillover'_`i', update nogen
			quiet replace clogwage`spillover' = logwage_cpi if year<=2003
			erase counterfactual`spillover'_`i'.dta
		}
	}

	g agesq 		= (age)^2
	g agecub 		= (age)^3
	g idbrnempsq 	= idbrnemp^2

	xtset, clear
	xtset jobid year
	
	quietly tab year, gen(d)

	foreach p in clogwage{
		forvalue spillover = 0(1)100{
			preserve
				quietly areg `p'`spillover' d2-d19 age agesq agecub idbrnemp idbrnempsq sex colag, absorb(jobid) vce(cluster jobid)
				matrix b = e(b)
				clear
				svmat b
				forvalue i=1/18 {
				rename b`i' c`i'
				}
				drop b*
				xpose, clear
				capture drop year
				gen year=_n + 1998
				gen se=.
				forvalue i = 2/19{
					quietly replace se=_se[d`i'] if year==1997+`i'
				}	
				quietly rename se `p'_`spillover'_se
				quietly rename v1 `p'_`spillover'
				cd $nmw 
				save beta_`p'`spillover'.dta, replace
			restore
		}
	}

	cd $other_data
	use econ, clear
	cd $nmw
	foreach p in clogwage {
		forvalue spillover = 0(1)100{
			quietly merge 1:1 year using beta_`p'`spillover', nogen
			capture erase beta_`p'`spillover'.dta
		}
	}	
	drop if year<=1998

	cd $nmw
	save results_clogwage.dta, replace

	cd $nmw
	use results_clogwage, clear
	tsset year

	forvalue spillover = 0(1)100{
		quietly newey clogwage_`spillover' unemp year, lag(1)
		preserve
			clear
			set obs 1
			gen b = _b[unemp]
			gen se = _se[unemp]
			gen id = `spillover'
			cd $nmw
			quiet save clogwage_`spillover'.dta, replace
		restore
	}

	cd $nmw
	use clogwage_0.dta, clear
	forvalue spillover = 1(1)100{
		append using clogwage_`spillover'.dta
		erase clogwage_`spillover'.dta
	}
	cd $nmw
	save second_stage_counterfactual.dta, replace
	erase clogwage_0.dta

	*************************************
	*** Second stage estimates figure ***
	*************************************

	cd $nmw
	use second_stage_counterfactual.dta, clear

	replace id = id/10

	cd $figure_dir
	graph twoway	( scatter b id, msymbol(Oh) ), ///	
					title("Second stage estimates with varying spillover assumption")  ytitle("Estimated semi-elasticity") ///
					xlabel(0(1)10) xsc(titlegap(*2.5) r(0 10)) xtitle("Assumed spillover of NMW in percentage points") ///
					ylabel(-2.3(-0.1)-2.8, format(%9.1fc) nogrid angle(0)) ymlabel(,nolabels) yline(-2.55, lc(black) lpattern(shortdash)) ysc(titlegap(*2.5) r(-2.3 -2.8)) ///
					legend(order(1) label(1 "Semi-elasticity of real hiring wages to unemployment rate") ) ///
					text(-2.53 3 "Baseline estimate: -2.56", placement(e)) ///
					graphregion(fcolor(white)) name(fig_F2, replace) 	
				graph export "fig_F2.png", as(png) name(fig_F2) replace width(2800) height(2000)
				graph close

}

********************************************
*** Test for selection bias (Wooldridge) ***
********************************************
{
	cd $created_datadir
	use slim_2003_2016_all.dta, clear
	
	* Select the industries to consider
	g industry = floor(sic/10000)
	keep if industry==5 | industry==7 | industry==9
	drop industry
	
	* Keep jobs with at least three observations
	sort jobid year
	by jobid year: egen count = sum(poe)
	g temp = 0
	by jobid year: replace temp = 1 if count>=3
	drop count
	
	foreach k in age idbrnemp{
		capture drop `k'_j
		sort jobid year
		by jobid year: egen `k'_j = median(`k')
		quietly replace `k' = `k'_j
		drop `k'_j
	}
	
	foreach k in colag sex{
		capture drop `k'_j
		sort jobid year
		by jobid year: egen `k'_j = mean(`k')
		quietly replace `k' = `k'_j
		drop `k'_j
	}

	foreach p in logwage_cpi{
		capture drop `p'_med
		sort jobid year 
		by jobid year: egen `p'_med = median(`p')
		drop `p'
	}

	* Keep one obs per job and year
	egen tag = tag(jobid year)
	keep if tag==1
	drop tag

	g agesq 		= (age)^2
	g agecub 		= (age)^3
	g idbrnempsq 	= idbrnemp^2
	
	quietly tab year, gen(d)
	
	cd $other_data
	quiet merge m:1 year using econ, nogen keepusing(unemp)
	
	xtset, clear
	xtset jobid year
	
	areg logwage_cpi_med L.temp d2-d14 unemp age agesq agecub idbrnemp idbrnempsq sex colag, absorb(jobid) vce(cluster jobid)

}

**********************************************
*** Ramsey RESET test for misspecification ***
**********************************************
{
	* NEW HIRES
	cd $created_datadir
	use slim_1997_2016, clear

	* define sample to be analysed
	drop if poe!=1

	* Keep only private enterprises
	keep if idbrsta==1 | idbrsta==2 | idbrsta==3

	*** COVARIATES
	foreach k in age idbrnemp{
		capture drop `k'_j
		sort jobid year
		by jobid year: egen `k'_j = median(`k')
		quietly replace `k' = `k'_j
		drop `k'_j
		}

	replace sex = 0 if sex==2
	foreach k in colag sex ft{
		capture drop `k'_j
		sort jobid year
		by jobid year: egen `k'_j = mean(`k')
		quietly replace `k' = `k'_j
		drop `k'_j
		}

	foreach p in logwage_cpi{
		capture drop `p'_med
		sort jobid year 
		by jobid year: egen `p'_med = median(`p')
		drop `p'
		}
		
	foreach p in loghours{
		capture drop `p'_med
		sort jobid year 
		by jobid year: egen `p'_med = median(`p')
		drop `p'
		}

	* Keep one obs per job and year
	egen tag = tag(jobid year)
	keep if tag==1
	drop tag

	gen agesq 		= (age)^2
	gen agecub 		= (age)^3
	gen idbrnempsq 	= idbrnemp^2

	xtset, clear
	xtset jobid year

	quietly tab year, gen(d)

	quiet areg logwage_cpi_med d2-d19 age agesq agecub idbrnemp idbrnempsq sex colag, absorb(jobid) vce(cluster jobid)
	predict y
	g y2 = y*y
	g y3 = y*y*y
	quiet areg logwage_cpi_med y2 y3 d2-d19 age agesq agecub idbrnemp idbrnempsq sex colag, absorb(jobid) vce(cluster jobid)
	test y2 y3
	
	drop y y2 y3
	quiet areg loghours d2-d19 age agesq agecub idbrnemp idbrnempsq sex colag, absorb(jobid) vce(cluster jobid)
	predict y
	g y2 = y*y
	g y3 = y*y*y
	quiet areg loghours y2 y3 d2-d19 age agesq agecub idbrnemp idbrnempsq sex colag, absorb(jobid) vce(cluster jobid)
	test y2 y3

	****************************************************************************
	
	* JOB STAYERS
	cd $created_datadir
	use slim_1997_2016, clear

	keep if idbrsta==1 | idbrsta==2 | idbrsta==3

	xtset, clear
	xtset piden year

	drop poe* w*
	drop if idbrnemp==0

	replace sex = 0 if sex==1
	replace sex = 1 if sex==2

	forvalues i = 2016(-1)1999{
		preserve
			local k = `i' - 1
			keep if (year == `i') | (year == `k')
			keep piden jobid year age tenure idbrnemp log* sjd entref sex colag ft sic

			* Keep only employees who are observed in the same job consecutively
			sort piden year
			capture drop f`i'
			quiet gen f`i' = .
			quiet by piden: replace f`i'=1 if L.jobid==jobid & year == `i' & sjd==1 

			capture drop b`k'
			quiet gen b`k' = .
			quiet by piden: replace b`k'=1 if F.jobid==jobid & year == `k' & F.sjd==1
			
			sort jobid year
			capture drop temp
			capture drop temp2
			by jobid year: egen temp 	= count(f`i')
			by jobid year: egen temp2 	= count(b`k')
			drop if temp<3 & year == `i'
			drop if temp2<3 & year == `k'
			
			*drop temp temp2
			
			sort jobid year
			foreach x of varlist colag sex ft sic{
				by jobid year: egen asd_`x'_`i' = mean(`x') if f`i'==1
				by jobid year: egen asd_`x'_`k' = mean(`x') if b`k'==1
				by jobid: egen `x'_`i' = mean(asd_`x'_`i')
				by jobid: egen `x'_`k' = mean(asd_`x'_`k')
				drop asd_`x'_`i' asd_`x'_`k'
			}
			foreach x of varlist age tenure idbrnemp{
				by jobid year: egen asd_`x'_`i' = median(`x') if f`i'==1
				by jobid year: egen asd_`x'_`k' = median(`x') if b`k'==1
				by jobid: egen `x'_`i' = mean(asd_`x'_`i')
				by jobid: egen `x'_`k' = mean(asd_`x'_`k')
				drop asd_`x'_`i' asd_`x'_`k'
			}		
			foreach x of varlist logwage_cpi loghours{
				by jobid year: egen asd_`x'_`i' = median(`x') if f`i'==1
				by jobid year: egen asd_`x'_`k' = median(`x') if b`k'==1
				by jobid: egen `x'_`i' = mean(asd_`x'_`i')
				by jobid: egen `x'_`k' = mean(asd_`x'_`k')
				drop asd_`x'_`i' asd_`x'_`k'
			} 		
			drop f`i' b`k'
			
			capture drop tag
			egen tag = tag(jobid)
			drop if tag==0
			drop tag

			sort jobid
			foreach x of varlist age_`k' age_`i'{
				by jobid: gen sq`x' = (`x'-37)^2
				by jobid: gen cub`x' = (`x'-37)^3
			}	
			foreach x of varlist tenure_`k' tenure_`i'{
				by jobid: gen sq`x' = (`x'-7)^2
				by jobid: gen cub`x' = (`x'-7)^3
			}				
			
			keep jobid temp2 sic age_* loghours_* colag_* sex_* ft_* sqtenure_* sqage_* cubtenure_* cubage_* idbrnemp_* logwage_cpi_* entref

			quietly reshape long age_ loghours_ colag_ sex_ ft_ sqtenure_ sqage_ cubtenure_ cubage_ idbrnemp_ logwage_cpi_, i(jobid) j(year)
			
			rename idbrnemp_ asd
		
			capture drop id
			gen id = `i'
			
			rename asd idbrnemp_
			
			cd $created_datadir
			save temp`i'.dta, replace
		restore
	}

	* create empty dataset
	cd $created_datadir
	use temp2016.dta, clear
	forvalues i = 2015(-1)1999{
		append using temp`i'.dta
		capture erase temp`i'.dta
	}

	rename *_ *

	capture drop firm_life
	capture drop firm_start 
	capture drop firm_end
	sort entref
	by entref: egen firm_end=max(year)
	by entref: egen firm_start=min(year)
	gen firm_life=firm_end-firm_start+1
	drop entref

	* Keep only jobs which are observed for at least 50% of the years for which the firm exists
	sort jobid
	capture drop rel_years
	capture drop tag
	egen tag = tag(jobid year)
	replace tag=. if tag==0
	by jobid: egen rel_years = sum(tag)
	drop if (rel_years/firm_life)<0.5 & rel_years!=.
	drop rel_years tag firm*

	capture drop temp
	egen temp = group(jobid id)
	drop jobid id
	rename temp jobid

	xtset, clear
	xtset jobid year

	quietly tab year, gen(d)

	quietly areg logwage_cpi d2-d19 idbrnemp sqage sqtenure cubage cubtenure colag, absorb(jobid) vce(cluster jobid)
	predict y
	g y2 = y*y
	g y3 = y*y*y
	g y4 = y*y*y*y
	quiet areg logwage_cpi y2 y3 d2-d19 idbrnemp sqage sqtenure cubage cubtenure colag, absorb(jobid) vce(cluster jobid)
	test y2 y3
	
	drop y y2 y3
	quiet areg loghours d2-d19 idbrnemp sqage sqtenure cubage cubtenure colag, absorb(jobid) vce(cluster jobid)
	predict y
	g y2 = y*y
	g y3 = y*y*y
	quiet areg loghours y2 y3 d2-d19 idbrnemp sqage sqtenure cubage cubtenure colag, absorb(jobid) vce(cluster jobid)
	test y2 y3
		
}

**********************************************
*** Test for cyclicality of worker quality ***
**********************************************
{
	cd $created_datadir
	use slim_1997_2016_all.dta, clear
	
	g ind  = floor(sic/10000)
	g ind2 = floor(sic/1000)
	g ind3 = floor(sic/100)
	g ind4 = floor(sic/10)
	
	xtset, clear
	xtset piden year
	
	* Mean industry wage by year and relative difference
	* 1-DIGIT
	sort year ind
	by year ind: egen mean_ind = mean(logwage_cpi)
	g diff_wage = logwage_cpi - mean_ind
	* 2-DIGIT
	sort year ind2
	by year ind2: egen mean_ind2 = mean(logwage_cpi)
	g diff_wage2 = logwage_cpi - mean_ind2
	* 3-DIGIT
	sort year ind3
	by year ind3: egen mean_ind3 = mean(logwage_cpi)
	g diff_wage3 = logwage_cpi - mean_ind3
	* 4-DIGIT
	sort year ind4
	by year ind4: egen mean_ind4 = mean(logwage_cpi)
	g diff_wage4 = logwage_cpi - mean_ind4
	drop mean_ind mean_ind2 mean_ind3 mean_ind4
	
	* Create for each observation the previous wage
	sort piden year
	g last_wage		 = logwage_cpi[_n-1] if piden == piden[_n-1]
	
	* 1-DIGIT
	g last_wage_diff = diff_wage[_n-1] if piden == piden[_n-1]
	* 2-DIGIT
	g last_wage_diff2 = diff_wage2[_n-1] if piden == piden[_n-1]
	* 3-DIGIT
	g last_wage_diff3 = diff_wage3[_n-1] if piden == piden[_n-1]
	* 4-DIGIT
	g last_wage_diff4 = diff_wage4[_n-1] if piden == piden[_n-1]
	drop diff_wage diff_wage2 diff_wage3 diff_wage4
	
	keep if poe==1
	
	foreach k in age idbrnemp{
		capture drop `k'_j
		sort jobid year
		by jobid year: egen `k'_j = median(`k')
		quietly replace `k' = `k'_j
		drop `k'_j
	}
	
	foreach k in colag sex{
		capture drop `k'_j
		sort jobid year
		by jobid year: egen `k'_j = mean(`k')
		quietly replace `k' = `k'_j
		drop `k'_j
	}
	
	foreach p in last_wage{
		capture drop `p'_med
		sort jobid year 
		by jobid year: egen `p'_med = median(`p')
		drop `p'
	}

	foreach p in last_wage_diff last_wage_diff2 last_wage_diff3 last_wage_diff4{
		capture drop `p'_med
		sort jobid year 
		by jobid year: egen `p'_med = median(`p')
		drop `p'
	}

	* Keep one obs per job and year
	egen tag = tag(jobid year)
	keep if tag==1
	drop tag

	gen agesq 		= (age)^2
	gen agecub 		= (age)^3
	gen idbrnempsq 	= idbrnemp^2

	xtset, clear
	xtset jobid year

	quietly tab year, gen(d)
	
	* Last wage
	preserve
		quietly areg last_wage_med d2-d19 age agesq agecub idbrnemp idbrnempsq sex colag, absorb(jobid) vce(cluster jobid)
		matrix b = e(b)
		clear
		svmat b
		forvalue i=1/18 {
		rename b`i' c`i'
		}
		drop b*
		xpose, clear
		capture drop year
		gen year=_n + 1998
		
		cd $other_data
		merge 1:1 year using econ, nogen
		drop if year<1999
		
		* The coefficient on "unemp" gives the response of the dependent 
		* variable wrt to the unemployment rate
		reg v1 year unemp
	restore
	
	* Difference to mean industry wage
	preserve
		quietly areg last_wage_diff4_med d2-d19 age agesq agecub idbrnemp idbrnempsq sex colag, absorb(jobid) vce(cluster jobid)
		matrix b = e(b)
		clear
		svmat b
		forvalue i=1/18 {
		rename b`i' c`i'
		}
		drop b*
		xpose, clear
		capture drop year
		gen year=_n + 1998
		
		cd $other_data
		merge 1:1 year using econ, nogen
		drop if year<1999
		
		* The coefficient on "unemp" gives the response of the dependent 
		* variable wrt to the unemployment rate
		tsset year
		newey v1 year unemp, lag(1)
	restore
	
}

capture log close